# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nodes.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bnodes.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"`\n\x11NodeCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf3\x01\n\x12NodeCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\x05token\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xf0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"N\n\x0eNodeGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcd\x01\n\x0fNodeGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"l\n\x11NodeUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\"\n\x04node\x18\x03 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x12NodeUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04node\x18\x02 \x01(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x11NodeDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xaf\x01\n\x12NodeDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x0fNodeListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb8\x01\n\x10NodeListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12#\n\x05nodes\x18\x02 \x03(\x0b\x32\x08.v1.NodeB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x8f\x01\n\x13NodeTCPProbeRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x1b\n\x07node_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04host\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04port\x18\x04 \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xeb\x01\n\x14NodeTCPProbeResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tsucceeded\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x65rror\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x94\x02\n\x04Node\x12&\n\x05relay\x18\x01 \x01(\x0b\x32\t.v1.RelayB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12*\n\x07gateway\x18\x02 \x01(\x0b\x32\x0b.v1.GatewayB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\x35\n\rproxy_cluster\x18\x03 \x01(\x0b\x32\x10.v1.ProxyClusterB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00:[\xfa\xf8\xb3\x07L\xc2\xf3\xb3\x07G\xa2\xf3\xb3\x07\x1dtf_examples/node_resource.txt\xaa\xf3\xb3\x07 tf_examples/node_data_source.txt\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42$\n\x04node\x12\x1c\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04tags\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\"\xa8\x04\n\x05Relay\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12<\n\x05state\x18\x03 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0egateway_filter\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06\x64\x65vice\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12!\n\x08location\x18\x07 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12 \n\x07version\x18\x08 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12,\n\x04uuid\x18\t \x01(\tB\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12t\n\x13maintenance_windows\x18\x0b \x03(\x0b\x32\x19.v1.NodeMaintenanceWindowB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12maintenance_window\x12L\n\x10\x64iscovery_config\x18\x0c \x01(\x0b\x32\x17.v1.NodeDiscoveryConfigB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x84\x05\n\x07Gateway\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12<\n\x05state\x18\x03 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\x12,\n\x0elisten_address\x18\x04 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xe0\xf3\xb3\x07\x01\x12*\n\x0c\x62ind_address\x18\x05 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xe0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12\"\n\x04tags\x18\x06 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0egateway_filter\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06\x64\x65vice\x18\x08 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12!\n\x08location\x18\t \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12 \n\x07version\x18\n \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12,\n\x04uuid\x18\x0b \x01(\tB\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12t\n\x13maintenance_windows\x18\r \x03(\x0b\x32\x19.v1.NodeMaintenanceWindowB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12maintenance_window\x12L\n\x10\x64iscovery_config\x18\x0e \x01(\x0b\x32\x17.v1.NodeDiscoveryConfigB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xdb\x02\n\x0cProxyCluster\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12 \n\x07\x61\x64\x64ress\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12t\n\x13maintenance_windows\x18\x05 \x03(\x0b\x32\x19.v1.NodeMaintenanceWindowB<\xf2\xf8\xb3\x07\x37\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07-\xc2\xf4\xb3\x07(\n\x12terraform-provider\x12\x12maintenance_window\x12L\n\x10\x64iscovery_config\x18\x06 \x01(\x0b\x32\x17.v1.NodeDiscoveryConfigB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb6\x01\n\x15NodeMaintenanceWindow\x12!\n\rcron_schedule\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x10require_idleness\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:T\xfa\xf8\xb3\x07O\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x45\xf2\xf3\xb3\x07\x1e\n\x12terraform-provider\x12\x08TypeList\xfa\xf3\xb3\x07\x1dnodeMaintenanceWindowElemType\"\xc3\x01\n\x13NodeDiscoveryConfig\x12\x1b\n\x07\x65nabled\x18\x01 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x06period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\x0c\x65nabledTypes\x18\x03 \x03(\x0b\x32\x1b.v1.NodeDiscoveryTypeConfigB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"N\n\x17NodeDiscoveryTypeConfig\x12\x18\n\x04type\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private2\x93\x05\n\x05Nodes\x12Z\n\x06\x43reate\x12\x15.v1.NodeCreateRequest\x1a\x16.v1.NodeCreateResponse\"!\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/nodes\x12U\n\x03Get\x12\x12.v1.NodeGetRequest\x1a\x13.v1.NodeGetResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/nodes/{id}\x12^\n\x06Update\x12\x15.v1.NodeUpdateRequest\x1a\x16.v1.NodeUpdateResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/nodes/{id}\x12\x61\n\x06\x44\x65lete\x12\x15.v1.NodeDeleteRequest\x1a\x16.v1.NodeDeleteResponse\"(\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/nodes/{id}\x12S\n\x04List\x12\x13.v1.NodeListRequest\x1a\x14.v1.NodeListResponse\" \x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/nodes\x12\x89\x01\n\x08TCPProbe\x12\x17.v1.NodeTCPProbeRequest\x1a\x18.v1.NodeTCPProbeResponse\"J\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/nodes/tcp-probe\x82\xf9\xb3\x07\x1a\xca\xf3\xb3\x07\x15\xc2\xf4\xb3\x07\x10\n\x04java\x12\x08tcpProbe\x1a\x33\xca\xf9\xb3\x07\t\xc2\xf9\xb3\x07\x04Node\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02n-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cliBa\n\x19\x63om.strongdm.api.plumbingB\rNodesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_NODECREATEREQUEST = DESCRIPTOR.message_types_by_name['NodeCreateRequest']
_NODECREATERESPONSE = DESCRIPTOR.message_types_by_name['NodeCreateResponse']
_NODEGETREQUEST = DESCRIPTOR.message_types_by_name['NodeGetRequest']
_NODEGETRESPONSE = DESCRIPTOR.message_types_by_name['NodeGetResponse']
_NODEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['NodeUpdateRequest']
_NODEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['NodeUpdateResponse']
_NODEDELETEREQUEST = DESCRIPTOR.message_types_by_name['NodeDeleteRequest']
_NODEDELETERESPONSE = DESCRIPTOR.message_types_by_name['NodeDeleteResponse']
_NODELISTREQUEST = DESCRIPTOR.message_types_by_name['NodeListRequest']
_NODELISTRESPONSE = DESCRIPTOR.message_types_by_name['NodeListResponse']
_NODETCPPROBEREQUEST = DESCRIPTOR.message_types_by_name['NodeTCPProbeRequest']
_NODETCPPROBERESPONSE = DESCRIPTOR.message_types_by_name['NodeTCPProbeResponse']
_NODE = DESCRIPTOR.message_types_by_name['Node']
_RELAY = DESCRIPTOR.message_types_by_name['Relay']
_GATEWAY = DESCRIPTOR.message_types_by_name['Gateway']
_PROXYCLUSTER = DESCRIPTOR.message_types_by_name['ProxyCluster']
_NODEMAINTENANCEWINDOW = DESCRIPTOR.message_types_by_name['NodeMaintenanceWindow']
_NODEDISCOVERYCONFIG = DESCRIPTOR.message_types_by_name['NodeDiscoveryConfig']
_NODEDISCOVERYTYPECONFIG = DESCRIPTOR.message_types_by_name['NodeDiscoveryTypeConfig']
NodeCreateRequest = _reflection.GeneratedProtocolMessageType('NodeCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODECREATEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeCreateRequest)
  })
_sym_db.RegisterMessage(NodeCreateRequest)

NodeCreateResponse = _reflection.GeneratedProtocolMessageType('NodeCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODECREATERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeCreateResponse)
  })
_sym_db.RegisterMessage(NodeCreateResponse)

NodeGetRequest = _reflection.GeneratedProtocolMessageType('NodeGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEGETREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeGetRequest)
  })
_sym_db.RegisterMessage(NodeGetRequest)

NodeGetResponse = _reflection.GeneratedProtocolMessageType('NodeGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEGETRESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeGetResponse)
  })
_sym_db.RegisterMessage(NodeGetResponse)

NodeUpdateRequest = _reflection.GeneratedProtocolMessageType('NodeUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEUPDATEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeUpdateRequest)
  })
_sym_db.RegisterMessage(NodeUpdateRequest)

NodeUpdateResponse = _reflection.GeneratedProtocolMessageType('NodeUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEUPDATERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeUpdateResponse)
  })
_sym_db.RegisterMessage(NodeUpdateResponse)

NodeDeleteRequest = _reflection.GeneratedProtocolMessageType('NodeDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODEDELETEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDeleteRequest)
  })
_sym_db.RegisterMessage(NodeDeleteRequest)

NodeDeleteResponse = _reflection.GeneratedProtocolMessageType('NodeDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODEDELETERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDeleteResponse)
  })
_sym_db.RegisterMessage(NodeDeleteResponse)

NodeListRequest = _reflection.GeneratedProtocolMessageType('NodeListRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODELISTREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeListRequest)
  })
_sym_db.RegisterMessage(NodeListRequest)

NodeListResponse = _reflection.GeneratedProtocolMessageType('NodeListResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODELISTRESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeListResponse)
  })
_sym_db.RegisterMessage(NodeListResponse)

NodeTCPProbeRequest = _reflection.GeneratedProtocolMessageType('NodeTCPProbeRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODETCPPROBEREQUEST,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeTCPProbeRequest)
  })
_sym_db.RegisterMessage(NodeTCPProbeRequest)

NodeTCPProbeResponse = _reflection.GeneratedProtocolMessageType('NodeTCPProbeResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODETCPPROBERESPONSE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeTCPProbeResponse)
  })
_sym_db.RegisterMessage(NodeTCPProbeResponse)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.Node)
  })
_sym_db.RegisterMessage(Node)

Relay = _reflection.GeneratedProtocolMessageType('Relay', (_message.Message,), {
  'DESCRIPTOR' : _RELAY,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.Relay)
  })
_sym_db.RegisterMessage(Relay)

Gateway = _reflection.GeneratedProtocolMessageType('Gateway', (_message.Message,), {
  'DESCRIPTOR' : _GATEWAY,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.Gateway)
  })
_sym_db.RegisterMessage(Gateway)

ProxyCluster = _reflection.GeneratedProtocolMessageType('ProxyCluster', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTER,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyCluster)
  })
_sym_db.RegisterMessage(ProxyCluster)

NodeMaintenanceWindow = _reflection.GeneratedProtocolMessageType('NodeMaintenanceWindow', (_message.Message,), {
  'DESCRIPTOR' : _NODEMAINTENANCEWINDOW,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeMaintenanceWindow)
  })
_sym_db.RegisterMessage(NodeMaintenanceWindow)

NodeDiscoveryConfig = _reflection.GeneratedProtocolMessageType('NodeDiscoveryConfig', (_message.Message,), {
  'DESCRIPTOR' : _NODEDISCOVERYCONFIG,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDiscoveryConfig)
  })
_sym_db.RegisterMessage(NodeDiscoveryConfig)

NodeDiscoveryTypeConfig = _reflection.GeneratedProtocolMessageType('NodeDiscoveryTypeConfig', (_message.Message,), {
  'DESCRIPTOR' : _NODEDISCOVERYTYPECONFIG,
  '__module__' : 'nodes_pb2'
  # @@protoc_insertion_point(class_scope:v1.NodeDiscoveryTypeConfig)
  })
_sym_db.RegisterMessage(NodeDiscoveryTypeConfig)

_NODES = DESCRIPTOR.services_by_name['Nodes']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\rNodesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _NODECREATEREQUEST.fields_by_name['node']._options = None
  _NODECREATEREQUEST.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['meta']._options = None
  _NODECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['node']._options = None
  _NODECREATERESPONSE.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['token']._options = None
  _NODECREATERESPONSE.fields_by_name['token']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\360\363\263\007\001'
  _NODECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _NODECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODECREATERESPONSE._options = None
  _NODECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEGETREQUEST.fields_by_name['id']._options = None
  _NODEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEGETRESPONSE.fields_by_name['meta']._options = None
  _NODEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEGETRESPONSE.fields_by_name['node']._options = None
  _NODEGETRESPONSE.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _NODEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODEGETRESPONSE._options = None
  _NODEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEUPDATEREQUEST.fields_by_name['node']._options = None
  _NODEUPDATEREQUEST.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEUPDATERESPONSE.fields_by_name['meta']._options = None
  _NODEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEUPDATERESPONSE.fields_by_name['node']._options = None
  _NODEUPDATERESPONSE.fields_by_name['node']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _NODEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODEUPDATERESPONSE._options = None
  _NODEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEDELETEREQUEST.fields_by_name['id']._options = None
  _NODEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDELETERESPONSE.fields_by_name['meta']._options = None
  _NODEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _NODEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODEDELETERESPONSE._options = None
  _NODEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODELISTREQUEST.fields_by_name['filter']._options = None
  _NODELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODELISTRESPONSE.fields_by_name['nodes']._options = None
  _NODELISTRESPONSE.fields_by_name['nodes']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _NODELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _NODELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODETCPPROBEREQUEST.fields_by_name['node_id']._options = None
  _NODETCPPROBEREQUEST.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBEREQUEST.fields_by_name['host']._options = None
  _NODETCPPROBEREQUEST.fields_by_name['host']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBEREQUEST.fields_by_name['port']._options = None
  _NODETCPPROBEREQUEST.fields_by_name['port']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['meta']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['succeeded']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['succeeded']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['error']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['error']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODETCPPROBERESPONSE.fields_by_name['rate_limit']._options = None
  _NODETCPPROBERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _NODETCPPROBERESPONSE._options = None
  _NODETCPPROBERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODE.oneofs_by_name['node']._options = None
  _NODE.oneofs_by_name['node']._serialized_options = b'\252\370\263\007\t\252\370\263\007\004tags\252\370\263\007\t\252\370\263\007\004name'
  _NODE.fields_by_name['relay']._options = None
  _NODE.fields_by_name['relay']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODE.fields_by_name['gateway']._options = None
  _NODE.fields_by_name['gateway']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODE.fields_by_name['proxy_cluster']._options = None
  _NODE.fields_by_name['proxy_cluster']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODE._options = None
  _NODE._serialized_options = b'\372\370\263\007L\302\363\263\007G\242\363\263\007\035tf_examples/node_resource.txt\252\363\263\007 tf_examples/node_data_source.txt\372\370\263\007\005\250\363\263\007\001'
  _RELAY.fields_by_name['id']._options = None
  _RELAY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RELAY.fields_by_name['name']._options = None
  _RELAY.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _RELAY.fields_by_name['state']._options = None
  _RELAY.fields_by_name['state']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _RELAY.fields_by_name['tags']._options = None
  _RELAY.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RELAY.fields_by_name['gateway_filter']._options = None
  _RELAY.fields_by_name['gateway_filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RELAY.fields_by_name['device']._options = None
  _RELAY.fields_by_name['device']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _RELAY.fields_by_name['location']._options = None
  _RELAY.fields_by_name['location']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _RELAY.fields_by_name['version']._options = None
  _RELAY.fields_by_name['version']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _RELAY.fields_by_name['uuid']._options = None
  _RELAY.fields_by_name['uuid']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private'
  _RELAY.fields_by_name['maintenance_windows']._options = None
  _RELAY.fields_by_name['maintenance_windows']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\022terraform-provider\022\022maintenance_window'
  _RELAY.fields_by_name['discovery_config']._options = None
  _RELAY.fields_by_name['discovery_config']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _RELAY._options = None
  _RELAY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _GATEWAY.fields_by_name['id']._options = None
  _GATEWAY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GATEWAY.fields_by_name['name']._options = None
  _GATEWAY.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _GATEWAY.fields_by_name['state']._options = None
  _GATEWAY.fields_by_name['state']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _GATEWAY.fields_by_name['listen_address']._options = None
  _GATEWAY.fields_by_name['listen_address']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\300\363\263\007\001\340\363\263\007\001'
  _GATEWAY.fields_by_name['bind_address']._options = None
  _GATEWAY.fields_by_name['bind_address']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\340\363\263\007\001\320\364\263\007\001'
  _GATEWAY.fields_by_name['tags']._options = None
  _GATEWAY.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GATEWAY.fields_by_name['gateway_filter']._options = None
  _GATEWAY.fields_by_name['gateway_filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GATEWAY.fields_by_name['device']._options = None
  _GATEWAY.fields_by_name['device']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GATEWAY.fields_by_name['location']._options = None
  _GATEWAY.fields_by_name['location']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GATEWAY.fields_by_name['version']._options = None
  _GATEWAY.fields_by_name['version']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GATEWAY.fields_by_name['uuid']._options = None
  _GATEWAY.fields_by_name['uuid']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private'
  _GATEWAY.fields_by_name['maintenance_windows']._options = None
  _GATEWAY.fields_by_name['maintenance_windows']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\022terraform-provider\022\022maintenance_window'
  _GATEWAY.fields_by_name['discovery_config']._options = None
  _GATEWAY.fields_by_name['discovery_config']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _GATEWAY._options = None
  _GATEWAY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['id']._options = None
  _PROXYCLUSTER.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['name']._options = None
  _PROXYCLUSTER.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PROXYCLUSTER.fields_by_name['address']._options = None
  _PROXYCLUSTER.fields_by_name['address']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['tags']._options = None
  _PROXYCLUSTER.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTER.fields_by_name['maintenance_windows']._options = None
  _PROXYCLUSTER.fields_by_name['maintenance_windows']._serialized_options = b'\362\370\263\0077\260\363\263\007\001\312\363\263\007-\302\364\263\007(\n\022terraform-provider\022\022maintenance_window'
  _PROXYCLUSTER.fields_by_name['discovery_config']._options = None
  _PROXYCLUSTER.fields_by_name['discovery_config']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _PROXYCLUSTER._options = None
  _PROXYCLUSTER._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _NODEMAINTENANCEWINDOW.fields_by_name['cron_schedule']._options = None
  _NODEMAINTENANCEWINDOW.fields_by_name['cron_schedule']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEMAINTENANCEWINDOW.fields_by_name['require_idleness']._options = None
  _NODEMAINTENANCEWINDOW.fields_by_name['require_idleness']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEMAINTENANCEWINDOW._options = None
  _NODEMAINTENANCEWINDOW._serialized_options = b'\372\370\263\007O\250\363\263\007\001\312\363\263\007E\362\363\263\007\036\n\022terraform-provider\022\010TypeList\372\363\263\007\035nodeMaintenanceWindowElemType'
  _NODEDISCOVERYCONFIG.fields_by_name['enabled']._options = None
  _NODEDISCOVERYCONFIG.fields_by_name['enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYCONFIG.fields_by_name['period']._options = None
  _NODEDISCOVERYCONFIG.fields_by_name['period']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYCONFIG.fields_by_name['enabledTypes']._options = None
  _NODEDISCOVERYCONFIG.fields_by_name['enabledTypes']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYCONFIG._options = None
  _NODEDISCOVERYCONFIG._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _NODEDISCOVERYTYPECONFIG.fields_by_name['type']._options = None
  _NODEDISCOVERYTYPECONFIG.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _NODEDISCOVERYTYPECONFIG._options = None
  _NODEDISCOVERYTYPECONFIG._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _NODES._options = None
  _NODES._serialized_options = b'\312\371\263\007\t\302\371\263\007\004Node\312\371\263\007\007\322\371\263\007\002n-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli'
  _NODES.methods_by_name['Create']._options = None
  _NODES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\016\252\363\263\007\t/v1/nodes'
  _NODES.methods_by_name['Get']._options = None
  _NODES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\023\252\363\263\007\016/v1/nodes/{id}'
  _NODES.methods_by_name['Update']._options = None
  _NODES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\023\252\363\263\007\016/v1/nodes/{id}'
  _NODES.methods_by_name['Delete']._options = None
  _NODES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\023\252\363\263\007\016/v1/nodes/{id}'
  _NODES.methods_by_name['List']._options = None
  _NODES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\016\252\363\263\007\t/v1/nodes'
  _NODES.methods_by_name['TCPProbe']._options = None
  _NODES.methods_by_name['TCPProbe']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\030\252\363\263\007\023/v1/nodes/tcp-probe\202\371\263\007\032\312\363\263\007\025\302\364\263\007\020\n\004java\022\010tcpProbe'
  _NODECREATEREQUEST._serialized_start=90
  _NODECREATEREQUEST._serialized_end=186
  _NODECREATERESPONSE._serialized_start=189
  _NODECREATERESPONSE._serialized_end=432
  _NODEGETREQUEST._serialized_start=434
  _NODEGETREQUEST._serialized_end=512
  _NODEGETRESPONSE._serialized_start=515
  _NODEGETRESPONSE._serialized_end=720
  _NODEUPDATEREQUEST._serialized_start=722
  _NODEUPDATEREQUEST._serialized_end=830
  _NODEUPDATERESPONSE._serialized_start=833
  _NODEUPDATERESPONSE._serialized_end=1044
  _NODEDELETEREQUEST._serialized_start=1046
  _NODEDELETEREQUEST._serialized_end=1130
  _NODEDELETERESPONSE._serialized_start=1133
  _NODEDELETERESPONSE._serialized_end=1308
  _NODELISTREQUEST._serialized_start=1310
  _NODELISTREQUEST._serialized_end=1394
  _NODELISTRESPONSE._serialized_start=1397
  _NODELISTRESPONSE._serialized_end=1581
  _NODETCPPROBEREQUEST._serialized_start=1584
  _NODETCPPROBEREQUEST._serialized_end=1727
  _NODETCPPROBERESPONSE._serialized_start=1730
  _NODETCPPROBERESPONSE._serialized_end=1965
  _NODE._serialized_start=1968
  _NODE._serialized_end=2244
  _RELAY._serialized_start=2247
  _RELAY._serialized_end=2799
  _GATEWAY._serialized_start=2802
  _GATEWAY._serialized_end=3446
  _PROXYCLUSTER._serialized_start=3449
  _PROXYCLUSTER._serialized_end=3796
  _NODEMAINTENANCEWINDOW._serialized_start=3799
  _NODEMAINTENANCEWINDOW._serialized_end=3981
  _NODEDISCOVERYCONFIG._serialized_start=3984
  _NODEDISCOVERYCONFIG._serialized_end=4179
  _NODEDISCOVERYTYPECONFIG._serialized_start=4181
  _NODEDISCOVERYTYPECONFIG._serialized_end=4259
  _NODES._serialized_start=4262
  _NODES._serialized_end=4921
# @@protoc_insertion_point(module_scope)
