# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: remote_identities.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17remote_identities.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x7f\n\x1bRemoteIdentityCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf2\x01\n\x1cRemoteIdentityCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x18RemoteIdentityGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x19RemoteIdentityGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x8b\x01\n\x1bRemoteIdentityUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x37\n\x0fremote_identity\x18\x03 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf2\x01\n\x1cRemoteIdentityUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x0fremote_identity\x18\x02 \x01(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x1bRemoteIdentityDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb9\x01\n\x1cRemoteIdentityDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x19RemoteIdentityListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd8\x01\n\x1aRemoteIdentityListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x39\n\x11remote_identities\x18\x02 \x03(\x0b\x32\x12.v1.RemoteIdentityB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x91\x02\n\x0eRemoteIdentity\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x31\n\x18remote_identity_group_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x08username\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:l\xfa\xf8\xb3\x07g\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07]\xa2\xf3\xb3\x07(tf_examples/remote_identity_resource.txt\xaa\xf3\xb3\x07+tf_examples/remote_identity_data_source.txt2\xa7\x05\n\x10RemoteIdentities\x12z\n\x06\x43reate\x12\x1f.v1.RemoteIdentityCreateRequest\x1a .v1.RemoteIdentityCreateResponse\"-\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/remote-identities\x12u\n\x03Get\x12\x1c.v1.RemoteIdentityGetRequest\x1a\x1d.v1.RemoteIdentityGetResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identities/{id}\x12~\n\x06Update\x12\x1f.v1.RemoteIdentityUpdateRequest\x1a .v1.RemoteIdentityUpdateResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identities/{id}\x12\x81\x01\n\x06\x44\x65lete\x12\x1f.v1.RemoteIdentityDeleteRequest\x1a .v1.RemoteIdentityDeleteResponse\"4\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/remote-identities/{id}\x12s\n\x04List\x12\x1d.v1.RemoteIdentityListRequest\x1a\x1e.v1.RemoteIdentityListResponse\",\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/remote-identities\x1a\'\x88\x02\x01\xca\xf9\xb3\x07\x13\xc2\xf9\xb3\x07\x0eRemoteIdentity\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02i-Bl\n\x19\x63om.strongdm.api.plumbingB\x18RemoteIdentitiesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_REMOTEIDENTITYCREATEREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityCreateRequest']
_REMOTEIDENTITYCREATERESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityCreateResponse']
_REMOTEIDENTITYGETREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityGetRequest']
_REMOTEIDENTITYGETRESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityGetResponse']
_REMOTEIDENTITYUPDATEREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityUpdateRequest']
_REMOTEIDENTITYUPDATERESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityUpdateResponse']
_REMOTEIDENTITYDELETEREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityDeleteRequest']
_REMOTEIDENTITYDELETERESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityDeleteResponse']
_REMOTEIDENTITYLISTREQUEST = DESCRIPTOR.message_types_by_name['RemoteIdentityListRequest']
_REMOTEIDENTITYLISTRESPONSE = DESCRIPTOR.message_types_by_name['RemoteIdentityListResponse']
_REMOTEIDENTITY = DESCRIPTOR.message_types_by_name['RemoteIdentity']
RemoteIdentityCreateRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYCREATEREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityCreateRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityCreateRequest)

RemoteIdentityCreateResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYCREATERESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityCreateResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityCreateResponse)

RemoteIdentityGetRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGETREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGetRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityGetRequest)

RemoteIdentityGetResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYGETRESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityGetResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityGetResponse)

RemoteIdentityUpdateRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYUPDATEREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityUpdateRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityUpdateRequest)

RemoteIdentityUpdateResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYUPDATERESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityUpdateResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityUpdateResponse)

RemoteIdentityDeleteRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYDELETEREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityDeleteRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityDeleteRequest)

RemoteIdentityDeleteResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYDELETERESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityDeleteResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityDeleteResponse)

RemoteIdentityListRequest = _reflection.GeneratedProtocolMessageType('RemoteIdentityListRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYLISTREQUEST,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityListRequest)
  })
_sym_db.RegisterMessage(RemoteIdentityListRequest)

RemoteIdentityListResponse = _reflection.GeneratedProtocolMessageType('RemoteIdentityListResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITYLISTRESPONSE,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentityListResponse)
  })
_sym_db.RegisterMessage(RemoteIdentityListResponse)

RemoteIdentity = _reflection.GeneratedProtocolMessageType('RemoteIdentity', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEIDENTITY,
  '__module__' : 'remote_identities_pb2'
  # @@protoc_insertion_point(class_scope:v1.RemoteIdentity)
  })
_sym_db.RegisterMessage(RemoteIdentity)

_REMOTEIDENTITIES = DESCRIPTOR.services_by_name['RemoteIdentities']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\030RemoteIdentitiesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _REMOTEIDENTITYCREATEREQUEST.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYCREATEREQUEST.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYCREATERESPONSE._options = None
  _REMOTEIDENTITYCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYGETREQUEST.fields_by_name['id']._options = None
  _REMOTEIDENTITYGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYGETRESPONSE._options = None
  _REMOTEIDENTITYGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYUPDATEREQUEST.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYUPDATEREQUEST.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['remote_identity']._options = None
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['remote_identity']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYUPDATERESPONSE._options = None
  _REMOTEIDENTITYUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYDELETEREQUEST.fields_by_name['id']._options = None
  _REMOTEIDENTITYDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['meta']._options = None
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITYDELETERESPONSE._options = None
  _REMOTEIDENTITYDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _REMOTEIDENTITYLISTREQUEST.fields_by_name['filter']._options = None
  _REMOTEIDENTITYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['remote_identities']._options = None
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['remote_identities']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _REMOTEIDENTITYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REMOTEIDENTITY.fields_by_name['id']._options = None
  _REMOTEIDENTITY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REMOTEIDENTITY.fields_by_name['account_id']._options = None
  _REMOTEIDENTITY.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITY.fields_by_name['remote_identity_group_id']._options = None
  _REMOTEIDENTITY.fields_by_name['remote_identity_group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITY.fields_by_name['username']._options = None
  _REMOTEIDENTITY.fields_by_name['username']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REMOTEIDENTITY._options = None
  _REMOTEIDENTITY._serialized_options = b'\372\370\263\007g\250\363\263\007\001\302\363\263\007]\242\363\263\007(tf_examples/remote_identity_resource.txt\252\363\263\007+tf_examples/remote_identity_data_source.txt'
  _REMOTEIDENTITIES._options = None
  _REMOTEIDENTITIES._serialized_options = b'\210\002\001\312\371\263\007\023\302\371\263\007\016RemoteIdentity\312\371\263\007\007\322\371\263\007\002i-'
  _REMOTEIDENTITIES.methods_by_name['Create']._options = None
  _REMOTEIDENTITIES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\032\252\363\263\007\025/v1/remote-identities'
  _REMOTEIDENTITIES.methods_by_name['Get']._options = None
  _REMOTEIDENTITIES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\037\252\363\263\007\032/v1/remote-identities/{id}'
  _REMOTEIDENTITIES.methods_by_name['Update']._options = None
  _REMOTEIDENTITIES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\037\252\363\263\007\032/v1/remote-identities/{id}'
  _REMOTEIDENTITIES.methods_by_name['Delete']._options = None
  _REMOTEIDENTITIES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\037\252\363\263\007\032/v1/remote-identities/{id}'
  _REMOTEIDENTITIES.methods_by_name['List']._options = None
  _REMOTEIDENTITIES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\032\252\363\263\007\025/v1/remote-identities'
  _REMOTEIDENTITYCREATEREQUEST._serialized_start=58
  _REMOTEIDENTITYCREATEREQUEST._serialized_end=185
  _REMOTEIDENTITYCREATERESPONSE._serialized_start=188
  _REMOTEIDENTITYCREATERESPONSE._serialized_end=430
  _REMOTEIDENTITYGETREQUEST._serialized_start=432
  _REMOTEIDENTITYGETREQUEST._serialized_end=520
  _REMOTEIDENTITYGETRESPONSE._serialized_start=523
  _REMOTEIDENTITYGETRESPONSE._serialized_end=759
  _REMOTEIDENTITYUPDATEREQUEST._serialized_start=762
  _REMOTEIDENTITYUPDATEREQUEST._serialized_end=901
  _REMOTEIDENTITYUPDATERESPONSE._serialized_start=904
  _REMOTEIDENTITYUPDATERESPONSE._serialized_end=1146
  _REMOTEIDENTITYDELETEREQUEST._serialized_start=1148
  _REMOTEIDENTITYDELETEREQUEST._serialized_end=1242
  _REMOTEIDENTITYDELETERESPONSE._serialized_start=1245
  _REMOTEIDENTITYDELETERESPONSE._serialized_end=1430
  _REMOTEIDENTITYLISTREQUEST._serialized_start=1432
  _REMOTEIDENTITYLISTREQUEST._serialized_end=1526
  _REMOTEIDENTITYLISTRESPONSE._serialized_start=1529
  _REMOTEIDENTITYLISTRESPONSE._serialized_end=1745
  _REMOTEIDENTITY._serialized_start=1748
  _REMOTEIDENTITY._serialized_end=2021
  _REMOTEIDENTITIES._serialized_start=2024
  _REMOTEIDENTITIES._serialized_end=2703
# @@protoc_insertion_point(module_scope)
