# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discovery_connectors.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x64iscovery_connectors.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"\x89\x01\n\x16\x43onnectorCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12,\n\tconnector\x18\x02 \x01(\x0b\x32\r.v1.ConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc2\x01\n\x17\x43onnectorCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12,\n\tconnector\x18\x02 \x01(\x0b\x32\r.v1.ConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"m\n\x13\x43onnectorGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc8\x01\n\x14\x43onnectorGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12,\n\tconnector\x18\x02 \x01(\x0b\x32\r.v1.ConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x95\x01\n\x16\x43onnectorUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12,\n\tconnector\x18\x03 \x01(\x0b\x32\r.v1.ConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc2\x01\n\x17\x43onnectorUpdateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12,\n\tconnector\x18\x02 \x01(\x0b\x32\r.v1.ConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"s\n\x16\x43onnectorDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xa0\x01\n\x17\x43onnectorDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"s\n\x14\x43onnectorListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xbf\x01\n\x15\x43onnectorListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12-\n\nconnectors\x18\x02 \x03(\x0b\x32\r.v1.ConnectorB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc2\x02\n\tConnector\x12+\n\x03\x61ws\x18\x64 \x01(\x0b\x32\x10.v1.AWSConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12/\n\x05\x61zure\x18\x65 \x01(\x0b\x32\x12.v1.AzureConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12+\n\x03gcp\x18\x66 \x01(\x0b\x32\x10.v1.GCPConnectorB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63liB\x8f\x01\n\x05\x63loud\x12\x85\x01\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\xaa\xf8\xb3\x07\x10\xaa\xf8\xb3\x07\x0b\x64\x65scription\xaa\xf8\xb3\x07\r\xaa\xf8\xb3\x07\x08services\xaa\xf8\xb3\x07\x11\xaa\xf8\xb3\x07\x0cinclude_tags\xaa\xf8\xb3\x07\x11\xaa\xf8\xb3\x07\x0c\x65xclude_tags\xaa\xf8\xb3\x07\x10\xaa\xf8\xb3\x07\x0bscan_period\xaa\xf8\xb3\x07\n\xb2\xf8\xb3\x07\x05\x63loud\"\xa4\x03\n\x0c\x41WSConnector\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bscan_period\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08services\x18\x05 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0cinclude_tags\x18\x06 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0c\x65xclude_tags\x18\x07 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\'\n\trole_name\x18\x14 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12)\n\x0b\x61\x63\x63ount_ids\x18\x15 \x03(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01:S\xfa\xf8\xb3\x07N\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x36\xc2\xf4\xb3\x07\x19\n\x12terraform-provider\x12\x03\x61ws\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03\x61ws\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xd8\x03\n\x0e\x41zureConnector\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bscan_period\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08services\x18\x05 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0cinclude_tags\x18\x06 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0c\x65xclude_tags\x18\x07 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\'\n\ttenant_id\x18\x14 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12\'\n\tclient_id\x18\x15 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12.\n\x10subscription_ids\x18\x16 \x03(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01:W\xfa\xf8\xb3\x07R\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07:\xc2\xf4\xb3\x07\x1b\n\x12terraform-provider\x12\x05\x61zure\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05\x61zure\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc9\x04\n\x0cGCPConnector\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bscan_period\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08services\x18\x05 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0cinclude_tags\x18\x06 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0c\x65xclude_tags\x18\x07 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x0bproject_ids\x18\x17 \x03(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12\x35\n\x17workload_project_number\x18\x18 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12\x31\n\x13workload_project_id\x18\x19 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12\x32\n\x14workload_provider_id\x18\x1a \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01\x12.\n\x10workload_pool_id\x18\x1b \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x05\x88\xf4\xb3\x07\x01:S\xfa\xf8\xb3\x07N\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x36\xc2\xf4\xb3\x07\x19\n\x12terraform-provider\x12\x03gcp\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03gcp\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\xd7\x04\n\x13\x44iscoveryConnectors\x12i\n\x06\x43reate\x12\x1a.v1.ConnectorCreateRequest\x1a\x1b.v1.ConnectorCreateResponse\"&\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/connectors\x12\x64\n\x03Get\x12\x17.v1.ConnectorGetRequest\x1a\x18.v1.ConnectorGetResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/connectors/{id}\x12m\n\x06Update\x12\x1a.v1.ConnectorUpdateRequest\x1a\x1b.v1.ConnectorUpdateResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/connectors/{id}\x12p\n\x06\x44\x65lete\x12\x1a.v1.ConnectorDeleteRequest\x1a\x1b.v1.ConnectorDeleteResponse\"-\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/connectors/{id}\x12\x62\n\x04List\x12\x18.v1.ConnectorListRequest\x1a\x19.v1.ConnectorListResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/connectors\x1a*\xca\xf9\xb3\x07%\xc2\xf9\xb3\x07\tConnector\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\x04\x63on-B\x87\x01\n\x19\x63om.strongdm.api.plumbingB\x1b\x44iscoveryConnectorsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_CONNECTORCREATEREQUEST = DESCRIPTOR.message_types_by_name['ConnectorCreateRequest']
_CONNECTORCREATERESPONSE = DESCRIPTOR.message_types_by_name['ConnectorCreateResponse']
_CONNECTORGETREQUEST = DESCRIPTOR.message_types_by_name['ConnectorGetRequest']
_CONNECTORGETRESPONSE = DESCRIPTOR.message_types_by_name['ConnectorGetResponse']
_CONNECTORUPDATEREQUEST = DESCRIPTOR.message_types_by_name['ConnectorUpdateRequest']
_CONNECTORUPDATERESPONSE = DESCRIPTOR.message_types_by_name['ConnectorUpdateResponse']
_CONNECTORDELETEREQUEST = DESCRIPTOR.message_types_by_name['ConnectorDeleteRequest']
_CONNECTORDELETERESPONSE = DESCRIPTOR.message_types_by_name['ConnectorDeleteResponse']
_CONNECTORLISTREQUEST = DESCRIPTOR.message_types_by_name['ConnectorListRequest']
_CONNECTORLISTRESPONSE = DESCRIPTOR.message_types_by_name['ConnectorListResponse']
_CONNECTOR = DESCRIPTOR.message_types_by_name['Connector']
_AWSCONNECTOR = DESCRIPTOR.message_types_by_name['AWSConnector']
_AZURECONNECTOR = DESCRIPTOR.message_types_by_name['AzureConnector']
_GCPCONNECTOR = DESCRIPTOR.message_types_by_name['GCPConnector']
ConnectorCreateRequest = _reflection.GeneratedProtocolMessageType('ConnectorCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORCREATEREQUEST,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorCreateRequest)
  })
_sym_db.RegisterMessage(ConnectorCreateRequest)

ConnectorCreateResponse = _reflection.GeneratedProtocolMessageType('ConnectorCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORCREATERESPONSE,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorCreateResponse)
  })
_sym_db.RegisterMessage(ConnectorCreateResponse)

ConnectorGetRequest = _reflection.GeneratedProtocolMessageType('ConnectorGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORGETREQUEST,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorGetRequest)
  })
_sym_db.RegisterMessage(ConnectorGetRequest)

ConnectorGetResponse = _reflection.GeneratedProtocolMessageType('ConnectorGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORGETRESPONSE,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorGetResponse)
  })
_sym_db.RegisterMessage(ConnectorGetResponse)

ConnectorUpdateRequest = _reflection.GeneratedProtocolMessageType('ConnectorUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORUPDATEREQUEST,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorUpdateRequest)
  })
_sym_db.RegisterMessage(ConnectorUpdateRequest)

ConnectorUpdateResponse = _reflection.GeneratedProtocolMessageType('ConnectorUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORUPDATERESPONSE,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorUpdateResponse)
  })
_sym_db.RegisterMessage(ConnectorUpdateResponse)

ConnectorDeleteRequest = _reflection.GeneratedProtocolMessageType('ConnectorDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORDELETEREQUEST,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorDeleteRequest)
  })
_sym_db.RegisterMessage(ConnectorDeleteRequest)

ConnectorDeleteResponse = _reflection.GeneratedProtocolMessageType('ConnectorDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORDELETERESPONSE,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorDeleteResponse)
  })
_sym_db.RegisterMessage(ConnectorDeleteResponse)

ConnectorListRequest = _reflection.GeneratedProtocolMessageType('ConnectorListRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORLISTREQUEST,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorListRequest)
  })
_sym_db.RegisterMessage(ConnectorListRequest)

ConnectorListResponse = _reflection.GeneratedProtocolMessageType('ConnectorListResponse', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORLISTRESPONSE,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.ConnectorListResponse)
  })
_sym_db.RegisterMessage(ConnectorListResponse)

Connector = _reflection.GeneratedProtocolMessageType('Connector', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTOR,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.Connector)
  })
_sym_db.RegisterMessage(Connector)

AWSConnector = _reflection.GeneratedProtocolMessageType('AWSConnector', (_message.Message,), {
  'DESCRIPTOR' : _AWSCONNECTOR,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.AWSConnector)
  })
_sym_db.RegisterMessage(AWSConnector)

AzureConnector = _reflection.GeneratedProtocolMessageType('AzureConnector', (_message.Message,), {
  'DESCRIPTOR' : _AZURECONNECTOR,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.AzureConnector)
  })
_sym_db.RegisterMessage(AzureConnector)

GCPConnector = _reflection.GeneratedProtocolMessageType('GCPConnector', (_message.Message,), {
  'DESCRIPTOR' : _GCPCONNECTOR,
  '__module__' : 'discovery_connectors_pb2'
  # @@protoc_insertion_point(class_scope:v1.GCPConnector)
  })
_sym_db.RegisterMessage(GCPConnector)

_DISCOVERYCONNECTORS = DESCRIPTOR.services_by_name['DiscoveryConnectors']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\033DiscoveryConnectorsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _CONNECTORCREATEREQUEST.fields_by_name['connector']._options = None
  _CONNECTORCREATEREQUEST.fields_by_name['connector']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORCREATEREQUEST._options = None
  _CONNECTORCREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORCREATERESPONSE.fields_by_name['connector']._options = None
  _CONNECTORCREATERESPONSE.fields_by_name['connector']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _CONNECTORCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORCREATERESPONSE._options = None
  _CONNECTORCREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORGETREQUEST.fields_by_name['id']._options = None
  _CONNECTORGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORGETREQUEST._options = None
  _CONNECTORGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORGETRESPONSE.fields_by_name['meta']._options = None
  _CONNECTORGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORGETRESPONSE.fields_by_name['connector']._options = None
  _CONNECTORGETRESPONSE.fields_by_name['connector']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORGETRESPONSE.fields_by_name['rate_limit']._options = None
  _CONNECTORGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORGETRESPONSE._options = None
  _CONNECTORGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORUPDATEREQUEST.fields_by_name['connector']._options = None
  _CONNECTORUPDATEREQUEST.fields_by_name['connector']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORUPDATEREQUEST._options = None
  _CONNECTORUPDATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORUPDATERESPONSE.fields_by_name['connector']._options = None
  _CONNECTORUPDATERESPONSE.fields_by_name['connector']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _CONNECTORUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORUPDATERESPONSE._options = None
  _CONNECTORUPDATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORDELETEREQUEST.fields_by_name['id']._options = None
  _CONNECTORDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORDELETEREQUEST._options = None
  _CONNECTORDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORDELETERESPONSE.fields_by_name['meta']._options = None
  _CONNECTORDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _CONNECTORDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORDELETERESPONSE._options = None
  _CONNECTORDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORLISTREQUEST.fields_by_name['filter']._options = None
  _CONNECTORLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORLISTREQUEST._options = None
  _CONNECTORLISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTORLISTRESPONSE.fields_by_name['connectors']._options = None
  _CONNECTORLISTRESPONSE.fields_by_name['connectors']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _CONNECTORLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _CONNECTORLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTORLISTRESPONSE._options = None
  _CONNECTORLISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _CONNECTOR.oneofs_by_name['cloud']._options = None
  _CONNECTOR.oneofs_by_name['cloud']._serialized_options = b'\252\370\263\007\t\252\370\263\007\004name\252\370\263\007\020\252\370\263\007\013description\252\370\263\007\r\252\370\263\007\010services\252\370\263\007\021\252\370\263\007\014include_tags\252\370\263\007\021\252\370\263\007\014exclude_tags\252\370\263\007\020\252\370\263\007\013scan_period\252\370\263\007\n\262\370\263\007\005cloud'
  _CONNECTOR.fields_by_name['aws']._options = None
  _CONNECTOR.fields_by_name['aws']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTOR.fields_by_name['azure']._options = None
  _CONNECTOR.fields_by_name['azure']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTOR.fields_by_name['gcp']._options = None
  _CONNECTOR.fields_by_name['gcp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CONNECTOR._options = None
  _CONNECTOR._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _AWSCONNECTOR.fields_by_name['id']._options = None
  _AWSCONNECTOR.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['name']._options = None
  _AWSCONNECTOR.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['description']._options = None
  _AWSCONNECTOR.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['scan_period']._options = None
  _AWSCONNECTOR.fields_by_name['scan_period']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['services']._options = None
  _AWSCONNECTOR.fields_by_name['services']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['include_tags']._options = None
  _AWSCONNECTOR.fields_by_name['include_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['exclude_tags']._options = None
  _AWSCONNECTOR.fields_by_name['exclude_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AWSCONNECTOR.fields_by_name['role_name']._options = None
  _AWSCONNECTOR.fields_by_name['role_name']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _AWSCONNECTOR.fields_by_name['account_ids']._options = None
  _AWSCONNECTOR.fields_by_name['account_ids']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _AWSCONNECTOR._options = None
  _AWSCONNECTOR._serialized_options = b'\372\370\263\007N\250\363\263\007\001\312\363\263\0076\302\364\263\007\031\n\022terraform-provider\022\003aws\302\364\263\007\023\n\014json_gateway\022\003aws\322\363\263\007\001*\322\363\263\007\003cli'
  _AZURECONNECTOR.fields_by_name['id']._options = None
  _AZURECONNECTOR.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['name']._options = None
  _AZURECONNECTOR.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['description']._options = None
  _AZURECONNECTOR.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['scan_period']._options = None
  _AZURECONNECTOR.fields_by_name['scan_period']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['services']._options = None
  _AZURECONNECTOR.fields_by_name['services']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['include_tags']._options = None
  _AZURECONNECTOR.fields_by_name['include_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['exclude_tags']._options = None
  _AZURECONNECTOR.fields_by_name['exclude_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _AZURECONNECTOR.fields_by_name['tenant_id']._options = None
  _AZURECONNECTOR.fields_by_name['tenant_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _AZURECONNECTOR.fields_by_name['client_id']._options = None
  _AZURECONNECTOR.fields_by_name['client_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _AZURECONNECTOR.fields_by_name['subscription_ids']._options = None
  _AZURECONNECTOR.fields_by_name['subscription_ids']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _AZURECONNECTOR._options = None
  _AZURECONNECTOR._serialized_options = b'\372\370\263\007R\250\363\263\007\001\312\363\263\007:\302\364\263\007\033\n\022terraform-provider\022\005azure\302\364\263\007\025\n\014json_gateway\022\005azure\322\363\263\007\001*\322\363\263\007\003cli'
  _GCPCONNECTOR.fields_by_name['id']._options = None
  _GCPCONNECTOR.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['name']._options = None
  _GCPCONNECTOR.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['description']._options = None
  _GCPCONNECTOR.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['scan_period']._options = None
  _GCPCONNECTOR.fields_by_name['scan_period']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['services']._options = None
  _GCPCONNECTOR.fields_by_name['services']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['include_tags']._options = None
  _GCPCONNECTOR.fields_by_name['include_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['exclude_tags']._options = None
  _GCPCONNECTOR.fields_by_name['exclude_tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GCPCONNECTOR.fields_by_name['project_ids']._options = None
  _GCPCONNECTOR.fields_by_name['project_ids']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _GCPCONNECTOR.fields_by_name['workload_project_number']._options = None
  _GCPCONNECTOR.fields_by_name['workload_project_number']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _GCPCONNECTOR.fields_by_name['workload_project_id']._options = None
  _GCPCONNECTOR.fields_by_name['workload_project_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _GCPCONNECTOR.fields_by_name['workload_provider_id']._options = None
  _GCPCONNECTOR.fields_by_name['workload_provider_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _GCPCONNECTOR.fields_by_name['workload_pool_id']._options = None
  _GCPCONNECTOR.fields_by_name['workload_pool_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\312\363\263\007\005\210\364\263\007\001'
  _GCPCONNECTOR._options = None
  _GCPCONNECTOR._serialized_options = b'\372\370\263\007N\250\363\263\007\001\312\363\263\0076\302\364\263\007\031\n\022terraform-provider\022\003gcp\302\364\263\007\023\n\014json_gateway\022\003gcp\322\363\263\007\001*\322\363\263\007\003cli'
  _DISCOVERYCONNECTORS._options = None
  _DISCOVERYCONNECTORS._serialized_options = b'\312\371\263\007%\302\371\263\007\tConnector\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\004con-'
  _DISCOVERYCONNECTORS.methods_by_name['Create']._options = None
  _DISCOVERYCONNECTORS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\023\252\363\263\007\016/v1/connectors'
  _DISCOVERYCONNECTORS.methods_by_name['Get']._options = None
  _DISCOVERYCONNECTORS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/connectors/{id}'
  _DISCOVERYCONNECTORS.methods_by_name['Update']._options = None
  _DISCOVERYCONNECTORS.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\030\252\363\263\007\023/v1/connectors/{id}'
  _DISCOVERYCONNECTORS.methods_by_name['Delete']._options = None
  _DISCOVERYCONNECTORS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\030\252\363\263\007\023/v1/connectors/{id}'
  _DISCOVERYCONNECTORS.methods_by_name['List']._options = None
  _DISCOVERYCONNECTORS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\023\252\363\263\007\016/v1/connectors'
  _CONNECTORCREATEREQUEST._serialized_start=74
  _CONNECTORCREATEREQUEST._serialized_end=211
  _CONNECTORCREATERESPONSE._serialized_start=214
  _CONNECTORCREATERESPONSE._serialized_end=408
  _CONNECTORGETREQUEST._serialized_start=410
  _CONNECTORGETREQUEST._serialized_end=519
  _CONNECTORGETRESPONSE._serialized_start=522
  _CONNECTORGETRESPONSE._serialized_end=722
  _CONNECTORUPDATEREQUEST._serialized_start=725
  _CONNECTORUPDATEREQUEST._serialized_end=874
  _CONNECTORUPDATERESPONSE._serialized_start=877
  _CONNECTORUPDATERESPONSE._serialized_end=1071
  _CONNECTORDELETEREQUEST._serialized_start=1073
  _CONNECTORDELETEREQUEST._serialized_end=1188
  _CONNECTORDELETERESPONSE._serialized_start=1191
  _CONNECTORDELETERESPONSE._serialized_end=1351
  _CONNECTORLISTREQUEST._serialized_start=1353
  _CONNECTORLISTREQUEST._serialized_end=1468
  _CONNECTORLISTRESPONSE._serialized_start=1471
  _CONNECTORLISTRESPONSE._serialized_end=1662
  _CONNECTOR._serialized_start=1665
  _CONNECTOR._serialized_end=1987
  _AWSCONNECTOR._serialized_start=1990
  _AWSCONNECTOR._serialized_end=2410
  _AZURECONNECTOR._serialized_start=2413
  _AZURECONNECTOR._serialized_end=2885
  _GCPCONNECTOR._serialized_start=2888
  _GCPCONNECTOR._serialized_end=3473
  _DISCOVERYCONNECTORS._serialized_start=3476
  _DISCOVERYCONNECTORS._serialized_end=4075
# @@protoc_insertion_point(module_scope)
