# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peering_groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14peering_groups.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"y\n\x19PeeringGroupCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\rpeering_group\x18\x02 \x01(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x1aPeeringGroupCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rpeering_group\x18\x02 \x01(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x16PeeringGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe6\x01\n\x17PeeringGroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rpeering_group\x18\x02 \x01(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x19PeeringGroupDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb7\x01\n\x1aPeeringGroupDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\\\n\x17PeeringGroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd1\x01\n\x18PeeringGroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0epeering_groups\x18\x02 \x03(\x0b\x32\x10.v1.PeeringGroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"Q\n\x0cPeeringGroup\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xa1\x04\n\rPeeringGroups\x12r\n\x06\x43reate\x12\x1d.v1.PeeringGroupCreateRequest\x1a\x1e.v1.PeeringGroupCreateResponse\")\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/peeringGroups\x12y\n\x06\x44\x65lete\x12\x1d.v1.PeeringGroupDeleteRequest\x1a\x1e.v1.PeeringGroupDeleteResponse\"0\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/peeringGroups/{id}\x12m\n\x03Get\x12\x1a.v1.PeeringGroupGetRequest\x1a\x1b.v1.PeeringGroupGetResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/peeringGroups/{id}\x12k\n\x04List\x12\x1b.v1.PeeringGroupListRequest\x1a\x1c.v1.PeeringGroupListResponse\"(\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/peeringGroups\x1a\x45\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0cPeeringGroup\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02g-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cli\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15PeeringGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_PEERINGGROUPCREATEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupCreateRequest']
_PEERINGGROUPCREATERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupCreateResponse']
_PEERINGGROUPGETREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupGetRequest']
_PEERINGGROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupGetResponse']
_PEERINGGROUPDELETEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupDeleteRequest']
_PEERINGGROUPDELETERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupDeleteResponse']
_PEERINGGROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupListRequest']
_PEERINGGROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupListResponse']
_PEERINGGROUP = DESCRIPTOR.message_types_by_name['PeeringGroup']
PeeringGroupCreateRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPCREATEREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupCreateRequest)
  })
_sym_db.RegisterMessage(PeeringGroupCreateRequest)

PeeringGroupCreateResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPCREATERESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupCreateResponse)
  })
_sym_db.RegisterMessage(PeeringGroupCreateResponse)

PeeringGroupGetRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPGETREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupGetRequest)
  })
_sym_db.RegisterMessage(PeeringGroupGetRequest)

PeeringGroupGetResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPGETRESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupGetResponse)
  })
_sym_db.RegisterMessage(PeeringGroupGetResponse)

PeeringGroupDeleteRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPDELETEREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupDeleteRequest)
  })
_sym_db.RegisterMessage(PeeringGroupDeleteRequest)

PeeringGroupDeleteResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPDELETERESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupDeleteResponse)
  })
_sym_db.RegisterMessage(PeeringGroupDeleteResponse)

PeeringGroupListRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPLISTREQUEST,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupListRequest)
  })
_sym_db.RegisterMessage(PeeringGroupListRequest)

PeeringGroupListResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPLISTRESPONSE,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupListResponse)
  })
_sym_db.RegisterMessage(PeeringGroupListResponse)

PeeringGroup = _reflection.GeneratedProtocolMessageType('PeeringGroup', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUP,
  '__module__' : 'peering_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroup)
  })
_sym_db.RegisterMessage(PeeringGroup)

_PEERINGGROUPS = DESCRIPTOR.services_by_name['PeeringGroups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025PeeringGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _PEERINGGROUPCREATEREQUEST.fields_by_name['peering_group']._options = None
  _PEERINGGROUPCREATEREQUEST.fields_by_name['peering_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPCREATERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPCREATERESPONSE.fields_by_name['peering_group']._options = None
  _PEERINGGROUPCREATERESPONSE.fields_by_name['peering_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPCREATERESPONSE._options = None
  _PEERINGGROUPCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPGETREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPGETRESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPGETRESPONSE.fields_by_name['peering_group']._options = None
  _PEERINGGROUPGETRESPONSE.fields_by_name['peering_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPGETRESPONSE._options = None
  _PEERINGGROUPGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPDELETEREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPDELETERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPDELETERESPONSE._options = None
  _PEERINGGROUPDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPLISTREQUEST.fields_by_name['filter']._options = None
  _PEERINGGROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPLISTRESPONSE.fields_by_name['peering_groups']._options = None
  _PEERINGGROUPLISTRESPONSE.fields_by_name['peering_groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _PEERINGGROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUP.fields_by_name['id']._options = None
  _PEERINGGROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUP.fields_by_name['name']._options = None
  _PEERINGGROUP.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PEERINGGROUP._options = None
  _PEERINGGROUP._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPS._options = None
  _PEERINGGROUPS._serialized_options = b'\312\371\263\007\021\302\371\263\007\014PeeringGroup\312\371\263\007\007\322\371\263\007\002g-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli\312\371\263\007\005\330\371\263\007\001'
  _PEERINGGROUPS.methods_by_name['Create']._options = None
  _PEERINGGROUPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\026\252\363\263\007\021/v1/peeringGroups'
  _PEERINGGROUPS.methods_by_name['Delete']._options = None
  _PEERINGGROUPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\033\252\363\263\007\026/v1/peeringGroups/{id}'
  _PEERINGGROUPS.methods_by_name['Get']._options = None
  _PEERINGGROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/peeringGroups/{id}'
  _PEERINGGROUPS.methods_by_name['List']._options = None
  _PEERINGGROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\026\252\363\263\007\021/v1/peeringGroups'
  _PEERINGGROUPCREATEREQUEST._serialized_start=55
  _PEERINGGROUPCREATEREQUEST._serialized_end=176
  _PEERINGGROUPCREATERESPONSE._serialized_start=179
  _PEERINGGROUPCREATERESPONSE._serialized_end=415
  _PEERINGGROUPGETREQUEST._serialized_start=417
  _PEERINGGROUPGETREQUEST._serialized_end=503
  _PEERINGGROUPGETRESPONSE._serialized_start=506
  _PEERINGGROUPGETRESPONSE._serialized_end=736
  _PEERINGGROUPDELETEREQUEST._serialized_start=738
  _PEERINGGROUPDELETEREQUEST._serialized_end=830
  _PEERINGGROUPDELETERESPONSE._serialized_start=833
  _PEERINGGROUPDELETERESPONSE._serialized_end=1016
  _PEERINGGROUPLISTREQUEST._serialized_start=1018
  _PEERINGGROUPLISTREQUEST._serialized_end=1110
  _PEERINGGROUPLISTRESPONSE._serialized_start=1113
  _PEERINGGROUPLISTRESPONSE._serialized_end=1322
  _PEERINGGROUP._serialized_start=1324
  _PEERINGGROUP._serialized_end=1405
  _PEERINGGROUPS._serialized_start=1408
  _PEERINGGROUPS._serialized_end=1953
# @@protoc_insertion_point(module_scope)
