# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: access_requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61\x63\x63\x65ss_requests.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"i\n\x18\x41\x63\x63\x65ssRequestListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xc9\x01\n\x19\x41\x63\x63\x65ssRequestListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x36\n\x0f\x61\x63\x63\x65ss_requests\x18\x02 \x03(\x0b\x32\x11.v1.AccessRequestB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12@\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\x15\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x83\x05\n\rAccessRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06reason\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bworkflow_id\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\naccount_id\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12@\n\x0bvalid_until\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06status\x18\x08 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\tstatus_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08grant_id\x18\n \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\x08\x64uration\x18\x0b \x01(\x03\x42\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12@\n\x11requestedDuration\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\x0eresultDuration\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x31\n\x0erequester_name\x18\x0c \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xf9\x01\n\x12\x41\x63\x63\x65ssRequestEvent\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\nrequest_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08\x61\x63tor_id\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04type\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08metadata\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x43\n\x04time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xfc\x02\n\x13RequestableResource\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04name\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07healthy\x18\x03 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x18\n\x04type\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x0e\x61uthentication\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x06 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06\x61\x63\x63\x65ss\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\nprivileges\x18\x08 \x01(\x0b\x32\x15.v1.PrivilegesMessageB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12@\n\x1dprivileges_requirement_status\x18\t \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xdc\x01\n\x11PrivilegesMessage\x12\x38\n\nkubernetes\x18\x01 \x01(\x0b\x32\x18.v1.KubernetesPrivilegesB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\x0b\x65ntraGroups\x18\x02 \x01(\x0b\x32\x18.v1.EntraGroupPrivilegesB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\noktaGroups\x18\x03 \x01(\x0b\x32\x17.v1.OktaGroupPrivilegesB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"M\n\x14KubernetesPrivileges\x12\x1a\n\x06groups\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"M\n\x14\x45ntraGroupPrivileges\x12\x1a\n\x06groups\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"L\n\x13OktaGroupPrivileges\x12\x1a\n\x06groups\x18\x01 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private\"\xc3\x01\n\x13\x41\x63\x63\x65ssRequestConfig\x12$\n\x0bresource_id\x18\x01 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06reason\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08\x64uration\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"\xcb\x03\n\x1aRequestAccessRequestConfig\x12\'\n\x0cresource_ids\x18\x01 \x03(\tB\x11\x18\x01\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1a\n\x06reason\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nstart_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08\x64uration\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\xf2\x01\n\x0c\x61\x63\x63\x65ss_rules\x18\x05 \x01(\tB\xdb\x01\xf2\xf8\xb3\x07\xd5\x01\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\xa9\x01\xea\xf3\xb3\x07\x0c\x61\x63\x63\x65ss_rules\xf2\xf3\xb3\x07\x11\n\x02go\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x19\n\ngo_private\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x1b\n\x0cgo_terraform\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x18\n\x04java\x12\x10List<AccessRule>\xf2\xf3\xb3\x07\"\n\x0cjson_gateway\x12\x12models.AccessRules\xba\xf4\xb3\x07\x17\x61\x63\x63\x65ssRulesDiffSuppress\xd0\xf4\xb3\x07\x01:\x19\xfa\xf8\xb3\x07\x14\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\ngo_private2\xd9\x01\n\x0e\x41\x63\x63\x65ssRequests\x12o\n\x04List\x12\x1c.v1.AccessRequestListRequest\x1a\x1d.v1.AccessRequestListResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/access-requests\x1aV\xca\xf9\xb3\x07\x12\xc2\xf9\xb3\x07\rAccessRequest\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61q-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-provider\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x92\x01\n\x19\x63om.strongdm.api.plumbingB\x16\x41\x63\x63\x65ssRequestsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ACCESSREQUESTLISTREQUEST = DESCRIPTOR.message_types_by_name['AccessRequestListRequest']
_ACCESSREQUESTLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccessRequestListResponse']
_ACCESSREQUEST = DESCRIPTOR.message_types_by_name['AccessRequest']
_ACCESSREQUESTEVENT = DESCRIPTOR.message_types_by_name['AccessRequestEvent']
_REQUESTABLERESOURCE = DESCRIPTOR.message_types_by_name['RequestableResource']
_PRIVILEGESMESSAGE = DESCRIPTOR.message_types_by_name['PrivilegesMessage']
_KUBERNETESPRIVILEGES = DESCRIPTOR.message_types_by_name['KubernetesPrivileges']
_ENTRAGROUPPRIVILEGES = DESCRIPTOR.message_types_by_name['EntraGroupPrivileges']
_OKTAGROUPPRIVILEGES = DESCRIPTOR.message_types_by_name['OktaGroupPrivileges']
_ACCESSREQUESTCONFIG = DESCRIPTOR.message_types_by_name['AccessRequestConfig']
_REQUESTACCESSREQUESTCONFIG = DESCRIPTOR.message_types_by_name['RequestAccessRequestConfig']
AccessRequestListRequest = _reflection.GeneratedProtocolMessageType('AccessRequestListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTLISTREQUEST,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestListRequest)
  })
_sym_db.RegisterMessage(AccessRequestListRequest)

AccessRequestListResponse = _reflection.GeneratedProtocolMessageType('AccessRequestListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTLISTRESPONSE,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestListResponse)
  })
_sym_db.RegisterMessage(AccessRequestListResponse)

AccessRequest = _reflection.GeneratedProtocolMessageType('AccessRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUEST,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequest)
  })
_sym_db.RegisterMessage(AccessRequest)

AccessRequestEvent = _reflection.GeneratedProtocolMessageType('AccessRequestEvent', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENT,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEvent)
  })
_sym_db.RegisterMessage(AccessRequestEvent)

RequestableResource = _reflection.GeneratedProtocolMessageType('RequestableResource', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTABLERESOURCE,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.RequestableResource)
  })
_sym_db.RegisterMessage(RequestableResource)

PrivilegesMessage = _reflection.GeneratedProtocolMessageType('PrivilegesMessage', (_message.Message,), {
  'DESCRIPTOR' : _PRIVILEGESMESSAGE,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.PrivilegesMessage)
  })
_sym_db.RegisterMessage(PrivilegesMessage)

KubernetesPrivileges = _reflection.GeneratedProtocolMessageType('KubernetesPrivileges', (_message.Message,), {
  'DESCRIPTOR' : _KUBERNETESPRIVILEGES,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.KubernetesPrivileges)
  })
_sym_db.RegisterMessage(KubernetesPrivileges)

EntraGroupPrivileges = _reflection.GeneratedProtocolMessageType('EntraGroupPrivileges', (_message.Message,), {
  'DESCRIPTOR' : _ENTRAGROUPPRIVILEGES,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.EntraGroupPrivileges)
  })
_sym_db.RegisterMessage(EntraGroupPrivileges)

OktaGroupPrivileges = _reflection.GeneratedProtocolMessageType('OktaGroupPrivileges', (_message.Message,), {
  'DESCRIPTOR' : _OKTAGROUPPRIVILEGES,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.OktaGroupPrivileges)
  })
_sym_db.RegisterMessage(OktaGroupPrivileges)

AccessRequestConfig = _reflection.GeneratedProtocolMessageType('AccessRequestConfig', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTCONFIG,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestConfig)
  })
_sym_db.RegisterMessage(AccessRequestConfig)

RequestAccessRequestConfig = _reflection.GeneratedProtocolMessageType('RequestAccessRequestConfig', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTACCESSREQUESTCONFIG,
  '__module__' : 'access_requests_pb2'
  # @@protoc_insertion_point(class_scope:v1.RequestAccessRequestConfig)
  })
_sym_db.RegisterMessage(RequestAccessRequestConfig)

_ACCESSREQUESTS = DESCRIPTOR.services_by_name['AccessRequests']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\026AccessRequestsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ACCESSREQUESTLISTREQUEST.fields_by_name['filter']._options = None
  _ACCESSREQUESTLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTLISTREQUEST._options = None
  _ACCESSREQUESTLISTREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['access_requests']._options = None
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['access_requests']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCESSREQUESTLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*'
  _ACCESSREQUESTLISTRESPONSE._options = None
  _ACCESSREQUESTLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['id']._options = None
  _ACCESSREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['resource_id']._options = None
  _ACCESSREQUEST.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['reason']._options = None
  _ACCESSREQUEST.fields_by_name['reason']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['workflow_id']._options = None
  _ACCESSREQUEST.fields_by_name['workflow_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['account_id']._options = None
  _ACCESSREQUEST.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['start_from']._options = None
  _ACCESSREQUEST.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['valid_until']._options = None
  _ACCESSREQUEST.fields_by_name['valid_until']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['status']._options = None
  _ACCESSREQUEST.fields_by_name['status']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['status_at']._options = None
  _ACCESSREQUEST.fields_by_name['status_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['grant_id']._options = None
  _ACCESSREQUEST.fields_by_name['grant_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['duration']._options = None
  _ACCESSREQUEST.fields_by_name['duration']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['requestedDuration']._options = None
  _ACCESSREQUEST.fields_by_name['requestedDuration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['resultDuration']._options = None
  _ACCESSREQUEST.fields_by_name['resultDuration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUEST.fields_by_name['requester_name']._options = None
  _ACCESSREQUEST.fields_by_name['requester_name']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _ACCESSREQUEST._options = None
  _ACCESSREQUEST._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _ACCESSREQUESTEVENT.fields_by_name['id']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['request_id']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['request_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['actor_id']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['actor_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['type']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['metadata']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['metadata']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENT.fields_by_name['time']._options = None
  _ACCESSREQUESTEVENT.fields_by_name['time']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _ACCESSREQUESTEVENT._options = None
  _ACCESSREQUESTEVENT._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _REQUESTABLERESOURCE.fields_by_name['id']._options = None
  _REQUESTABLERESOURCE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['name']._options = None
  _REQUESTABLERESOURCE.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['healthy']._options = None
  _REQUESTABLERESOURCE.fields_by_name['healthy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['type']._options = None
  _REQUESTABLERESOURCE.fields_by_name['type']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['authentication']._options = None
  _REQUESTABLERESOURCE.fields_by_name['authentication']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['tags']._options = None
  _REQUESTABLERESOURCE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['access']._options = None
  _REQUESTABLERESOURCE.fields_by_name['access']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTABLERESOURCE.fields_by_name['privileges']._options = None
  _REQUESTABLERESOURCE.fields_by_name['privileges']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _REQUESTABLERESOURCE.fields_by_name['privileges_requirement_status']._options = None
  _REQUESTABLERESOURCE.fields_by_name['privileges_requirement_status']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _REQUESTABLERESOURCE._options = None
  _REQUESTABLERESOURCE._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _PRIVILEGESMESSAGE.fields_by_name['kubernetes']._options = None
  _PRIVILEGESMESSAGE.fields_by_name['kubernetes']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PRIVILEGESMESSAGE.fields_by_name['entraGroups']._options = None
  _PRIVILEGESMESSAGE.fields_by_name['entraGroups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PRIVILEGESMESSAGE.fields_by_name['oktaGroups']._options = None
  _PRIVILEGESMESSAGE.fields_by_name['oktaGroups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PRIVILEGESMESSAGE._options = None
  _PRIVILEGESMESSAGE._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _KUBERNETESPRIVILEGES.fields_by_name['groups']._options = None
  _KUBERNETESPRIVILEGES.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KUBERNETESPRIVILEGES._options = None
  _KUBERNETESPRIVILEGES._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _ENTRAGROUPPRIVILEGES.fields_by_name['groups']._options = None
  _ENTRAGROUPPRIVILEGES.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ENTRAGROUPPRIVILEGES._options = None
  _ENTRAGROUPPRIVILEGES._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _OKTAGROUPPRIVILEGES.fields_by_name['groups']._options = None
  _OKTAGROUPPRIVILEGES.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _OKTAGROUPPRIVILEGES._options = None
  _OKTAGROUPPRIVILEGES._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _ACCESSREQUESTCONFIG.fields_by_name['resource_id']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCESSREQUESTCONFIG.fields_by_name['reason']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['reason']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTCONFIG.fields_by_name['start_from']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTCONFIG.fields_by_name['duration']._options = None
  _ACCESSREQUESTCONFIG.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTCONFIG._options = None
  _ACCESSREQUESTCONFIG._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['resource_ids']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['resource_ids']._serialized_options = b'\030\001\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['reason']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['reason']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['start_from']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['start_from']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['duration']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['access_rules']._options = None
  _REQUESTACCESSREQUESTCONFIG.fields_by_name['access_rules']._serialized_options = b'\362\370\263\007\325\001\260\363\263\007\001\312\363\263\007\251\001\352\363\263\007\014access_rules\362\363\263\007\021\n\002go\022\013AccessRules\362\363\263\007\031\n\ngo_private\022\013AccessRules\362\363\263\007\033\n\014go_terraform\022\013AccessRules\362\363\263\007\030\n\004java\022\020List<AccessRule>\362\363\263\007\"\n\014json_gateway\022\022models.AccessRules\272\364\263\007\027accessRulesDiffSuppress\320\364\263\007\001'
  _REQUESTACCESSREQUESTCONFIG._options = None
  _REQUESTACCESSREQUESTCONFIG._serialized_options = b'\372\370\263\007\024\250\363\263\007\001\322\363\263\007\ngo_private'
  _ACCESSREQUESTS._options = None
  _ACCESSREQUESTS._serialized_options = b'\312\371\263\007\022\302\371\263\007\rAccessRequest\312\371\263\007\010\322\371\263\007\003aq-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider\312\371\263\007\005\350\371\263\007\001'
  _ACCESSREQUESTS.methods_by_name['List']._options = None
  _ACCESSREQUESTS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/access-requests'
  _ACCESSREQUESTLISTREQUEST._serialized_start=133
  _ACCESSREQUESTLISTREQUEST._serialized_end=238
  _ACCESSREQUESTLISTRESPONSE._serialized_start=241
  _ACCESSREQUESTLISTRESPONSE._serialized_end=442
  _ACCESSREQUEST._serialized_start=445
  _ACCESSREQUEST._serialized_end=1088
  _ACCESSREQUESTEVENT._serialized_start=1091
  _ACCESSREQUESTEVENT._serialized_end=1340
  _REQUESTABLERESOURCE._serialized_start=1343
  _REQUESTABLERESOURCE._serialized_end=1723
  _PRIVILEGESMESSAGE._serialized_start=1726
  _PRIVILEGESMESSAGE._serialized_end=1946
  _KUBERNETESPRIVILEGES._serialized_start=1948
  _KUBERNETESPRIVILEGES._serialized_end=2025
  _ENTRAGROUPPRIVILEGES._serialized_start=2027
  _ENTRAGROUPPRIVILEGES._serialized_end=2104
  _OKTAGROUPPRIVILEGES._serialized_start=2106
  _OKTAGROUPPRIVILEGES._serialized_end=2182
  _ACCESSREQUESTCONFIG._serialized_start=2185
  _ACCESSREQUESTCONFIG._serialized_end=2380
  _REQUESTACCESSREQUESTCONFIG._serialized_start=2383
  _REQUESTACCESSREQUESTCONFIG._serialized_end=2842
  _ACCESSREQUESTS._serialized_start=2845
  _ACCESSREQUESTS._serialized_end=3062
# @@protoc_insertion_point(module_scope)
