# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identity_aliases.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16identity_aliases.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"|\n\x1aIdentityAliasCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xef\x01\n\x1bIdentityAliasCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"W\n\x17IdentityAliasGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe9\x01\n\x18IdentityAliasGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x88\x01\n\x1aIdentityAliasUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x35\n\x0eidentity_alias\x18\x03 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xef\x01\n\x1bIdentityAliasUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\x0eidentity_alias\x18\x02 \x01(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"]\n\x1aIdentityAliasDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb8\x01\n\x1bIdentityAliasDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"]\n\x18IdentityAliasListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd5\x01\n\x19IdentityAliasListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x37\n\x10identity_aliases\x18\x02 \x03(\x0b\x32\x11.v1.IdentityAliasB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x85\x02\n\rIdentityAlias\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12(\n\x0fidentity_set_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x08username\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:j\xfa\xf8\xb3\x07\x65\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07[\xa2\xf3\xb3\x07\'tf_examples/identity_alias_resource.txt\xaa\xf3\xb3\x07*tf_examples/identity_alias_data_source.txt2\x92\x05\n\x0fIdentityAliases\x12w\n\x06\x43reate\x12\x1e.v1.IdentityAliasCreateRequest\x1a\x1f.v1.IdentityAliasCreateResponse\",\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/identity-aliases\x12r\n\x03Get\x12\x1b.v1.IdentityAliasGetRequest\x1a\x1c.v1.IdentityAliasGetResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/identity-aliases/{id}\x12{\n\x06Update\x12\x1e.v1.IdentityAliasUpdateRequest\x1a\x1f.v1.IdentityAliasUpdateResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/identity-aliases/{id}\x12~\n\x06\x44\x65lete\x12\x1e.v1.IdentityAliasDeleteRequest\x1a\x1f.v1.IdentityAliasDeleteResponse\"3\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/identity-aliases/{id}\x12p\n\x04List\x12\x1c.v1.IdentityAliasListRequest\x1a\x1d.v1.IdentityAliasListResponse\"+\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/identity-aliases\x1a#\xca\xf9\xb3\x07\x12\xc2\xf9\xb3\x07\rIdentityAlias\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02i-Bk\n\x19\x63om.strongdm.api.plumbingB\x17IdentityAliasesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_IDENTITYALIASCREATEREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasCreateRequest']
_IDENTITYALIASCREATERESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasCreateResponse']
_IDENTITYALIASGETREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasGetRequest']
_IDENTITYALIASGETRESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasGetResponse']
_IDENTITYALIASUPDATEREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasUpdateRequest']
_IDENTITYALIASUPDATERESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasUpdateResponse']
_IDENTITYALIASDELETEREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasDeleteRequest']
_IDENTITYALIASDELETERESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasDeleteResponse']
_IDENTITYALIASLISTREQUEST = DESCRIPTOR.message_types_by_name['IdentityAliasListRequest']
_IDENTITYALIASLISTRESPONSE = DESCRIPTOR.message_types_by_name['IdentityAliasListResponse']
_IDENTITYALIAS = DESCRIPTOR.message_types_by_name['IdentityAlias']
IdentityAliasCreateRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASCREATEREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasCreateRequest)
  })
_sym_db.RegisterMessage(IdentityAliasCreateRequest)

IdentityAliasCreateResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASCREATERESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasCreateResponse)
  })
_sym_db.RegisterMessage(IdentityAliasCreateResponse)

IdentityAliasGetRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASGETREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasGetRequest)
  })
_sym_db.RegisterMessage(IdentityAliasGetRequest)

IdentityAliasGetResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASGETRESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasGetResponse)
  })
_sym_db.RegisterMessage(IdentityAliasGetResponse)

IdentityAliasUpdateRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASUPDATEREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasUpdateRequest)
  })
_sym_db.RegisterMessage(IdentityAliasUpdateRequest)

IdentityAliasUpdateResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASUPDATERESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasUpdateResponse)
  })
_sym_db.RegisterMessage(IdentityAliasUpdateResponse)

IdentityAliasDeleteRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASDELETEREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasDeleteRequest)
  })
_sym_db.RegisterMessage(IdentityAliasDeleteRequest)

IdentityAliasDeleteResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASDELETERESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasDeleteResponse)
  })
_sym_db.RegisterMessage(IdentityAliasDeleteResponse)

IdentityAliasListRequest = _reflection.GeneratedProtocolMessageType('IdentityAliasListRequest', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASLISTREQUEST,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasListRequest)
  })
_sym_db.RegisterMessage(IdentityAliasListRequest)

IdentityAliasListResponse = _reflection.GeneratedProtocolMessageType('IdentityAliasListResponse', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIASLISTRESPONSE,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAliasListResponse)
  })
_sym_db.RegisterMessage(IdentityAliasListResponse)

IdentityAlias = _reflection.GeneratedProtocolMessageType('IdentityAlias', (_message.Message,), {
  'DESCRIPTOR' : _IDENTITYALIAS,
  '__module__' : 'identity_aliases_pb2'
  # @@protoc_insertion_point(class_scope:v1.IdentityAlias)
  })
_sym_db.RegisterMessage(IdentityAlias)

_IDENTITYALIASES = DESCRIPTOR.services_by_name['IdentityAliases']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\027IdentityAliasesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _IDENTITYALIASCREATEREQUEST.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASCREATEREQUEST.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASCREATERESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASCREATERESPONSE.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASCREATERESPONSE.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASCREATERESPONSE._options = None
  _IDENTITYALIASCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASGETREQUEST.fields_by_name['id']._options = None
  _IDENTITYALIASGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASGETRESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASGETRESPONSE.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASGETRESPONSE.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASGETRESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASGETRESPONSE._options = None
  _IDENTITYALIASGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASUPDATEREQUEST.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASUPDATEREQUEST.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['identity_alias']._options = None
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['identity_alias']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASUPDATERESPONSE._options = None
  _IDENTITYALIASUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASDELETEREQUEST.fields_by_name['id']._options = None
  _IDENTITYALIASDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASDELETERESPONSE.fields_by_name['meta']._options = None
  _IDENTITYALIASDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIASDELETERESPONSE._options = None
  _IDENTITYALIASDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _IDENTITYALIASLISTREQUEST.fields_by_name['filter']._options = None
  _IDENTITYALIASLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIASLISTRESPONSE.fields_by_name['identity_aliases']._options = None
  _IDENTITYALIASLISTRESPONSE.fields_by_name['identity_aliases']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _IDENTITYALIASLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _IDENTITYALIASLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _IDENTITYALIAS.fields_by_name['id']._options = None
  _IDENTITYALIAS.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _IDENTITYALIAS.fields_by_name['account_id']._options = None
  _IDENTITYALIAS.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _IDENTITYALIAS.fields_by_name['identity_set_id']._options = None
  _IDENTITYALIAS.fields_by_name['identity_set_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _IDENTITYALIAS.fields_by_name['username']._options = None
  _IDENTITYALIAS.fields_by_name['username']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _IDENTITYALIAS._options = None
  _IDENTITYALIAS._serialized_options = b'\372\370\263\007e\250\363\263\007\001\302\363\263\007[\242\363\263\007\'tf_examples/identity_alias_resource.txt\252\363\263\007*tf_examples/identity_alias_data_source.txt'
  _IDENTITYALIASES._options = None
  _IDENTITYALIASES._serialized_options = b'\312\371\263\007\022\302\371\263\007\rIdentityAlias\312\371\263\007\007\322\371\263\007\002i-'
  _IDENTITYALIASES.methods_by_name['Create']._options = None
  _IDENTITYALIASES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\031\252\363\263\007\024/v1/identity-aliases'
  _IDENTITYALIASES.methods_by_name['Get']._options = None
  _IDENTITYALIASES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\036\252\363\263\007\031/v1/identity-aliases/{id}'
  _IDENTITYALIASES.methods_by_name['Update']._options = None
  _IDENTITYALIASES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\036\252\363\263\007\031/v1/identity-aliases/{id}'
  _IDENTITYALIASES.methods_by_name['Delete']._options = None
  _IDENTITYALIASES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\036\252\363\263\007\031/v1/identity-aliases/{id}'
  _IDENTITYALIASES.methods_by_name['List']._options = None
  _IDENTITYALIASES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\031\252\363\263\007\024/v1/identity-aliases'
  _IDENTITYALIASCREATEREQUEST._serialized_start=57
  _IDENTITYALIASCREATEREQUEST._serialized_end=181
  _IDENTITYALIASCREATERESPONSE._serialized_start=184
  _IDENTITYALIASCREATERESPONSE._serialized_end=423
  _IDENTITYALIASGETREQUEST._serialized_start=425
  _IDENTITYALIASGETREQUEST._serialized_end=512
  _IDENTITYALIASGETRESPONSE._serialized_start=515
  _IDENTITYALIASGETRESPONSE._serialized_end=748
  _IDENTITYALIASUPDATEREQUEST._serialized_start=751
  _IDENTITYALIASUPDATEREQUEST._serialized_end=887
  _IDENTITYALIASUPDATERESPONSE._serialized_start=890
  _IDENTITYALIASUPDATERESPONSE._serialized_end=1129
  _IDENTITYALIASDELETEREQUEST._serialized_start=1131
  _IDENTITYALIASDELETEREQUEST._serialized_end=1224
  _IDENTITYALIASDELETERESPONSE._serialized_start=1227
  _IDENTITYALIASDELETERESPONSE._serialized_end=1411
  _IDENTITYALIASLISTREQUEST._serialized_start=1413
  _IDENTITYALIASLISTREQUEST._serialized_end=1506
  _IDENTITYALIASLISTRESPONSE._serialized_start=1509
  _IDENTITYALIASLISTRESPONSE._serialized_end=1722
  _IDENTITYALIAS._serialized_start=1725
  _IDENTITYALIAS._serialized_end=1986
  _IDENTITYALIASES._serialized_start=1989
  _IDENTITYALIASES._serialized_end=2647
# @@protoc_insertion_point(module_scope)
