# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_stores.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import secret_store_types_pb2 as secret__store__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13secret_stores.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\x18secret_store_types.proto\"v\n\x18SecretStoreCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x31\n\x0csecret_store\x18\x02 \x01(\x0b\x32\x0f.v1.SecretStoreB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe9\x01\n\x19SecretStoreCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x31\n\x0csecret_store\x18\x02 \x01(\x0b\x32\x0f.v1.SecretStoreB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"U\n\x15SecretStoreGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe3\x01\n\x16SecretStoreGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x31\n\x0csecret_store\x18\x02 \x01(\x0b\x32\x0f.v1.SecretStoreB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x82\x01\n\x18SecretStoreUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x31\n\x0csecret_store\x18\x03 \x01(\x0b\x32\x0f.v1.SecretStoreB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe9\x01\n\x19SecretStoreUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x31\n\x0csecret_store\x18\x02 \x01(\x0b\x32\x0f.v1.SecretStoreB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"[\n\x18SecretStoreDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb6\x01\n\x19SecretStoreDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"[\n\x16SecretStoreListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xce\x01\n\x17SecretStoreListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x32\n\rsecret_stores\x18\x02 \x03(\x0b\x32\x0f.v1.SecretStoreB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway2\xeb\x04\n\x0cSecretStores\x12p\n\x06\x43reate\x12\x1c.v1.SecretStoreCreateRequest\x1a\x1d.v1.SecretStoreCreateResponse\")\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/secret-stores\x12k\n\x03Get\x12\x19.v1.SecretStoreGetRequest\x1a\x1a.v1.SecretStoreGetResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/secret-stores/{id}\x12t\n\x06Update\x12\x1c.v1.SecretStoreUpdateRequest\x1a\x1d.v1.SecretStoreUpdateResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/secret-stores/{id}\x12w\n\x06\x44\x65lete\x12\x1c.v1.SecretStoreDeleteRequest\x1a\x1d.v1.SecretStoreDeleteResponse\"0\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/secret-stores/{id}\x12i\n\x04List\x12\x1a.v1.SecretStoreListRequest\x1a\x1b.v1.SecretStoreListResponse\"(\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/secret-stores\x1a\"\xca\xf9\xb3\x07\x10\xc2\xf9\xb3\x07\x0bSecretStore\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03se-Bh\n\x19\x63om.strongdm.api.plumbingB\x14SecretStoresPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_SECRETSTORECREATEREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreCreateRequest']
_SECRETSTORECREATERESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreCreateResponse']
_SECRETSTOREGETREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreGetRequest']
_SECRETSTOREGETRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreGetResponse']
_SECRETSTOREUPDATEREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreUpdateRequest']
_SECRETSTOREUPDATERESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreUpdateResponse']
_SECRETSTOREDELETEREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreDeleteRequest']
_SECRETSTOREDELETERESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreDeleteResponse']
_SECRETSTORELISTREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreListRequest']
_SECRETSTORELISTRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreListResponse']
SecretStoreCreateRequest = _reflection.GeneratedProtocolMessageType('SecretStoreCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTORECREATEREQUEST,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreCreateRequest)
  })
_sym_db.RegisterMessage(SecretStoreCreateRequest)

SecretStoreCreateResponse = _reflection.GeneratedProtocolMessageType('SecretStoreCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTORECREATERESPONSE,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreCreateResponse)
  })
_sym_db.RegisterMessage(SecretStoreCreateResponse)

SecretStoreGetRequest = _reflection.GeneratedProtocolMessageType('SecretStoreGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREGETREQUEST,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreGetRequest)
  })
_sym_db.RegisterMessage(SecretStoreGetRequest)

SecretStoreGetResponse = _reflection.GeneratedProtocolMessageType('SecretStoreGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREGETRESPONSE,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreGetResponse)
  })
_sym_db.RegisterMessage(SecretStoreGetResponse)

SecretStoreUpdateRequest = _reflection.GeneratedProtocolMessageType('SecretStoreUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREUPDATEREQUEST,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreUpdateRequest)
  })
_sym_db.RegisterMessage(SecretStoreUpdateRequest)

SecretStoreUpdateResponse = _reflection.GeneratedProtocolMessageType('SecretStoreUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREUPDATERESPONSE,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreUpdateResponse)
  })
_sym_db.RegisterMessage(SecretStoreUpdateResponse)

SecretStoreDeleteRequest = _reflection.GeneratedProtocolMessageType('SecretStoreDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREDELETEREQUEST,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreDeleteRequest)
  })
_sym_db.RegisterMessage(SecretStoreDeleteRequest)

SecretStoreDeleteResponse = _reflection.GeneratedProtocolMessageType('SecretStoreDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREDELETERESPONSE,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreDeleteResponse)
  })
_sym_db.RegisterMessage(SecretStoreDeleteResponse)

SecretStoreListRequest = _reflection.GeneratedProtocolMessageType('SecretStoreListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTORELISTREQUEST,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreListRequest)
  })
_sym_db.RegisterMessage(SecretStoreListRequest)

SecretStoreListResponse = _reflection.GeneratedProtocolMessageType('SecretStoreListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTORELISTRESPONSE,
  '__module__' : 'secret_stores_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreListResponse)
  })
_sym_db.RegisterMessage(SecretStoreListResponse)

_SECRETSTORES = DESCRIPTOR.services_by_name['SecretStores']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\024SecretStoresPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _SECRETSTORECREATEREQUEST.fields_by_name['secret_store']._options = None
  _SECRETSTORECREATEREQUEST.fields_by_name['secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORECREATERESPONSE.fields_by_name['meta']._options = None
  _SECRETSTORECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORECREATERESPONSE.fields_by_name['secret_store']._options = None
  _SECRETSTORECREATERESPONSE.fields_by_name['secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTORECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTORECREATERESPONSE._options = None
  _SECRETSTORECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREGETREQUEST.fields_by_name['id']._options = None
  _SECRETSTOREGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREGETRESPONSE.fields_by_name['meta']._options = None
  _SECRETSTOREGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREGETRESPONSE.fields_by_name['secret_store']._options = None
  _SECRETSTOREGETRESPONSE.fields_by_name['secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREGETRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREGETRESPONSE._options = None
  _SECRETSTOREGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREUPDATEREQUEST.fields_by_name['secret_store']._options = None
  _SECRETSTOREUPDATEREQUEST.fields_by_name['secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREUPDATERESPONSE.fields_by_name['meta']._options = None
  _SECRETSTOREUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREUPDATERESPONSE.fields_by_name['secret_store']._options = None
  _SECRETSTOREUPDATERESPONSE.fields_by_name['secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREUPDATERESPONSE._options = None
  _SECRETSTOREUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREDELETEREQUEST.fields_by_name['id']._options = None
  _SECRETSTOREDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREDELETERESPONSE.fields_by_name['meta']._options = None
  _SECRETSTOREDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREDELETERESPONSE._options = None
  _SECRETSTOREDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTORELISTREQUEST.fields_by_name['filter']._options = None
  _SECRETSTORELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTORELISTRESPONSE.fields_by_name['secret_stores']._options = None
  _SECRETSTORELISTRESPONSE.fields_by_name['secret_stores']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _SECRETSTORELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTORELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTORES._options = None
  _SECRETSTORES._serialized_options = b'\312\371\263\007\020\302\371\263\007\013SecretStore\312\371\263\007\010\322\371\263\007\003se-'
  _SECRETSTORES.methods_by_name['Create']._options = None
  _SECRETSTORES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\026\252\363\263\007\021/v1/secret-stores'
  _SECRETSTORES.methods_by_name['Get']._options = None
  _SECRETSTORES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/secret-stores/{id}'
  _SECRETSTORES.methods_by_name['Update']._options = None
  _SECRETSTORES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\033\252\363\263\007\026/v1/secret-stores/{id}'
  _SECRETSTORES.methods_by_name['Delete']._options = None
  _SECRETSTORES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\033\252\363\263\007\026/v1/secret-stores/{id}'
  _SECRETSTORES.methods_by_name['List']._options = None
  _SECRETSTORES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\026\252\363\263\007\021/v1/secret-stores'
  _SECRETSTORECREATEREQUEST._serialized_start=80
  _SECRETSTORECREATEREQUEST._serialized_end=198
  _SECRETSTORECREATERESPONSE._serialized_start=201
  _SECRETSTORECREATERESPONSE._serialized_end=434
  _SECRETSTOREGETREQUEST._serialized_start=436
  _SECRETSTOREGETREQUEST._serialized_end=521
  _SECRETSTOREGETRESPONSE._serialized_start=524
  _SECRETSTOREGETRESPONSE._serialized_end=751
  _SECRETSTOREUPDATEREQUEST._serialized_start=754
  _SECRETSTOREUPDATEREQUEST._serialized_end=884
  _SECRETSTOREUPDATERESPONSE._serialized_start=887
  _SECRETSTOREUPDATERESPONSE._serialized_end=1120
  _SECRETSTOREDELETEREQUEST._serialized_start=1122
  _SECRETSTOREDELETEREQUEST._serialized_end=1213
  _SECRETSTOREDELETERESPONSE._serialized_start=1216
  _SECRETSTOREDELETERESPONSE._serialized_end=1398
  _SECRETSTORELISTREQUEST._serialized_start=1400
  _SECRETSTORELISTREQUEST._serialized_end=1491
  _SECRETSTORELISTRESPONSE._serialized_start=1494
  _SECRETSTORELISTRESPONSE._serialized_end=1700
  _SECRETSTORES._serialized_start=1703
  _SECRETSTORES._serialized_end=2322
# @@protoc_insertion_point(module_scope)
