# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: approval_workflow_steps.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61pproval_workflow_steps.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\x1egoogle/protobuf/duration.proto\"\x92\x01\n!ApprovalWorkflowStepCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x44\n\x16\x61pproval_workflow_step\x18\x02 \x01(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf9\x01\n\"ApprovalWorkflowStepCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x44\n\x16\x61pproval_workflow_step\x18\x02 \x01(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x1e\x41pprovalWorkflowStepGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xff\x01\n\x1f\x41pprovalWorkflowStepGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x16\x61pproval_workflow_step\x18\x02 \x01(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n!ApprovalWorkflowStepDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcb\x01\n\"ApprovalWorkflowStepDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n\x1f\x41pprovalWorkflowStepListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf6\x01\n ApprovalWorkflowStepListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x45\n\x17\x61pproval_workflow_steps\x18\x02 \x03(\x0b\x32\x18.v1.ApprovalWorkflowStepB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x84\x03\n\x14\x41pprovalWorkflowStep\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x10\x61pproval_flow_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12J\n\nquantifier\x18\x03 \x01(\tB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli\x12\x65\n\nskip_after\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli\x12J\n\nstep_order\x18\x05 \x01(\x05\x42\x36\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\xb2\xf4\xb3\x07\x04!cli:*\x18\x01\xfa\xf8\xb3\x07#\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x13!terraform-provider2\xab\x05\n\x15\x41pprovalWorkflowSteps\x12\x8c\x01\n\x06\x43reate\x12%.v1.ApprovalWorkflowStepCreateRequest\x1a&.v1.ApprovalWorkflowStepCreateResponse\"3\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/approval-workflow-steps\x12\x86\x01\n\x03Get\x12\".v1.ApprovalWorkflowStepGetRequest\x1a#.v1.ApprovalWorkflowStepGetResponse\"6\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07$\xaa\xf3\xb3\x07\x1f/v1/approval-workflow-step/{id}\x12\x8e\x01\n\x06\x44\x65lete\x12%.v1.ApprovalWorkflowStepDeleteRequest\x1a&.v1.ApprovalWorkflowStepDeleteResponse\"5\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/approval-workflow-steps\x12\x85\x01\n\x04List\x12#.v1.ApprovalWorkflowStepListRequest\x1a$.v1.ApprovalWorkflowStepListResponse\"2\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/approval-workflow-steps\x1a\x61\x88\x02\x01\xca\xf9\xb3\x07\x19\xc2\xf9\xb3\x07\x14\x41pprovalWorkflowStep\xca\xf9\xb3\x07\t\xd2\xf9\xb3\x07\x04\x61\x66s-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerBq\n\x19\x63om.strongdm.api.plumbingB\x1d\x41pprovalWorkflowStepsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_APPROVALWORKFLOWSTEPCREATEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepCreateRequest']
_APPROVALWORKFLOWSTEPCREATERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepCreateResponse']
_APPROVALWORKFLOWSTEPGETREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepGetRequest']
_APPROVALWORKFLOWSTEPGETRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepGetResponse']
_APPROVALWORKFLOWSTEPDELETEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepDeleteRequest']
_APPROVALWORKFLOWSTEPDELETERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepDeleteResponse']
_APPROVALWORKFLOWSTEPLISTREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepListRequest']
_APPROVALWORKFLOWSTEPLISTRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStepListResponse']
_APPROVALWORKFLOWSTEP = DESCRIPTOR.message_types_by_name['ApprovalWorkflowStep']
ApprovalWorkflowStepCreateRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPCREATEREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepCreateRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepCreateRequest)

ApprovalWorkflowStepCreateResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPCREATERESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepCreateResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepCreateResponse)

ApprovalWorkflowStepGetRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPGETREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepGetRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepGetRequest)

ApprovalWorkflowStepGetResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPGETRESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepGetResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepGetResponse)

ApprovalWorkflowStepDeleteRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPDELETEREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepDeleteRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepDeleteRequest)

ApprovalWorkflowStepDeleteResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPDELETERESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepDeleteResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepDeleteResponse)

ApprovalWorkflowStepListRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepListRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPLISTREQUEST,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepListRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepListRequest)

ApprovalWorkflowStepListResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStepListResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEPLISTRESPONSE,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStepListResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStepListResponse)

ApprovalWorkflowStep = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowStep', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWSTEP,
  '__module__' : 'approval_workflow_steps_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowStep)
  })
_sym_db.RegisterMessage(ApprovalWorkflowStep)

_APPROVALWORKFLOWSTEPS = DESCRIPTOR.services_by_name['ApprovalWorkflowSteps']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\035ApprovalWorkflowStepsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _APPROVALWORKFLOWSTEPCREATEREQUEST.fields_by_name['approval_workflow_step']._options = None
  _APPROVALWORKFLOWSTEPCREATEREQUEST.fields_by_name['approval_workflow_step']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['approval_workflow_step']._options = None
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['approval_workflow_step']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPCREATERESPONSE._options = None
  _APPROVALWORKFLOWSTEPCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['meta']._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['approval_workflow_step']._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['approval_workflow_step']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPGETRESPONSE._options = None
  _APPROVALWORKFLOWSTEPGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEPDELETEREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPDELETERESPONSE._options = None
  _APPROVALWORKFLOWSTEPDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEPLISTREQUEST.fields_by_name['filter']._options = None
  _APPROVALWORKFLOWSTEPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['approval_workflow_steps']._options = None
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['approval_workflow_steps']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWSTEPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWSTEPLISTRESPONSE._options = None
  _APPROVALWORKFLOWSTEPLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWSTEP.fields_by_name['id']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWSTEP.fields_by_name['approval_flow_id']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['approval_flow_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _APPROVALWORKFLOWSTEP.fields_by_name['quantifier']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['quantifier']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWSTEP.fields_by_name['skip_after']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['skip_after']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWSTEP.fields_by_name['step_order']._options = None
  _APPROVALWORKFLOWSTEP.fields_by_name['step_order']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider\262\364\263\007\004!cli'
  _APPROVALWORKFLOWSTEP._options = None
  _APPROVALWORKFLOWSTEP._serialized_options = b'\030\001\372\370\263\007#\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\023!terraform-provider'
  _APPROVALWORKFLOWSTEPS._options = None
  _APPROVALWORKFLOWSTEPS._serialized_options = b'\210\002\001\312\371\263\007\031\302\371\263\007\024ApprovalWorkflowStep\312\371\263\007\t\322\371\263\007\004afs-\312\371\263\007\005\350\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _APPROVALWORKFLOWSTEPS.methods_by_name['Create']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007 \252\363\263\007\033/v1/approval-workflow-steps'
  _APPROVALWORKFLOWSTEPS.methods_by_name['Get']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007$\252\363\263\007\037/v1/approval-workflow-step/{id}'
  _APPROVALWORKFLOWSTEPS.methods_by_name['Delete']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007 \252\363\263\007\033/v1/approval-workflow-steps'
  _APPROVALWORKFLOWSTEPS.methods_by_name['List']._options = None
  _APPROVALWORKFLOWSTEPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007 \252\363\263\007\033/v1/approval-workflow-steps'
  _APPROVALWORKFLOWSTEPCREATEREQUEST._serialized_start=97
  _APPROVALWORKFLOWSTEPCREATEREQUEST._serialized_end=243
  _APPROVALWORKFLOWSTEPCREATERESPONSE._serialized_start=246
  _APPROVALWORKFLOWSTEPCREATERESPONSE._serialized_end=495
  _APPROVALWORKFLOWSTEPGETREQUEST._serialized_start=497
  _APPROVALWORKFLOWSTEPGETREQUEST._serialized_end=591
  _APPROVALWORKFLOWSTEPGETRESPONSE._serialized_start=594
  _APPROVALWORKFLOWSTEPGETRESPONSE._serialized_end=849
  _APPROVALWORKFLOWSTEPDELETEREQUEST._serialized_start=851
  _APPROVALWORKFLOWSTEPDELETEREQUEST._serialized_end=951
  _APPROVALWORKFLOWSTEPDELETERESPONSE._serialized_start=954
  _APPROVALWORKFLOWSTEPDELETERESPONSE._serialized_end=1157
  _APPROVALWORKFLOWSTEPLISTREQUEST._serialized_start=1159
  _APPROVALWORKFLOWSTEPLISTREQUEST._serialized_end=1259
  _APPROVALWORKFLOWSTEPLISTRESPONSE._serialized_start=1262
  _APPROVALWORKFLOWSTEPLISTRESPONSE._serialized_end=1508
  _APPROVALWORKFLOWSTEP._serialized_start=1511
  _APPROVALWORKFLOWSTEP._serialized_end=1899
  _APPROVALWORKFLOWSTEPS._serialized_start=1902
  _APPROVALWORKFLOWSTEPS._serialized_end=2585
# @@protoc_insertion_point(module_scope)
