# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: organization_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aorganization_history.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\"\x8d\x01\n\x1eOrganizationHistoryListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x88\x02\n\x1fOrganizationHistoryListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12:\n\x07history\x18\x02 \x03(\x0b\x32\x1d.v1.OrganizationHistoryRecordB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xdf\x01\n\x19OrganizationHistoryRecord\x12\x1f\n\x0b\x61\x63tivity_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\x0corganization\x18\x03 \x01(\x0b\x32\x10.v1.OrganizationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xa1\r\n\x0cOrganization\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rauth_provider\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x14idle_timeout_enabled\x18\x05 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12;\n\x0cidle_timeout\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12+\n\x17session_timeout_enabled\x18\x07 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12>\n\x0fsession_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\x0bmfa_enabled\x18\t \x01(\x08\x42$\xf2\xf8\xb3\x07\x1f\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x15\xc2\xf4\xb3\x07\x10\n\x02go\x12\nMFAEnabled\x12;\n\x0cmfa_provider\x18\n \x01(\tB%\xf2\xf8\xb3\x07 \xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x16\xc2\xf4\xb3\x07\x11\n\x02go\x12\x0bMFAProvider\x12(\n\x12log_remote_encoder\x18\x0b \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\'\n\x11log_local_storage\x18\x0c \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\'\n\x11log_local_encoder\x18\r \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x10log_local_format\x18\x0e \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x42\n\x0flog_tcp_address\x18\x0f \x01(\tB)\x18\x01\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x02go\x12\rLogTCPAddress\x12%\n\x0flog_socket_path\x18\x10 \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12=\n\rscim_provider\x18\x11 \x01(\tB&\xf2\xf8\xb3\x07!\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x17\xc2\xf4\xb3\x07\x12\n\x02go\x12\x0cSCIMProvider\x12&\n\x12websites_subdomain\x18\x12 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12h\n$ssh_certificate_authority_public_key\x18\x13 \x01(\tB:\xf2\xf8\xb3\x07\x35\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07+\xc2\xf4\xb3\x07&\n\x02go\x12 SSHCertificateAuthorityPublicKey\x12\x84\x01\n$ssh_certificate_authority_updated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.TimestampB:\xf2\xf8\xb3\x07\x35\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07+\xc2\xf4\xb3\x07&\n\x02go\x12 SSHCertificateAuthorityUpdatedAt\x12(\n\x14require_secret_store\x18\x15 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\x0fsensitive_label\x18\x16 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x11saml_metadata_url\x18\x17 \x01(\tB)\xf2\xf8\xb3\x07$\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x02go\x12\x0fSAMLMetadataURL\x12\x18\n\x04kind\x18\x18 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12%\n\x02id\x18\x19 \x01(\tB\x19\xf2\xf8\xb3\x07\x14\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12\"\n\x0eloopback_range\x18\x1a \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12(\n\x14\x64\x65vice_trust_enabled\x18\x1b \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12)\n\x15\x64\x65vice_trust_provider\x18\x1c \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x16\x65nforce_single_session\x18\x1d \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12%\n\x0f\x64iscard_replays\x18\x1e \x01(\x08\x42\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0epublic_key_pem\x18\x1f \x01(\tB\x0c\x18\x01\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\nlog_config\x18  \x01(\x0b\x32\r.v1.LogConfigB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xc6\x02\n\tLogConfig\x12!\n\rlocal_storage\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rlocal_encoder\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0clocal_format\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x11local_tcp_address\x18\x04 \x01(\tB)\xf2\xf8\xb3\x07$\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x02go\x12\x0fLocalTCPAddress\x12%\n\x11local_socket_path\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\npublic_key\x18\x06 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x38\n\ncategories\x18\x07 \x01(\x0b\x32\x18.v1.LogCategoryConfigMapB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xbc\x03\n\x14LogCategoryConfigMap\x12/\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1e.v1.LogCategoryConfigMap.Entry\x1a[\n\x05\x45ntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x15.v1.LogCategoryConfig:\x1d\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\r!json_gateway:\x95\x02\xfa\xf8\xb3\x07\x8f\x02\xca\xf3\xb3\x07\xf1\x01\xea\xf3\xb3\x07\x17log_category_config_map\xf2\xf3\xb3\x07\x1a\n\x02go\x12\x14LogCategoryConfigMap\xf2\xf3\xb3\x07\"\n\ngo_private\x12\x14LogCategoryConfigMap\xf2\xf3\xb3\x07$\n\x0cgo_terraform\x12\x14LogCategoryConfigMap\xf2\xf3\xb3\x07\x30\n\x04java\x12(java.util.Map<String, LogCategoryConfig>\xf2\xf3\xb3\x07,\n\x0cjson_gateway\x12\x1cmap[string]LogCategoryConfig\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\r!json_gateway\"o\n\x11LogCategoryConfig\x12\"\n\x0eremote_encoder\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x16remote_discard_replays\x18\x02 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xef\x01\n\x13OrganizationHistory\x12\x80\x01\n\x04List\x12\".v1.OrganizationHistoryListRequest\x1a#.v1.OrganizationHistoryListResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/organization-history\x1aU\xca\xf9\xb3\x07\x1e\xc2\xf9\xb3\x07\x19OrganizationHistoryRecord\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x97\x01\n\x19\x63om.strongdm.api.plumbingB\x1bOrganizationHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ORGANIZATIONHISTORYLISTREQUEST = DESCRIPTOR.message_types_by_name['OrganizationHistoryListRequest']
_ORGANIZATIONHISTORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['OrganizationHistoryListResponse']
_ORGANIZATIONHISTORYRECORD = DESCRIPTOR.message_types_by_name['OrganizationHistoryRecord']
_ORGANIZATION = DESCRIPTOR.message_types_by_name['Organization']
_LOGCONFIG = DESCRIPTOR.message_types_by_name['LogConfig']
_LOGCATEGORYCONFIGMAP = DESCRIPTOR.message_types_by_name['LogCategoryConfigMap']
_LOGCATEGORYCONFIGMAP_ENTRY = _LOGCATEGORYCONFIGMAP.nested_types_by_name['Entry']
_LOGCATEGORYCONFIG = DESCRIPTOR.message_types_by_name['LogCategoryConfig']
OrganizationHistoryListRequest = _reflection.GeneratedProtocolMessageType('OrganizationHistoryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONHISTORYLISTREQUEST,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.OrganizationHistoryListRequest)
  })
_sym_db.RegisterMessage(OrganizationHistoryListRequest)

OrganizationHistoryListResponse = _reflection.GeneratedProtocolMessageType('OrganizationHistoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONHISTORYLISTRESPONSE,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.OrganizationHistoryListResponse)
  })
_sym_db.RegisterMessage(OrganizationHistoryListResponse)

OrganizationHistoryRecord = _reflection.GeneratedProtocolMessageType('OrganizationHistoryRecord', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONHISTORYRECORD,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.OrganizationHistoryRecord)
  })
_sym_db.RegisterMessage(OrganizationHistoryRecord)

Organization = _reflection.GeneratedProtocolMessageType('Organization', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATION,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.Organization)
  })
_sym_db.RegisterMessage(Organization)

LogConfig = _reflection.GeneratedProtocolMessageType('LogConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGCONFIG,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.LogConfig)
  })
_sym_db.RegisterMessage(LogConfig)

LogCategoryConfigMap = _reflection.GeneratedProtocolMessageType('LogCategoryConfigMap', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _LOGCATEGORYCONFIGMAP_ENTRY,
    '__module__' : 'organization_history_pb2'
    # @@protoc_insertion_point(class_scope:v1.LogCategoryConfigMap.Entry)
    })
  ,
  'DESCRIPTOR' : _LOGCATEGORYCONFIGMAP,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.LogCategoryConfigMap)
  })
_sym_db.RegisterMessage(LogCategoryConfigMap)
_sym_db.RegisterMessage(LogCategoryConfigMap.Entry)

LogCategoryConfig = _reflection.GeneratedProtocolMessageType('LogCategoryConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGCATEGORYCONFIG,
  '__module__' : 'organization_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.LogCategoryConfig)
  })
_sym_db.RegisterMessage(LogCategoryConfig)

_ORGANIZATIONHISTORY = DESCRIPTOR.services_by_name['OrganizationHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\033OrganizationHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ORGANIZATIONHISTORYLISTREQUEST.fields_by_name['filter']._options = None
  _ORGANIZATIONHISTORYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYLISTREQUEST._options = None
  _ORGANIZATIONHISTORYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['history']._options = None
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['history']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ORGANIZATIONHISTORYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ORGANIZATIONHISTORYLISTRESPONSE._options = None
  _ORGANIZATIONHISTORYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ORGANIZATIONHISTORYRECORD.fields_by_name['activity_id']._options = None
  _ORGANIZATIONHISTORYRECORD.fields_by_name['activity_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYRECORD.fields_by_name['timestamp']._options = None
  _ORGANIZATIONHISTORYRECORD.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYRECORD.fields_by_name['organization']._options = None
  _ORGANIZATIONHISTORYRECORD.fields_by_name['organization']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATIONHISTORYRECORD._options = None
  _ORGANIZATIONHISTORYRECORD._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ORGANIZATION.fields_by_name['name']._options = None
  _ORGANIZATION.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['created_at']._options = None
  _ORGANIZATION.fields_by_name['created_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['updated_at']._options = None
  _ORGANIZATION.fields_by_name['updated_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['auth_provider']._options = None
  _ORGANIZATION.fields_by_name['auth_provider']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['idle_timeout_enabled']._options = None
  _ORGANIZATION.fields_by_name['idle_timeout_enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['idle_timeout']._options = None
  _ORGANIZATION.fields_by_name['idle_timeout']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['session_timeout_enabled']._options = None
  _ORGANIZATION.fields_by_name['session_timeout_enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['session_timeout']._options = None
  _ORGANIZATION.fields_by_name['session_timeout']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['mfa_enabled']._options = None
  _ORGANIZATION.fields_by_name['mfa_enabled']._serialized_options = b'\362\370\263\007\037\260\363\263\007\001\312\363\263\007\025\302\364\263\007\020\n\002go\022\nMFAEnabled'
  _ORGANIZATION.fields_by_name['mfa_provider']._options = None
  _ORGANIZATION.fields_by_name['mfa_provider']._serialized_options = b'\362\370\263\007 \260\363\263\007\001\312\363\263\007\026\302\364\263\007\021\n\002go\022\013MFAProvider'
  _ORGANIZATION.fields_by_name['log_remote_encoder']._options = None
  _ORGANIZATION.fields_by_name['log_remote_encoder']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_local_storage']._options = None
  _ORGANIZATION.fields_by_name['log_local_storage']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_local_encoder']._options = None
  _ORGANIZATION.fields_by_name['log_local_encoder']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_local_format']._options = None
  _ORGANIZATION.fields_by_name['log_local_format']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_tcp_address']._options = None
  _ORGANIZATION.fields_by_name['log_tcp_address']._serialized_options = b'\030\001\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\002go\022\rLogTCPAddress'
  _ORGANIZATION.fields_by_name['log_socket_path']._options = None
  _ORGANIZATION.fields_by_name['log_socket_path']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['scim_provider']._options = None
  _ORGANIZATION.fields_by_name['scim_provider']._serialized_options = b'\362\370\263\007!\260\363\263\007\001\312\363\263\007\027\302\364\263\007\022\n\002go\022\014SCIMProvider'
  _ORGANIZATION.fields_by_name['websites_subdomain']._options = None
  _ORGANIZATION.fields_by_name['websites_subdomain']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_public_key']._options = None
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_public_key']._serialized_options = b'\362\370\263\0075\260\363\263\007\001\312\363\263\007+\302\364\263\007&\n\002go\022 SSHCertificateAuthorityPublicKey'
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_updated_at']._options = None
  _ORGANIZATION.fields_by_name['ssh_certificate_authority_updated_at']._serialized_options = b'\362\370\263\0075\260\363\263\007\001\312\363\263\007+\302\364\263\007&\n\002go\022 SSHCertificateAuthorityUpdatedAt'
  _ORGANIZATION.fields_by_name['require_secret_store']._options = None
  _ORGANIZATION.fields_by_name['require_secret_store']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['sensitive_label']._options = None
  _ORGANIZATION.fields_by_name['sensitive_label']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['saml_metadata_url']._options = None
  _ORGANIZATION.fields_by_name['saml_metadata_url']._serialized_options = b'\362\370\263\007$\260\363\263\007\001\312\363\263\007\032\302\364\263\007\025\n\002go\022\017SAMLMetadataURL'
  _ORGANIZATION.fields_by_name['kind']._options = None
  _ORGANIZATION.fields_by_name['kind']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['id']._options = None
  _ORGANIZATION.fields_by_name['id']._serialized_options = b'\362\370\263\007\024\260\363\263\007\001\262\364\263\007\ngo_private'
  _ORGANIZATION.fields_by_name['loopback_range']._options = None
  _ORGANIZATION.fields_by_name['loopback_range']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['device_trust_enabled']._options = None
  _ORGANIZATION.fields_by_name['device_trust_enabled']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['device_trust_provider']._options = None
  _ORGANIZATION.fields_by_name['device_trust_provider']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['enforce_single_session']._options = None
  _ORGANIZATION.fields_by_name['enforce_single_session']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['discard_replays']._options = None
  _ORGANIZATION.fields_by_name['discard_replays']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['public_key_pem']._options = None
  _ORGANIZATION.fields_by_name['public_key_pem']._serialized_options = b'\030\001\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION.fields_by_name['log_config']._options = None
  _ORGANIZATION.fields_by_name['log_config']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ORGANIZATION._options = None
  _ORGANIZATION._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _LOGCONFIG.fields_by_name['local_storage']._options = None
  _LOGCONFIG.fields_by_name['local_storage']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['local_encoder']._options = None
  _LOGCONFIG.fields_by_name['local_encoder']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['local_format']._options = None
  _LOGCONFIG.fields_by_name['local_format']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['local_tcp_address']._options = None
  _LOGCONFIG.fields_by_name['local_tcp_address']._serialized_options = b'\362\370\263\007$\260\363\263\007\001\312\363\263\007\032\302\364\263\007\025\n\002go\022\017LocalTCPAddress'
  _LOGCONFIG.fields_by_name['local_socket_path']._options = None
  _LOGCONFIG.fields_by_name['local_socket_path']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['public_key']._options = None
  _LOGCONFIG.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG.fields_by_name['categories']._options = None
  _LOGCONFIG.fields_by_name['categories']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCONFIG._options = None
  _LOGCONFIG._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _LOGCATEGORYCONFIGMAP_ENTRY._options = None
  _LOGCATEGORYCONFIGMAP_ENTRY._serialized_options = b'\372\370\263\007\030\322\363\263\007\001*\322\363\263\007\r!json_gateway'
  _LOGCATEGORYCONFIGMAP._options = None
  _LOGCATEGORYCONFIGMAP._serialized_options = b'\372\370\263\007\217\002\312\363\263\007\361\001\352\363\263\007\027log_category_config_map\362\363\263\007\032\n\002go\022\024LogCategoryConfigMap\362\363\263\007\"\n\ngo_private\022\024LogCategoryConfigMap\362\363\263\007$\n\014go_terraform\022\024LogCategoryConfigMap\362\363\263\0070\n\004java\022(java.util.Map<String, LogCategoryConfig>\362\363\263\007,\n\014json_gateway\022\034map[string]LogCategoryConfig\322\363\263\007\001*\322\363\263\007\r!json_gateway'
  _LOGCATEGORYCONFIG.fields_by_name['remote_encoder']._options = None
  _LOGCATEGORYCONFIG.fields_by_name['remote_encoder']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCATEGORYCONFIG.fields_by_name['remote_discard_replays']._options = None
  _LOGCATEGORYCONFIG.fields_by_name['remote_discard_replays']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _LOGCATEGORYCONFIG._options = None
  _LOGCATEGORYCONFIG._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ORGANIZATIONHISTORY._options = None
  _ORGANIZATIONHISTORY._serialized_options = b'\312\371\263\007\036\302\371\263\007\031OrganizationHistoryRecord\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _ORGANIZATIONHISTORY.methods_by_name['List']._options = None
  _ORGANIZATIONHISTORY.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/organization-history'
  _ORGANIZATIONHISTORYLISTREQUEST._serialized_start=127
  _ORGANIZATIONHISTORYLISTREQUEST._serialized_end=268
  _ORGANIZATIONHISTORYLISTRESPONSE._serialized_start=271
  _ORGANIZATIONHISTORYLISTRESPONSE._serialized_end=535
  _ORGANIZATIONHISTORYRECORD._serialized_start=538
  _ORGANIZATIONHISTORYRECORD._serialized_end=761
  _ORGANIZATION._serialized_start=764
  _ORGANIZATION._serialized_end=2461
  _LOGCONFIG._serialized_start=2464
  _LOGCONFIG._serialized_end=2790
  _LOGCATEGORYCONFIGMAP._serialized_start=2793
  _LOGCATEGORYCONFIGMAP._serialized_end=3237
  _LOGCATEGORYCONFIGMAP_ENTRY._serialized_start=2866
  _LOGCATEGORYCONFIGMAP_ENTRY._serialized_end=2957
  _LOGCATEGORYCONFIG._serialized_start=3239
  _LOGCATEGORYCONFIG._serialized_end=3350
  _ORGANIZATIONHISTORY._serialized_start=3353
  _ORGANIZATIONHISTORY._serialized_end=3592
# @@protoc_insertion_point(module_scope)
