# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups_roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12groups_roles.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x8a\x01\n\x16GroupRoleCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12-\n\ngroup_role\x18\x02 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc3\x01\n\x17GroupRoleCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12-\n\ngroup_role\x18\x02 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"m\n\x13GroupRoleGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc9\x01\n\x14GroupRoleGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\ngroup_role\x18\x02 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"s\n\x16GroupRoleDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xcf\x01\n\x17GroupRoleDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12-\n\ngroup_role\x18\x03 \x01(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"s\n\x14GroupRoleListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc1\x01\n\x15GroupRoleListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12/\n\x0cgroups_roles\x18\x02 \x03(\x0b\x32\r.v1.GroupRoleB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc6\x02\n\tGroupRole\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\x08group_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07role_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x32\n\ngroup_name\x18\x04 \x01(\tB\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\x12\x36\n\trole_name\x18\x05 \x01(\tB#\xf2\xf8\xb3\x07\x1e\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\ngo_private\xd0\xf4\xb3\x07\x01:p\xfa\xf8\xb3\x07k\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07S\xa2\xf3\xb3\x07#tf_examples/group_role_resource.txt\xaa\xf3\xb3\x07&tf_examples/group_role_data_source.txt\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\xf4\x03\n\x0bGroupsRoles\x12j\n\x06\x43reate\x12\x1a.v1.GroupRoleCreateRequest\x1a\x1b.v1.GroupRoleCreateResponse\"\'\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groupsroles\x12\x65\n\x03Get\x12\x17.v1.GroupRoleGetRequest\x1a\x18.v1.GroupRoleGetResponse\"+\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/groupsroles/{id}\x12q\n\x06\x44\x65lete\x12\x1a.v1.GroupRoleDeleteRequest\x1a\x1b.v1.GroupRoleDeleteResponse\".\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x19\xaa\xf3\xb3\x07\x14/v1/groupsroles/{id}\x12\x63\n\x04List\x12\x18.v1.GroupRoleListRequest\x1a\x19.v1.GroupRoleListResponse\"&\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groupsroles\x1a:\xca\xf9\xb3\x07+\xc2\xf9\xb3\x07\tGroupRole\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\ngrouprole-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x7f\n\x19\x63om.strongdm.api.plumbingB\x13GroupsRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_GROUPROLECREATEREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleCreateRequest']
_GROUPROLECREATERESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleCreateResponse']
_GROUPROLEGETREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleGetRequest']
_GROUPROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleGetResponse']
_GROUPROLEDELETEREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleDeleteRequest']
_GROUPROLEDELETERESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleDeleteResponse']
_GROUPROLELISTREQUEST = DESCRIPTOR.message_types_by_name['GroupRoleListRequest']
_GROUPROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['GroupRoleListResponse']
_GROUPROLE = DESCRIPTOR.message_types_by_name['GroupRole']
GroupRoleCreateRequest = _reflection.GeneratedProtocolMessageType('GroupRoleCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLECREATEREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleCreateRequest)
  })
_sym_db.RegisterMessage(GroupRoleCreateRequest)

GroupRoleCreateResponse = _reflection.GeneratedProtocolMessageType('GroupRoleCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLECREATERESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleCreateResponse)
  })
_sym_db.RegisterMessage(GroupRoleCreateResponse)

GroupRoleGetRequest = _reflection.GeneratedProtocolMessageType('GroupRoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEGETREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleGetRequest)
  })
_sym_db.RegisterMessage(GroupRoleGetRequest)

GroupRoleGetResponse = _reflection.GeneratedProtocolMessageType('GroupRoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEGETRESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleGetResponse)
  })
_sym_db.RegisterMessage(GroupRoleGetResponse)

GroupRoleDeleteRequest = _reflection.GeneratedProtocolMessageType('GroupRoleDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEDELETEREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleDeleteRequest)
  })
_sym_db.RegisterMessage(GroupRoleDeleteRequest)

GroupRoleDeleteResponse = _reflection.GeneratedProtocolMessageType('GroupRoleDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLEDELETERESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleDeleteResponse)
  })
_sym_db.RegisterMessage(GroupRoleDeleteResponse)

GroupRoleListRequest = _reflection.GeneratedProtocolMessageType('GroupRoleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLELISTREQUEST,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleListRequest)
  })
_sym_db.RegisterMessage(GroupRoleListRequest)

GroupRoleListResponse = _reflection.GeneratedProtocolMessageType('GroupRoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLELISTRESPONSE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRoleListResponse)
  })
_sym_db.RegisterMessage(GroupRoleListResponse)

GroupRole = _reflection.GeneratedProtocolMessageType('GroupRole', (_message.Message,), {
  'DESCRIPTOR' : _GROUPROLE,
  '__module__' : 'groups_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupRole)
  })
_sym_db.RegisterMessage(GroupRole)

_GROUPSROLES = DESCRIPTOR.services_by_name['GroupsRoles']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\023GroupsRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _GROUPROLECREATEREQUEST.fields_by_name['group_role']._options = None
  _GROUPROLECREATEREQUEST.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLECREATEREQUEST._options = None
  _GROUPROLECREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLECREATERESPONSE.fields_by_name['group_role']._options = None
  _GROUPROLECREATERESPONSE.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLECREATERESPONSE._options = None
  _GROUPROLECREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEGETREQUEST.fields_by_name['id']._options = None
  _GROUPROLEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETREQUEST._options = None
  _GROUPROLEGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEGETRESPONSE.fields_by_name['meta']._options = None
  _GROUPROLEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETRESPONSE.fields_by_name['group_role']._options = None
  _GROUPROLEGETRESPONSE.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEGETRESPONSE._options = None
  _GROUPROLEGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEDELETEREQUEST.fields_by_name['id']._options = None
  _GROUPROLEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETEREQUEST._options = None
  _GROUPROLEDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLEDELETERESPONSE.fields_by_name['meta']._options = None
  _GROUPROLEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETERESPONSE.fields_by_name['group_role']._options = None
  _GROUPROLEDELETERESPONSE.fields_by_name['group_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLEDELETERESPONSE._options = None
  _GROUPROLEDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLELISTREQUEST.fields_by_name['filter']._options = None
  _GROUPROLELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLELISTREQUEST._options = None
  _GROUPROLELISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLELISTRESPONSE.fields_by_name['groups_roles']._options = None
  _GROUPROLELISTRESPONSE.fields_by_name['groups_roles']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _GROUPROLELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPROLELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLELISTRESPONSE._options = None
  _GROUPROLELISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPROLE.fields_by_name['id']._options = None
  _GROUPROLE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPROLE.fields_by_name['group_id']._options = None
  _GROUPROLE.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GROUPROLE.fields_by_name['role_id']._options = None
  _GROUPROLE.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GROUPROLE.fields_by_name['group_name']._options = None
  _GROUPROLE.fields_by_name['group_name']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private'
  _GROUPROLE.fields_by_name['role_name']._options = None
  _GROUPROLE.fields_by_name['role_name']._serialized_options = b'\362\370\263\007\036\260\363\263\007\001\230\364\263\007\001\262\364\263\007\ngo_private\320\364\263\007\001'
  _GROUPROLE._options = None
  _GROUPROLE._serialized_options = b'\372\370\263\007k\250\363\263\007\001\302\363\263\007S\242\363\263\007#tf_examples/group_role_resource.txt\252\363\263\007&tf_examples/group_role_data_source.txt\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPSROLES._options = None
  _GROUPSROLES._serialized_options = b'\312\371\263\007+\302\371\263\007\tGroupRole\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\ngrouprole-\312\371\263\007\005\350\371\263\007\001'
  _GROUPSROLES.methods_by_name['Create']._options = None
  _GROUPSROLES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\024\252\363\263\007\017/v1/groupsroles'
  _GROUPSROLES.methods_by_name['Get']._options = None
  _GROUPSROLES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\031\252\363\263\007\024/v1/groupsroles/{id}'
  _GROUPSROLES.methods_by_name['Delete']._options = None
  _GROUPSROLES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\031\252\363\263\007\024/v1/groupsroles/{id}'
  _GROUPSROLES.methods_by_name['List']._options = None
  _GROUPSROLES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\024\252\363\263\007\017/v1/groupsroles'
  _GROUPROLECREATEREQUEST._serialized_start=54
  _GROUPROLECREATEREQUEST._serialized_end=192
  _GROUPROLECREATERESPONSE._serialized_start=195
  _GROUPROLECREATERESPONSE._serialized_end=390
  _GROUPROLEGETREQUEST._serialized_start=392
  _GROUPROLEGETREQUEST._serialized_end=501
  _GROUPROLEGETRESPONSE._serialized_start=504
  _GROUPROLEGETRESPONSE._serialized_end=705
  _GROUPROLEDELETEREQUEST._serialized_start=707
  _GROUPROLEDELETEREQUEST._serialized_end=822
  _GROUPROLEDELETERESPONSE._serialized_start=825
  _GROUPROLEDELETERESPONSE._serialized_end=1032
  _GROUPROLELISTREQUEST._serialized_start=1034
  _GROUPROLELISTREQUEST._serialized_end=1149
  _GROUPROLELISTRESPONSE._serialized_start=1152
  _GROUPROLELISTRESPONSE._serialized_end=1345
  _GROUPROLE._serialized_start=1348
  _GROUPROLE._serialized_end=1674
  _GROUPSROLES._serialized_start=1677
  _GROUPSROLES._serialized_end=2177
# @@protoc_insertion_point(module_scope)
