# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0broles.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\ntags.proto\"`\n\x11RoleCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x12RoleCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"N\n\x0eRoleGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcd\x01\n\x0fRoleGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"l\n\x11RoleUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\"\n\x04role\x18\x03 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x12RoleUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x11RoleDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xaf\x01\n\x12RoleDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"T\n\x0fRoleListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb8\x01\n\x10RoleListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12#\n\x05roles\x18\x02 \x03(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\xd9\x03\n\x04Role\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x04 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\xf2\x01\n\x0c\x61\x63\x63\x65ss_rules\x18\x05 \x01(\tB\xdb\x01\xf2\xf8\xb3\x07\xd5\x01\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\xa9\x01\xea\xf3\xb3\x07\x0c\x61\x63\x63\x65ss_rules\xf2\xf3\xb3\x07\x11\n\x02go\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x19\n\ngo_private\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x1b\n\x0cgo_terraform\x12\x0b\x41\x63\x63\x65ssRules\xf2\xf3\xb3\x07\x18\n\x04java\x12\x10List<AccessRule>\xf2\xf3\xb3\x07\"\n\x0cjson_gateway\x12\x12models.AccessRules\xba\xf4\xb3\x07\x17\x61\x63\x63\x65ssRulesDiffSuppress\xd0\xf4\xb3\x07\x01\x12#\n\nmanaged_by\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01:V\xfa\xf8\xb3\x07Q\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07G\xa2\xf3\xb3\x07\x1dtf_examples/role_resource.txt\xaa\xf3\xb3\x07 tf_examples/role_data_source.txtJ\x04\x08\x03\x10\x04\x32\xee\x03\n\x05Roles\x12Z\n\x06\x43reate\x12\x15.v1.RoleCreateRequest\x1a\x16.v1.RoleCreateResponse\"!\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/roles\x12U\n\x03Get\x12\x12.v1.RoleGetRequest\x1a\x13.v1.RoleGetResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/roles/{id}\x12^\n\x06Update\x12\x15.v1.RoleUpdateRequest\x1a\x16.v1.RoleUpdateResponse\"%\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/roles/{id}\x12\x61\n\x06\x44\x65lete\x12\x15.v1.RoleDeleteRequest\x1a\x16.v1.RoleDeleteResponse\"(\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x13\xaa\xf3\xb3\x07\x0e/v1/roles/{id}\x12S\n\x04List\x12\x13.v1.RoleListRequest\x1a\x14.v1.RoleListResponse\" \x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x0e\xaa\xf3\xb3\x07\t/v1/roles\x1a\x1a\xca\xf9\xb3\x07\t\xc2\xf9\xb3\x07\x04Role\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02r-Ba\n\x19\x63om.strongdm.api.plumbingB\rRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_ROLECREATEREQUEST = DESCRIPTOR.message_types_by_name['RoleCreateRequest']
_ROLECREATERESPONSE = DESCRIPTOR.message_types_by_name['RoleCreateResponse']
_ROLEGETREQUEST = DESCRIPTOR.message_types_by_name['RoleGetRequest']
_ROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['RoleGetResponse']
_ROLEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['RoleUpdateRequest']
_ROLEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['RoleUpdateResponse']
_ROLEDELETEREQUEST = DESCRIPTOR.message_types_by_name['RoleDeleteRequest']
_ROLEDELETERESPONSE = DESCRIPTOR.message_types_by_name['RoleDeleteResponse']
_ROLELISTREQUEST = DESCRIPTOR.message_types_by_name['RoleListRequest']
_ROLELISTRESPONSE = DESCRIPTOR.message_types_by_name['RoleListResponse']
_ROLE = DESCRIPTOR.message_types_by_name['Role']
RoleCreateRequest = _reflection.GeneratedProtocolMessageType('RoleCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLECREATEREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleCreateRequest)
  })
_sym_db.RegisterMessage(RoleCreateRequest)

RoleCreateResponse = _reflection.GeneratedProtocolMessageType('RoleCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLECREATERESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleCreateResponse)
  })
_sym_db.RegisterMessage(RoleCreateResponse)

RoleGetRequest = _reflection.GeneratedProtocolMessageType('RoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEGETREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleGetRequest)
  })
_sym_db.RegisterMessage(RoleGetRequest)

RoleGetResponse = _reflection.GeneratedProtocolMessageType('RoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLEGETRESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleGetResponse)
  })
_sym_db.RegisterMessage(RoleGetResponse)

RoleUpdateRequest = _reflection.GeneratedProtocolMessageType('RoleUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEUPDATEREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleUpdateRequest)
  })
_sym_db.RegisterMessage(RoleUpdateRequest)

RoleUpdateResponse = _reflection.GeneratedProtocolMessageType('RoleUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLEUPDATERESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleUpdateResponse)
  })
_sym_db.RegisterMessage(RoleUpdateResponse)

RoleDeleteRequest = _reflection.GeneratedProtocolMessageType('RoleDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLEDELETEREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleDeleteRequest)
  })
_sym_db.RegisterMessage(RoleDeleteRequest)

RoleDeleteResponse = _reflection.GeneratedProtocolMessageType('RoleDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLEDELETERESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleDeleteResponse)
  })
_sym_db.RegisterMessage(RoleDeleteResponse)

RoleListRequest = _reflection.GeneratedProtocolMessageType('RoleListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLELISTREQUEST,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleListRequest)
  })
_sym_db.RegisterMessage(RoleListRequest)

RoleListResponse = _reflection.GeneratedProtocolMessageType('RoleListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLELISTRESPONSE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleListResponse)
  })
_sym_db.RegisterMessage(RoleListResponse)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.Role)
  })
_sym_db.RegisterMessage(Role)

_ROLES = DESCRIPTOR.services_by_name['Roles']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\rRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _ROLECREATEREQUEST.fields_by_name['role']._options = None
  _ROLECREATEREQUEST.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLECREATERESPONSE.fields_by_name['meta']._options = None
  _ROLECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLECREATERESPONSE.fields_by_name['role']._options = None
  _ROLECREATERESPONSE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _ROLECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLECREATERESPONSE._options = None
  _ROLECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLEGETREQUEST.fields_by_name['id']._options = None
  _ROLEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEGETRESPONSE.fields_by_name['meta']._options = None
  _ROLEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEGETRESPONSE.fields_by_name['role']._options = None
  _ROLEGETRESPONSE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ROLEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLEGETRESPONSE._options = None
  _ROLEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLEUPDATEREQUEST.fields_by_name['role']._options = None
  _ROLEUPDATEREQUEST.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEUPDATERESPONSE.fields_by_name['meta']._options = None
  _ROLEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEUPDATERESPONSE.fields_by_name['role']._options = None
  _ROLEUPDATERESPONSE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _ROLEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLEUPDATERESPONSE._options = None
  _ROLEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLEDELETEREQUEST.fields_by_name['id']._options = None
  _ROLEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEDELETERESPONSE.fields_by_name['meta']._options = None
  _ROLEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _ROLEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLEDELETERESPONSE._options = None
  _ROLEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ROLELISTREQUEST.fields_by_name['filter']._options = None
  _ROLELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLELISTRESPONSE.fields_by_name['roles']._options = None
  _ROLELISTRESPONSE.fields_by_name['roles']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ROLELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ROLELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLE.fields_by_name['id']._options = None
  _ROLE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLE.fields_by_name['name']._options = None
  _ROLE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ROLE.fields_by_name['tags']._options = None
  _ROLE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLE.fields_by_name['access_rules']._options = None
  _ROLE.fields_by_name['access_rules']._serialized_options = b'\362\370\263\007\325\001\260\363\263\007\001\312\363\263\007\251\001\352\363\263\007\014access_rules\362\363\263\007\021\n\002go\022\013AccessRules\362\363\263\007\031\n\ngo_private\022\013AccessRules\362\363\263\007\033\n\014go_terraform\022\013AccessRules\362\363\263\007\030\n\004java\022\020List<AccessRule>\362\363\263\007\"\n\014json_gateway\022\022models.AccessRules\272\364\263\007\027accessRulesDiffSuppress\320\364\263\007\001'
  _ROLE.fields_by_name['managed_by']._options = None
  _ROLE.fields_by_name['managed_by']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _ROLE._options = None
  _ROLE._serialized_options = b'\372\370\263\007Q\250\363\263\007\001\302\363\263\007G\242\363\263\007\035tf_examples/role_resource.txt\252\363\263\007 tf_examples/role_data_source.txt'
  _ROLES._options = None
  _ROLES._serialized_options = b'\312\371\263\007\t\302\371\263\007\004Role\312\371\263\007\007\322\371\263\007\002r-'
  _ROLES.methods_by_name['Create']._options = None
  _ROLES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\016\252\363\263\007\t/v1/roles'
  _ROLES.methods_by_name['Get']._options = None
  _ROLES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\023\252\363\263\007\016/v1/roles/{id}'
  _ROLES.methods_by_name['Update']._options = None
  _ROLES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\023\252\363\263\007\016/v1/roles/{id}'
  _ROLES.methods_by_name['Delete']._options = None
  _ROLES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\023\252\363\263\007\016/v1/roles/{id}'
  _ROLES.methods_by_name['List']._options = None
  _ROLES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\016\252\363\263\007\t/v1/roles'
  _ROLECREATEREQUEST._serialized_start=58
  _ROLECREATEREQUEST._serialized_end=154
  _ROLECREATERESPONSE._serialized_start=157
  _ROLECREATERESPONSE._serialized_end=368
  _ROLEGETREQUEST._serialized_start=370
  _ROLEGETREQUEST._serialized_end=448
  _ROLEGETRESPONSE._serialized_start=451
  _ROLEGETRESPONSE._serialized_end=656
  _ROLEUPDATEREQUEST._serialized_start=658
  _ROLEUPDATEREQUEST._serialized_end=766
  _ROLEUPDATERESPONSE._serialized_start=769
  _ROLEUPDATERESPONSE._serialized_end=980
  _ROLEDELETEREQUEST._serialized_start=982
  _ROLEDELETEREQUEST._serialized_end=1066
  _ROLEDELETERESPONSE._serialized_start=1069
  _ROLEDELETERESPONSE._serialized_end=1244
  _ROLELISTREQUEST._serialized_start=1246
  _ROLELISTREQUEST._serialized_end=1330
  _ROLELISTRESPONSE._serialized_start=1333
  _ROLELISTRESPONSE._serialized_end=1517
  _ROLE._serialized_start=1520
  _ROLE._serialized_end=1993
  _ROLES._serialized_start=1996
  _ROLES._serialized_end=2490
# @@protoc_insertion_point(module_scope)
