# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: custom_headers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63ustom_headers.proto\x12\x02v1\x1a\roptions.proto\"W\n\rCustomHeaders\x12\x34\n\x0e\x63ustom_headers\x18\x01 \x03(\x0b\x32\x10.v1.CustomHeaderB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x10\xfa\xf8\xb3\x07\x0b\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\"k\n\x0c\x43ustomHeader\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05value\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06secret\x18\x03 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15\x43ustomHeadersPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_CUSTOMHEADERS = DESCRIPTOR.message_types_by_name['CustomHeaders']
_CUSTOMHEADER = DESCRIPTOR.message_types_by_name['CustomHeader']
CustomHeaders = _reflection.GeneratedProtocolMessageType('CustomHeaders', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMHEADERS,
  '__module__' : 'custom_headers_pb2'
  # @@protoc_insertion_point(class_scope:v1.CustomHeaders)
  })
_sym_db.RegisterMessage(CustomHeaders)

CustomHeader = _reflection.GeneratedProtocolMessageType('CustomHeader', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMHEADER,
  '__module__' : 'custom_headers_pb2'
  # @@protoc_insertion_point(class_scope:v1.CustomHeader)
  })
_sym_db.RegisterMessage(CustomHeader)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025CustomHeadersPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _CUSTOMHEADERS.fields_by_name['custom_headers']._options = None
  _CUSTOMHEADERS.fields_by_name['custom_headers']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADERS._options = None
  _CUSTOMHEADERS._serialized_options = b'\372\370\263\007\013\250\363\263\007\001\322\363\263\007\001*'
  _CUSTOMHEADER.fields_by_name['name']._options = None
  _CUSTOMHEADER.fields_by_name['name']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADER.fields_by_name['value']._options = None
  _CUSTOMHEADER.fields_by_name['value']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADER.fields_by_name['secret']._options = None
  _CUSTOMHEADER.fields_by_name['secret']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _CUSTOMHEADER._options = None
  _CUSTOMHEADER._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _CUSTOMHEADERS._serialized_start=43
  _CUSTOMHEADERS._serialized_end=130
  _CUSTOMHEADER._serialized_start=132
  _CUSTOMHEADER._serialized_end=239
# @@protoc_insertion_point(module_scope)
