# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: health_checks.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13health_checks.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"\x85\x01\n\x16HealthcheckListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x81\x02\n\x17HealthcheckListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x31\n\x0chealthchecks\x18\x02 \x03(\x0b\x32\x0f.v1.HealthcheckB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xf3\x02\n\x0bHealthcheck\x12\x1b\n\x02id\x18\x01 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12&\n\rresource_name\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07node_id\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\tnode_name\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07healthy\x18\x06 \x01(\x08\x42\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1d\n\terror_msg\x18\x07 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12>\n\ttimestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xc1\x01\n\x0cHealthChecks\x12h\n\x04List\x12\x1a.v1.HealthcheckListRequest\x1a\x1b.v1.HealthcheckListResponse\"\'\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x15\xaa\xf3\xb3\x07\x10/v1/healthchecks\x1aG\xca\xf9\xb3\x07\x10\xc2\xf9\xb3\x07\x0bHealthcheck\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x90\x01\n\x19\x63om.strongdm.api.plumbingB\x14HealthChecksPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_HEALTHCHECKLISTREQUEST = DESCRIPTOR.message_types_by_name['HealthcheckListRequest']
_HEALTHCHECKLISTRESPONSE = DESCRIPTOR.message_types_by_name['HealthcheckListResponse']
_HEALTHCHECK = DESCRIPTOR.message_types_by_name['Healthcheck']
HealthcheckListRequest = _reflection.GeneratedProtocolMessageType('HealthcheckListRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKLISTREQUEST,
  '__module__' : 'health_checks_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckListRequest)
  })
_sym_db.RegisterMessage(HealthcheckListRequest)

HealthcheckListResponse = _reflection.GeneratedProtocolMessageType('HealthcheckListResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKLISTRESPONSE,
  '__module__' : 'health_checks_pb2'
  # @@protoc_insertion_point(class_scope:v1.HealthcheckListResponse)
  })
_sym_db.RegisterMessage(HealthcheckListResponse)

Healthcheck = _reflection.GeneratedProtocolMessageType('Healthcheck', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'health_checks_pb2'
  # @@protoc_insertion_point(class_scope:v1.Healthcheck)
  })
_sym_db.RegisterMessage(Healthcheck)

_HEALTHCHECKS = DESCRIPTOR.services_by_name['HealthChecks']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\024HealthChecksPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _HEALTHCHECKLISTREQUEST.fields_by_name['filter']._options = None
  _HEALTHCHECKLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECKLISTREQUEST._options = None
  _HEALTHCHECKLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _HEALTHCHECKLISTRESPONSE.fields_by_name['healthchecks']._options = None
  _HEALTHCHECKLISTRESPONSE.fields_by_name['healthchecks']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _HEALTHCHECKLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _HEALTHCHECKLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _HEALTHCHECKLISTRESPONSE._options = None
  _HEALTHCHECKLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _HEALTHCHECK.fields_by_name['id']._options = None
  _HEALTHCHECK.fields_by_name['id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['resource_id']._options = None
  _HEALTHCHECK.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['resource_name']._options = None
  _HEALTHCHECK.fields_by_name['resource_name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['node_id']._options = None
  _HEALTHCHECK.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['node_name']._options = None
  _HEALTHCHECK.fields_by_name['node_name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['healthy']._options = None
  _HEALTHCHECK.fields_by_name['healthy']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK.fields_by_name['error_msg']._options = None
  _HEALTHCHECK.fields_by_name['error_msg']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _HEALTHCHECK.fields_by_name['timestamp']._options = None
  _HEALTHCHECK.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _HEALTHCHECK._options = None
  _HEALTHCHECK._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _HEALTHCHECKS._options = None
  _HEALTHCHECKS._serialized_options = b'\312\371\263\007\020\302\371\263\007\013Healthcheck\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _HEALTHCHECKS.methods_by_name['List']._options = None
  _HEALTHCHECKS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\025\252\363\263\007\020/v1/healthchecks'
  _HEALTHCHECKLISTREQUEST._serialized_start=88
  _HEALTHCHECKLISTREQUEST._serialized_end=221
  _HEALTHCHECKLISTRESPONSE._serialized_start=224
  _HEALTHCHECKLISTRESPONSE._serialized_end=481
  _HEALTHCHECK._serialized_start=484
  _HEALTHCHECK._serialized_end=855
  _HEALTHCHECKS._serialized_start=858
  _HEALTHCHECKS._serialized_end=1051
# @@protoc_insertion_point(module_scope)
