# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: access_request_events_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import access_requests_pb2 as access__requests__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#access_request_events_history.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15\x61\x63\x63\x65ss_requests.proto\x1a\roptions.proto\x1a\nspec.proto\"\x93\x01\n$AccessRequestEventHistoryListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x8e\x02\n%AccessRequestEventHistoryListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12:\n\x07history\x18\x02 \x03(\x0b\x32\x1d.v1.AccessRequestEventHistoryB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xa9\x02\n\x19\x41\x63\x63\x65ssRequestEventHistory\x12\x1f\n\x0b\x61\x63tivity_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12@\n\x14\x61\x63\x63\x65ss_request_event\x18\x03 \x01(\x0b\x32\x16.v1.AccessRequestEventB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ndeleted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\x95\x02\n\x1a\x41\x63\x63\x65ssRequestEventsHistory\x12\x95\x01\n\x04List\x12(.v1.AccessRequestEventHistoryListRequest\x1a).v1.AccessRequestEventHistoryListResponse\"8\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07&\xaa\xf3\xb3\x07!/v1/access-request-events-history\x1a_\xca\xf9\xb3\x07\x1e\xc2\xf9\xb3\x07\x19\x41\x63\x63\x65ssRequestEventHistory\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-provider\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x9e\x01\n\x19\x63om.strongdm.api.plumbingB\"AccessRequestEventsHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ACCESSREQUESTEVENTHISTORYLISTREQUEST = DESCRIPTOR.message_types_by_name['AccessRequestEventHistoryListRequest']
_ACCESSREQUESTEVENTHISTORYLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccessRequestEventHistoryListResponse']
_ACCESSREQUESTEVENTHISTORY = DESCRIPTOR.message_types_by_name['AccessRequestEventHistory']
AccessRequestEventHistoryListRequest = _reflection.GeneratedProtocolMessageType('AccessRequestEventHistoryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENTHISTORYLISTREQUEST,
  '__module__' : 'access_request_events_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEventHistoryListRequest)
  })
_sym_db.RegisterMessage(AccessRequestEventHistoryListRequest)

AccessRequestEventHistoryListResponse = _reflection.GeneratedProtocolMessageType('AccessRequestEventHistoryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENTHISTORYLISTRESPONSE,
  '__module__' : 'access_request_events_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEventHistoryListResponse)
  })
_sym_db.RegisterMessage(AccessRequestEventHistoryListResponse)

AccessRequestEventHistory = _reflection.GeneratedProtocolMessageType('AccessRequestEventHistory', (_message.Message,), {
  'DESCRIPTOR' : _ACCESSREQUESTEVENTHISTORY,
  '__module__' : 'access_request_events_history_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccessRequestEventHistory)
  })
_sym_db.RegisterMessage(AccessRequestEventHistory)

_ACCESSREQUESTEVENTSHISTORY = DESCRIPTOR.services_by_name['AccessRequestEventsHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\"AccessRequestEventsHistoryPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST.fields_by_name['filter']._options = None
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._options = None
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['history']._options = None
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['history']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._options = None
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['activity_id']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['activity_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['timestamp']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['timestamp']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['access_request_event']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['access_request_event']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['deleted_at']._options = None
  _ACCESSREQUESTEVENTHISTORY.fields_by_name['deleted_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCESSREQUESTEVENTHISTORY._options = None
  _ACCESSREQUESTEVENTHISTORY._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCESSREQUESTEVENTSHISTORY._options = None
  _ACCESSREQUESTEVENTSHISTORY._serialized_options = b'\312\371\263\007\036\302\371\263\007\031AccessRequestEventHistory\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider\312\371\263\007\005\350\371\263\007\001'
  _ACCESSREQUESTEVENTSHISTORY.methods_by_name['List']._options = None
  _ACCESSREQUESTEVENTSHISTORY.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007&\252\363\263\007!/v1/access-request-events-history'
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._serialized_start=127
  _ACCESSREQUESTEVENTHISTORYLISTREQUEST._serialized_end=274
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._serialized_start=277
  _ACCESSREQUESTEVENTHISTORYLISTRESPONSE._serialized_end=547
  _ACCESSREQUESTEVENTHISTORY._serialized_start=550
  _ACCESSREQUESTEVENTHISTORY._serialized_end=847
  _ACCESSREQUESTEVENTSHISTORY._serialized_start=850
  _ACCESSREQUESTEVENTSHISTORY._serialized_end=1127
# @@protoc_insertion_point(module_scope)
