# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_engine_types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import tags_pb2 as tags__pb2
from . import secret_engine_policy_pb2 as secret__engine__policy__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19secret_engine_types.proto\x12\x02v1\x1a\roptions.proto\x1a\ntags.proto\x1a\x1asecret_engine_policy.proto\x1a\x1egoogle/protobuf/duration.proto\"\xf5\x04\n\x0cSecretEngine\x12q\n\x10\x61\x63tive_directory\x18\xcc\x02 \x01(\x0b\x32\x19.v1.ActiveDirectoryEngineB9\xf2\xf8\xb3\x07*\xca\xf3\xb3\x07%\xc2\xf4\xb3\x07 \n\x0cjson_gateway\x12\x10\x61\x63tive_directory\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12\\\n\tkey_value\x18\xcb\x02 \x01(\x0b\x32\x12.v1.KeyValueEngineB2\xf2\xf8\xb3\x07#\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tkey_value\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12Q\n\x05mysql\x18\xce\x02 \x01(\x0b\x32\x0f.v1.MysqlEngineB.\xf2\xf8\xb3\x07\x1f\xca\xf3\xb3\x07\x1a\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05mysql\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12Z\n\x08postgres\x18\xcd\x02 \x01(\x0b\x32\x12.v1.PostgresEngineB1\xf2\xf8\xb3\x07\"\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08postgres\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00\x12]\n\tsqlserver\x18\xcf\x02 \x01(\x0b\x32\x13.v1.SqlserverEngineB2\xf2\xf8\xb3\x07#\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tsqlserver\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01H\x00:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x42z\n\rsecret_engine\x12i\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04name\xaa\xf8\xb3\x07\t\xaa\xf8\xb3\x07\x04tags\xaa\xf8\xb3\x07\x14\xaa\xf8\xb3\x07\x0fsecret_store_id\xaa\xf8\xb3\x07\x1b\xaa\xf8\xb3\x07\x16secret_store_root_path\xaa\xf8\xb3\x07\x0f\xaa\xf8\xb3\x07\npublic_key\"\xe1\x0c\n\x15\x41\x63tiveDirectoryEngine\x12\x64\n\x0e\x61\x66ter_read_ttl\x18\xf4\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12?\n\x06\x62inddn\x18l \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06\x62inddn\x12\x43\n\x08\x62indpass\x18m \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x62indpass\x12\x44\n\x0b\x63\x65rtificate\x18k \x01(\tB/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0b\x63\x65rtificate\x12Q\n\x12\x63onnection_timeout\x18g \x01(\rB5\xf2\xf8\xb3\x07\x30\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07&\xc2\xf4\xb3\x07!\n\x0cjson_gateway\x12\x11\x63onnectionTimeout\x12`\n\x1a\x64o_not_validate_timestamps\x18\xf7\x07 \x01(\x08\x42;\xf2\xf8\xb3\x07\x36\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07,\xc2\xf4\xb3\x07\'\n\x0cjson_gateway\x12\x17\x64oNotValidateTimestamps\x12\x45\n\x0cinsecure_tls\x18j \x01(\x08\x42/\xf2\xf8\xb3\x07*\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07 \xc2\xf4\xb3\x07\x1b\n\x0cjson_gateway\x12\x0binsecureTls\x12p\n\x14max_backoff_duration\x18\xf8\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB6\xf2\xf8\xb3\x07\x31\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\'\xc2\xf4\xb3\x07\"\n\x0cjson_gateway\x12\x12maxBackoffDuration\x12S\n\x06policy\x18\xf6\x07 \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12K\n\x0frequest_timeout\x18h \x01(\rB2\xf2\xf8\xb3\x07-\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x0cjson_gateway\x12\x0erequestTimeout\x12?\n\tstart_tls\x18i \x01(\x08\x42,\xf2\xf8\xb3\x07\'\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08startTls\x12P\n\x03ttl\x18\xf5\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x41\n\tupndomain\x18\xf3\x07 \x01(\tB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1e\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tupndomain\x12\x39\n\x03url\x18\x66 \x01(\tB,\xf2\xf8\xb3\x07\'\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03url\x12;\n\x06userdn\x18\xf2\x07 \x01(\tB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06userdn\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:{\xfa\xf8\xb3\x07v\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07l\xc2\xf4\xb3\x07\x17\n\x03\x63li\x12\x10\x61\x63tive_directory\xc2\xf4\xb3\x07 \n\x0cjson_gateway\x12\x10\x61\x63tive_directory\xc2\xf4\xb3\x07&\n\x12terraform-provider\x12\x10\x61\x63tive_directory\"\xb5\x03\n\x0eKeyValueEngine\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:f\xfa\xf8\xb3\x07\x61\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07W\xc2\xf4\xb3\x07\x10\n\x03\x63li\x12\tkey_value\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tkey_value\xc2\xf4\xb3\x07\x1f\n\x12terraform-provider\x12\tkey_value\"\x92\t\n\x0bMysqlEngine\x12\x63\n\x0e\x61\x66ter_read_ttl\x18i \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12\x43\n\x08\x64\x61tabase\x18l \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x64\x61tabase\x12\x43\n\x08hostname\x18\x65 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08hostname\x12\x43\n\x08password\x18g \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08password\x12R\n\x06policy\x18k \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12;\n\x04port\x18h \x01(\rB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04port\x12\x34\n\x03tls\x18m \x01(\x08\x42\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03tls\x12K\n\x0ftls_skip_verify\x18\xf2\x07 \x01(\x08\x42\x31\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rtlsSkipVerify\x12O\n\x03ttl\x18j \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x43\n\x08username\x18\x66 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08username\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:h\xfa\xf8\xb3\x07\x63\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07Y\xc2\xf4\xb3\x07\x0c\n\x03\x63li\x12\x05mysql\xc2\xf4\xb3\x07\x15\n\x0cjson_gateway\x12\x05mysql\xc2\xf4\xb3\x07)\n\x12terraform-provider\x12\x13mysql_secret_engine\"\xd1\x08\n\x0ePostgresEngine\x12\x63\n\x0e\x61\x66ter_read_ttl\x18i \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12\x43\n\x08\x64\x61tabase\x18l \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x64\x61tabase\x12\x43\n\x08hostname\x18\x65 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08hostname\x12\x43\n\x08password\x18g \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08password\x12R\n\x06policy\x18k \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12;\n\x04port\x18h \x01(\rB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04port\x12\x34\n\x03tls\x18m \x01(\x08\x42\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03tls\x12O\n\x03ttl\x18j \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x43\n\x08username\x18\x66 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08username\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:q\xfa\xf8\xb3\x07l\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x62\xc2\xf4\xb3\x07\x0f\n\x03\x63li\x12\x08postgres\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08postgres\xc2\xf4\xb3\x07,\n\x12terraform-provider\x12\x16postgres_secret_engine\"\xa2\t\n\x0fSqlserverEngine\x12\x63\n\x0e\x61\x66ter_read_ttl\x18i \x01(\x0b\x32\x19.google.protobuf.DurationB0\xf2\xf8\xb3\x07+\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07!\xc2\xf4\xb3\x07\x1c\n\x0cjson_gateway\x12\x0c\x61\x66terReadTtl\x12\x43\n\x08\x64\x61tabase\x18l \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08\x64\x61tabase\x12\x43\n\x08hostname\x18\x65 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08hostname\x12\x43\n\x08password\x18g \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08password\x12R\n\x06policy\x18k \x01(\x0b\x32\x16.v1.SecretEnginePolicyB*\xf2\xf8\xb3\x07%\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1b\xc2\xf4\xb3\x07\x16\n\x0cjson_gateway\x12\x06policy\x12;\n\x04port\x18h \x01(\rB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x19\xc2\xf4\xb3\x07\x14\n\x0cjson_gateway\x12\x04port\x12\x34\n\x03tls\x18m \x01(\x08\x42\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03tls\x12K\n\x0ftls_skip_verify\x18\xf2\x07 \x01(\x08\x42\x31\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\"\xc2\xf4\xb3\x07\x1d\n\x0cjson_gateway\x12\rtlsSkipVerify\x12O\n\x03ttl\x18j \x01(\x0b\x32\x19.google.protobuf.DurationB\'\xf2\xf8\xb3\x07\"\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x18\xc2\xf4\xb3\x07\x13\n\x0cjson_gateway\x12\x03ttl\x12\x43\n\x08username\x18\x66 \x01(\tB1\xf2\xf8\xb3\x07,\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x1d\xc2\xf4\xb3\x07\x18\n\x0cjson_gateway\x12\x08username\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x04type\x18\x03 \x01(\tB\x13\xf2\xf8\xb3\x07\x0e\xb0\xf3\xb3\x07\x01\xb2\xf4\xb3\x07\x04!cli\x12(\n\x0fsecret_store_id\x18\x05 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12/\n\x16secret_store_root_path\x18\x06 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\"\n\x04tags\x18\x07 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x32\n\npublic_key\x18\x08 \x01(\x0c\x42\x1e\xf2\xf8\xb3\x07\x19\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli\x12.\n\x1akey_rotation_interval_days\x18\t \x01(\x05\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:t\xfa\xf8\xb3\x07o\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x65\xc2\xf4\xb3\x07\x10\n\x03\x63li\x12\tsqlserver\xc2\xf4\xb3\x07\x19\n\x0cjson_gateway\x12\tsqlserver\xc2\xf4\xb3\x07-\n\x12terraform-provider\x12\x17sqlserver_secret_engineBm\n\x19\x63om.strongdm.api.plumbingB\x19SecretEngineTypesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_SECRETENGINE = DESCRIPTOR.message_types_by_name['SecretEngine']
_ACTIVEDIRECTORYENGINE = DESCRIPTOR.message_types_by_name['ActiveDirectoryEngine']
_KEYVALUEENGINE = DESCRIPTOR.message_types_by_name['KeyValueEngine']
_MYSQLENGINE = DESCRIPTOR.message_types_by_name['MysqlEngine']
_POSTGRESENGINE = DESCRIPTOR.message_types_by_name['PostgresEngine']
_SQLSERVERENGINE = DESCRIPTOR.message_types_by_name['SqlserverEngine']
SecretEngine = _reflection.GeneratedProtocolMessageType('SecretEngine', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretEngine)
  })
_sym_db.RegisterMessage(SecretEngine)

ActiveDirectoryEngine = _reflection.GeneratedProtocolMessageType('ActiveDirectoryEngine', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVEDIRECTORYENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.ActiveDirectoryEngine)
  })
_sym_db.RegisterMessage(ActiveDirectoryEngine)

KeyValueEngine = _reflection.GeneratedProtocolMessageType('KeyValueEngine', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUEENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.KeyValueEngine)
  })
_sym_db.RegisterMessage(KeyValueEngine)

MysqlEngine = _reflection.GeneratedProtocolMessageType('MysqlEngine', (_message.Message,), {
  'DESCRIPTOR' : _MYSQLENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.MysqlEngine)
  })
_sym_db.RegisterMessage(MysqlEngine)

PostgresEngine = _reflection.GeneratedProtocolMessageType('PostgresEngine', (_message.Message,), {
  'DESCRIPTOR' : _POSTGRESENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.PostgresEngine)
  })
_sym_db.RegisterMessage(PostgresEngine)

SqlserverEngine = _reflection.GeneratedProtocolMessageType('SqlserverEngine', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVERENGINE,
  '__module__' : 'secret_engine_types_pb2'
  # @@protoc_insertion_point(class_scope:v1.SqlserverEngine)
  })
_sym_db.RegisterMessage(SqlserverEngine)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\031SecretEngineTypesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _SECRETENGINE.oneofs_by_name['secret_engine']._options = None
  _SECRETENGINE.oneofs_by_name['secret_engine']._serialized_options = b'\252\370\263\007\t\252\370\263\007\004name\252\370\263\007\t\252\370\263\007\004tags\252\370\263\007\024\252\370\263\007\017secret_store_id\252\370\263\007\033\252\370\263\007\026secret_store_root_path\252\370\263\007\017\252\370\263\007\npublic_key'
  _SECRETENGINE.fields_by_name['active_directory']._options = None
  _SECRETENGINE.fields_by_name['active_directory']._serialized_options = b'\362\370\263\007*\312\363\263\007%\302\364\263\007 \n\014json_gateway\022\020active_directory\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['key_value']._options = None
  _SECRETENGINE.fields_by_name['key_value']._serialized_options = b'\362\370\263\007#\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tkey_value\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['mysql']._options = None
  _SECRETENGINE.fields_by_name['mysql']._serialized_options = b'\362\370\263\007\037\312\363\263\007\032\302\364\263\007\025\n\014json_gateway\022\005mysql\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['postgres']._options = None
  _SECRETENGINE.fields_by_name['postgres']._serialized_options = b'\362\370\263\007\"\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010postgres\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE.fields_by_name['sqlserver']._options = None
  _SECRETENGINE.fields_by_name['sqlserver']._serialized_options = b'\362\370\263\007#\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tsqlserver\362\370\263\007\005\260\363\263\007\001'
  _SECRETENGINE._options = None
  _SECRETENGINE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['after_read_ttl']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _ACTIVEDIRECTORYENGINE.fields_by_name['binddn']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['binddn']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\300\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006binddn'
  _ACTIVEDIRECTORYENGINE.fields_by_name['bindpass']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['bindpass']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010bindpass'
  _ACTIVEDIRECTORYENGINE.fields_by_name['certificate']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['certificate']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013certificate'
  _ACTIVEDIRECTORYENGINE.fields_by_name['connection_timeout']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['connection_timeout']._serialized_options = b'\362\370\263\0070\260\363\263\007\001\312\363\263\007&\302\364\263\007!\n\014json_gateway\022\021connectionTimeout'
  _ACTIVEDIRECTORYENGINE.fields_by_name['do_not_validate_timestamps']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['do_not_validate_timestamps']._serialized_options = b'\362\370\263\0076\260\363\263\007\001\312\363\263\007,\302\364\263\007\'\n\014json_gateway\022\027doNotValidateTimestamps'
  _ACTIVEDIRECTORYENGINE.fields_by_name['insecure_tls']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['insecure_tls']._serialized_options = b'\362\370\263\007*\260\363\263\007\001\312\363\263\007 \302\364\263\007\033\n\014json_gateway\022\013insecureTls'
  _ACTIVEDIRECTORYENGINE.fields_by_name['max_backoff_duration']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['max_backoff_duration']._serialized_options = b'\362\370\263\0071\260\363\263\007\001\312\363\263\007\'\302\364\263\007\"\n\014json_gateway\022\022maxBackoffDuration'
  _ACTIVEDIRECTORYENGINE.fields_by_name['policy']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _ACTIVEDIRECTORYENGINE.fields_by_name['request_timeout']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['request_timeout']._serialized_options = b'\362\370\263\007-\260\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\014json_gateway\022\016requestTimeout'
  _ACTIVEDIRECTORYENGINE.fields_by_name['start_tls']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['start_tls']._serialized_options = b'\362\370\263\007\'\260\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010startTls'
  _ACTIVEDIRECTORYENGINE.fields_by_name['ttl']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _ACTIVEDIRECTORYENGINE.fields_by_name['upndomain']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['upndomain']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\312\363\263\007\036\302\364\263\007\031\n\014json_gateway\022\tupndomain'
  _ACTIVEDIRECTORYENGINE.fields_by_name['url']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['url']._serialized_options = b'\362\370\263\007\'\260\363\263\007\001\300\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003url'
  _ACTIVEDIRECTORYENGINE.fields_by_name['userdn']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['userdn']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006userdn'
  _ACTIVEDIRECTORYENGINE.fields_by_name['id']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['name']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['type']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_id']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_root_path']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['tags']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYENGINE.fields_by_name['public_key']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _ACTIVEDIRECTORYENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _ACTIVEDIRECTORYENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACTIVEDIRECTORYENGINE._options = None
  _ACTIVEDIRECTORYENGINE._serialized_options = b'\372\370\263\007v\250\363\263\007\001\312\363\263\007l\302\364\263\007\027\n\003cli\022\020active_directory\302\364\263\007 \n\014json_gateway\022\020active_directory\302\364\263\007&\n\022terraform-provider\022\020active_directory'
  _KEYVALUEENGINE.fields_by_name['id']._options = None
  _KEYVALUEENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['name']._options = None
  _KEYVALUEENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['type']._options = None
  _KEYVALUEENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _KEYVALUEENGINE.fields_by_name['secret_store_id']._options = None
  _KEYVALUEENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['secret_store_root_path']._options = None
  _KEYVALUEENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['tags']._options = None
  _KEYVALUEENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYVALUEENGINE.fields_by_name['public_key']._options = None
  _KEYVALUEENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _KEYVALUEENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _KEYVALUEENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _KEYVALUEENGINE._options = None
  _KEYVALUEENGINE._serialized_options = b'\372\370\263\007a\250\363\263\007\001\312\363\263\007W\302\364\263\007\020\n\003cli\022\tkey_value\302\364\263\007\031\n\014json_gateway\022\tkey_value\302\364\263\007\037\n\022terraform-provider\022\tkey_value'
  _MYSQLENGINE.fields_by_name['after_read_ttl']._options = None
  _MYSQLENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _MYSQLENGINE.fields_by_name['database']._options = None
  _MYSQLENGINE.fields_by_name['database']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010database'
  _MYSQLENGINE.fields_by_name['hostname']._options = None
  _MYSQLENGINE.fields_by_name['hostname']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010hostname'
  _MYSQLENGINE.fields_by_name['password']._options = None
  _MYSQLENGINE.fields_by_name['password']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010password'
  _MYSQLENGINE.fields_by_name['policy']._options = None
  _MYSQLENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _MYSQLENGINE.fields_by_name['port']._options = None
  _MYSQLENGINE.fields_by_name['port']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\300\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004port'
  _MYSQLENGINE.fields_by_name['tls']._options = None
  _MYSQLENGINE.fields_by_name['tls']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003tls'
  _MYSQLENGINE.fields_by_name['tls_skip_verify']._options = None
  _MYSQLENGINE.fields_by_name['tls_skip_verify']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rtlsSkipVerify'
  _MYSQLENGINE.fields_by_name['ttl']._options = None
  _MYSQLENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _MYSQLENGINE.fields_by_name['username']._options = None
  _MYSQLENGINE.fields_by_name['username']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010username'
  _MYSQLENGINE.fields_by_name['id']._options = None
  _MYSQLENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MYSQLENGINE.fields_by_name['name']._options = None
  _MYSQLENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MYSQLENGINE.fields_by_name['type']._options = None
  _MYSQLENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _MYSQLENGINE.fields_by_name['secret_store_id']._options = None
  _MYSQLENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MYSQLENGINE.fields_by_name['secret_store_root_path']._options = None
  _MYSQLENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _MYSQLENGINE.fields_by_name['tags']._options = None
  _MYSQLENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MYSQLENGINE.fields_by_name['public_key']._options = None
  _MYSQLENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _MYSQLENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _MYSQLENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _MYSQLENGINE._options = None
  _MYSQLENGINE._serialized_options = b'\372\370\263\007c\250\363\263\007\001\312\363\263\007Y\302\364\263\007\014\n\003cli\022\005mysql\302\364\263\007\025\n\014json_gateway\022\005mysql\302\364\263\007)\n\022terraform-provider\022\023mysql_secret_engine'
  _POSTGRESENGINE.fields_by_name['after_read_ttl']._options = None
  _POSTGRESENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _POSTGRESENGINE.fields_by_name['database']._options = None
  _POSTGRESENGINE.fields_by_name['database']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010database'
  _POSTGRESENGINE.fields_by_name['hostname']._options = None
  _POSTGRESENGINE.fields_by_name['hostname']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010hostname'
  _POSTGRESENGINE.fields_by_name['password']._options = None
  _POSTGRESENGINE.fields_by_name['password']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010password'
  _POSTGRESENGINE.fields_by_name['policy']._options = None
  _POSTGRESENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _POSTGRESENGINE.fields_by_name['port']._options = None
  _POSTGRESENGINE.fields_by_name['port']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\300\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004port'
  _POSTGRESENGINE.fields_by_name['tls']._options = None
  _POSTGRESENGINE.fields_by_name['tls']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003tls'
  _POSTGRESENGINE.fields_by_name['ttl']._options = None
  _POSTGRESENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _POSTGRESENGINE.fields_by_name['username']._options = None
  _POSTGRESENGINE.fields_by_name['username']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010username'
  _POSTGRESENGINE.fields_by_name['id']._options = None
  _POSTGRESENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['name']._options = None
  _POSTGRESENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['type']._options = None
  _POSTGRESENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _POSTGRESENGINE.fields_by_name['secret_store_id']._options = None
  _POSTGRESENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['secret_store_root_path']._options = None
  _POSTGRESENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['tags']._options = None
  _POSTGRESENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POSTGRESENGINE.fields_by_name['public_key']._options = None
  _POSTGRESENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _POSTGRESENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _POSTGRESENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POSTGRESENGINE._options = None
  _POSTGRESENGINE._serialized_options = b'\372\370\263\007l\250\363\263\007\001\312\363\263\007b\302\364\263\007\017\n\003cli\022\010postgres\302\364\263\007\030\n\014json_gateway\022\010postgres\302\364\263\007,\n\022terraform-provider\022\026postgres_secret_engine'
  _SQLSERVERENGINE.fields_by_name['after_read_ttl']._options = None
  _SQLSERVERENGINE.fields_by_name['after_read_ttl']._serialized_options = b'\362\370\263\007+\260\363\263\007\001\312\363\263\007!\302\364\263\007\034\n\014json_gateway\022\014afterReadTtl'
  _SQLSERVERENGINE.fields_by_name['database']._options = None
  _SQLSERVERENGINE.fields_by_name['database']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010database'
  _SQLSERVERENGINE.fields_by_name['hostname']._options = None
  _SQLSERVERENGINE.fields_by_name['hostname']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010hostname'
  _SQLSERVERENGINE.fields_by_name['password']._options = None
  _SQLSERVERENGINE.fields_by_name['password']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010password'
  _SQLSERVERENGINE.fields_by_name['policy']._options = None
  _SQLSERVERENGINE.fields_by_name['policy']._serialized_options = b'\362\370\263\007%\260\363\263\007\001\312\363\263\007\033\302\364\263\007\026\n\014json_gateway\022\006policy'
  _SQLSERVERENGINE.fields_by_name['port']._options = None
  _SQLSERVERENGINE.fields_by_name['port']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\300\363\263\007\001\312\363\263\007\031\302\364\263\007\024\n\014json_gateway\022\004port'
  _SQLSERVERENGINE.fields_by_name['tls']._options = None
  _SQLSERVERENGINE.fields_by_name['tls']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003tls'
  _SQLSERVERENGINE.fields_by_name['tls_skip_verify']._options = None
  _SQLSERVERENGINE.fields_by_name['tls_skip_verify']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\312\363\263\007\"\302\364\263\007\035\n\014json_gateway\022\rtlsSkipVerify'
  _SQLSERVERENGINE.fields_by_name['ttl']._options = None
  _SQLSERVERENGINE.fields_by_name['ttl']._serialized_options = b'\362\370\263\007\"\260\363\263\007\001\312\363\263\007\030\302\364\263\007\023\n\014json_gateway\022\003ttl'
  _SQLSERVERENGINE.fields_by_name['username']._options = None
  _SQLSERVERENGINE.fields_by_name['username']._serialized_options = b'\362\370\263\007,\260\363\263\007\001\300\363\263\007\001\312\363\263\007\035\302\364\263\007\030\n\014json_gateway\022\010username'
  _SQLSERVERENGINE.fields_by_name['id']._options = None
  _SQLSERVERENGINE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['name']._options = None
  _SQLSERVERENGINE.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['type']._options = None
  _SQLSERVERENGINE.fields_by_name['type']._serialized_options = b'\362\370\263\007\016\260\363\263\007\001\262\364\263\007\004!cli'
  _SQLSERVERENGINE.fields_by_name['secret_store_id']._options = None
  _SQLSERVERENGINE.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['secret_store_root_path']._options = None
  _SQLSERVERENGINE.fields_by_name['secret_store_root_path']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['tags']._options = None
  _SQLSERVERENGINE.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SQLSERVERENGINE.fields_by_name['public_key']._options = None
  _SQLSERVERENGINE.fields_by_name['public_key']._serialized_options = b'\362\370\263\007\031\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\004!cli'
  _SQLSERVERENGINE.fields_by_name['key_rotation_interval_days']._options = None
  _SQLSERVERENGINE.fields_by_name['key_rotation_interval_days']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SQLSERVERENGINE._options = None
  _SQLSERVERENGINE._serialized_options = b'\372\370\263\007o\250\363\263\007\001\312\363\263\007e\302\364\263\007\020\n\003cli\022\tsqlserver\302\364\263\007\031\n\014json_gateway\022\tsqlserver\302\364\263\007-\n\022terraform-provider\022\027sqlserver_secret_engine'
  _SECRETENGINE._serialized_start=121
  _SECRETENGINE._serialized_end=750
  _ACTIVEDIRECTORYENGINE._serialized_start=753
  _ACTIVEDIRECTORYENGINE._serialized_end=2386
  _KEYVALUEENGINE._serialized_start=2389
  _KEYVALUEENGINE._serialized_end=2826
  _MYSQLENGINE._serialized_start=2829
  _MYSQLENGINE._serialized_end=3999
  _POSTGRESENGINE._serialized_start=4002
  _POSTGRESENGINE._serialized_end=5107
  _SQLSERVERENGINE._serialized_start=5110
  _SQLSERVERENGINE._serialized_end=6296
# @@protoc_insertion_point(module_scope)
