# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret_store_healths.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1asecret_store_healths.proto\x12\x02v1\x1a\roptions.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\nspec.proto\"\x8b\x01\n\x1cSecretStoreHealthListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x95\x02\n\x1dSecretStoreHealthListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12?\n\x14secret_store_healths\x18\x02 \x03(\x0b\x32\x15.v1.SecretStoreHealthB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x83\x01\n\x1dSecretStoreHealthCheckRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12#\n\x0fsecret_store_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x14\xfa\xf8\xb3\x07\x0f\xd2\xf3\xb3\x07\ngo_private\"\x97\x01\n\x1dSecretStoreHealthcheckRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12#\n\x0fsecret_store_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xc3\x01\n\x1eSecretStoreHealthCheckResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\x1e\xfa\xf8\xb3\x07\x0f\xd2\xf3\xb3\x07\ngo_private\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd7\x01\n\x1eSecretStoreHealthcheckResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xfb\x02\n\x11SecretStoreHealth\x12#\n\x0fsecret_store_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07node_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06status\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nchanged_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\nchecked_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x65rror\x18\x08 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12 \n\x0creachability\x18\t \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05\x66lags\x18\n \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01J\x04\x08\x03\x10\x04\x32\x8d\x04\n\x12SecretStoreHealths\x12|\n\x04List\x12 .v1.SecretStoreHealthListRequest\x1a!.v1.SecretStoreHealthListResponse\"/\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/secret-store-healths\x12\x94\x01\n\x05\x43heck\x12!.v1.SecretStoreHealthCheckRequest\x1a\".v1.SecretStoreHealthCheckResponse\"D\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/secret-store-healths\x82\xf9\xb3\x07\x0f\xca\xf9\xb3\x07\ngo_private\x12\x86\x01\n\x0bHealthcheck\x12!.v1.SecretStoreHealthcheckRequest\x1a\".v1.SecretStoreHealthcheckResponse\"0\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1d\xaa\xf3\xb3\x07\x18/v1/secret-store-healths\x1aY\xca\xf9\xb3\x07\x16\xc2\xf9\xb3\x07\x11SecretStoreHealth\xca\xf9\xb3\x07\x07\xd2\xf9\xb3\x07\x02x-\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x96\x01\n\x19\x63om.strongdm.api.plumbingB\x1aSecretStoreHealthsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_SECRETSTOREHEALTHLISTREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreHealthListRequest']
_SECRETSTOREHEALTHLISTRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreHealthListResponse']
_SECRETSTOREHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreHealthCheckRequest']
_SECRETSTOREHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['SecretStoreHealthcheckRequest']
_SECRETSTOREHEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreHealthCheckResponse']
_SECRETSTOREHEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['SecretStoreHealthcheckResponse']
_SECRETSTOREHEALTH = DESCRIPTOR.message_types_by_name['SecretStoreHealth']
SecretStoreHealthListRequest = _reflection.GeneratedProtocolMessageType('SecretStoreHealthListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHLISTREQUEST,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthListRequest)
  })
_sym_db.RegisterMessage(SecretStoreHealthListRequest)

SecretStoreHealthListResponse = _reflection.GeneratedProtocolMessageType('SecretStoreHealthListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHLISTRESPONSE,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthListResponse)
  })
_sym_db.RegisterMessage(SecretStoreHealthListResponse)

SecretStoreHealthCheckRequest = _reflection.GeneratedProtocolMessageType('SecretStoreHealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKREQUEST,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthCheckRequest)
  })
_sym_db.RegisterMessage(SecretStoreHealthCheckRequest)

SecretStoreHealthcheckRequest = _reflection.GeneratedProtocolMessageType('SecretStoreHealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKREQUEST,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthcheckRequest)
  })
_sym_db.RegisterMessage(SecretStoreHealthcheckRequest)

SecretStoreHealthCheckResponse = _reflection.GeneratedProtocolMessageType('SecretStoreHealthCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKRESPONSE,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthCheckResponse)
  })
_sym_db.RegisterMessage(SecretStoreHealthCheckResponse)

SecretStoreHealthcheckResponse = _reflection.GeneratedProtocolMessageType('SecretStoreHealthcheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTHCHECKRESPONSE,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealthcheckResponse)
  })
_sym_db.RegisterMessage(SecretStoreHealthcheckResponse)

SecretStoreHealth = _reflection.GeneratedProtocolMessageType('SecretStoreHealth', (_message.Message,), {
  'DESCRIPTOR' : _SECRETSTOREHEALTH,
  '__module__' : 'secret_store_healths_pb2'
  # @@protoc_insertion_point(class_scope:v1.SecretStoreHealth)
  })
_sym_db.RegisterMessage(SecretStoreHealth)

_SECRETSTOREHEALTHS = DESCRIPTOR.services_by_name['SecretStoreHealths']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\032SecretStoreHealthsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _SECRETSTOREHEALTHLISTREQUEST.fields_by_name['filter']._options = None
  _SECRETSTOREHEALTHLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTHLISTREQUEST._options = None
  _SECRETSTOREHEALTHLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['secret_store_healths']._options = None
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['secret_store_healths']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREHEALTHLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREHEALTHLISTRESPONSE._options = None
  _SECRETSTOREHEALTHLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._options = None
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTHCHECKREQUEST._options = None
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\017\322\363\263\007\ngo_private'
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._options = None
  _SECRETSTOREHEALTHCHECKREQUEST.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTHCHECKREQUEST._options = None
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREHEALTHCHECKRESPONSE._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\017\322\363\263\007\ngo_private\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _SECRETSTOREHEALTHCHECKRESPONSE._options = None
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['secret_store_id']._options = None
  _SECRETSTOREHEALTH.fields_by_name['secret_store_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['node_id']._options = None
  _SECRETSTOREHEALTH.fields_by_name['node_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['status']._options = None
  _SECRETSTOREHEALTH.fields_by_name['status']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['changed_at']._options = None
  _SECRETSTOREHEALTH.fields_by_name['changed_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['checked_at']._options = None
  _SECRETSTOREHEALTH.fields_by_name['checked_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['error']._options = None
  _SECRETSTOREHEALTH.fields_by_name['error']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['reachability']._options = None
  _SECRETSTOREHEALTH.fields_by_name['reachability']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH.fields_by_name['flags']._options = None
  _SECRETSTOREHEALTH.fields_by_name['flags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _SECRETSTOREHEALTH._options = None
  _SECRETSTOREHEALTH._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider\372\370\263\007\005\250\363\263\007\001'
  _SECRETSTOREHEALTHS._options = None
  _SECRETSTOREHEALTHS._serialized_options = b'\312\371\263\007\026\302\371\263\007\021SecretStoreHealth\312\371\263\007\007\322\371\263\007\002x-\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _SECRETSTOREHEALTHS.methods_by_name['List']._options = None
  _SECRETSTOREHEALTHS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\035\252\363\263\007\030/v1/secret-store-healths'
  _SECRETSTOREHEALTHS.methods_by_name['Check']._options = None
  _SECRETSTOREHEALTHS.methods_by_name['Check']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\035\252\363\263\007\030/v1/secret-store-healths\202\371\263\007\017\312\371\263\007\ngo_private'
  _SECRETSTOREHEALTHS.methods_by_name['Healthcheck']._options = None
  _SECRETSTOREHEALTHS.methods_by_name['Healthcheck']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\035\252\363\263\007\030/v1/secret-store-healths'
  _SECRETSTOREHEALTHLISTREQUEST._serialized_start=95
  _SECRETSTOREHEALTHLISTREQUEST._serialized_end=234
  _SECRETSTOREHEALTHLISTRESPONSE._serialized_start=237
  _SECRETSTOREHEALTHLISTRESPONSE._serialized_end=514
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_start=517
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_end=648
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_start=651
  _SECRETSTOREHEALTHCHECKREQUEST._serialized_end=802
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_start=805
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_end=1000
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_start=1003
  _SECRETSTOREHEALTHCHECKRESPONSE._serialized_end=1218
  _SECRETSTOREHEALTH._serialized_start=1221
  _SECRETSTOREHEALTH._serialized_end=1600
  _SECRETSTOREHEALTHS._serialized_start=1603
  _SECRETSTOREHEALTHS._serialized_end=2128
# @@protoc_insertion_point(module_scope)
