# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: replays.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rreplays.proto\x12\x02v1\x1a\x1egoogle/protobuf/duration.proto\x1a\roptions.proto\x1a\nspec.proto\"\x80\x01\n\x11ReplayListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xec\x01\n\x12ReplayListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12+\n\x06\x63hunks\x18\x02 \x03(\x0b\x32\x0f.v1.ReplayChunkB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xb0\x01\n\x0bReplayChunk\x12\x18\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x30\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x14.v1.ReplayChunkEventB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12!\n\rsymmetric_key\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x99\x01\n\x10ReplayChunkEvent\x12\x18\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xad\x01\n\x07Replays\x12Y\n\x04List\x12\x15.v1.ReplayListRequest\x1a\x16.v1.ReplayListResponse\"\"\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x10\xaa\xf3\xb3\x07\x0b/v1/replays\x1aG\xca\xf9\xb3\x07\x10\xc2\xf9\xb3\x07\x0bReplayChunk\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x8b\x01\n\x19\x63om.strongdm.api.plumbingB\x0fReplaysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_REPLAYLISTREQUEST = DESCRIPTOR.message_types_by_name['ReplayListRequest']
_REPLAYLISTRESPONSE = DESCRIPTOR.message_types_by_name['ReplayListResponse']
_REPLAYCHUNK = DESCRIPTOR.message_types_by_name['ReplayChunk']
_REPLAYCHUNKEVENT = DESCRIPTOR.message_types_by_name['ReplayChunkEvent']
ReplayListRequest = _reflection.GeneratedProtocolMessageType('ReplayListRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYLISTREQUEST,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayListRequest)
  })
_sym_db.RegisterMessage(ReplayListRequest)

ReplayListResponse = _reflection.GeneratedProtocolMessageType('ReplayListResponse', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYLISTRESPONSE,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayListResponse)
  })
_sym_db.RegisterMessage(ReplayListResponse)

ReplayChunk = _reflection.GeneratedProtocolMessageType('ReplayChunk', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYCHUNK,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayChunk)
  })
_sym_db.RegisterMessage(ReplayChunk)

ReplayChunkEvent = _reflection.GeneratedProtocolMessageType('ReplayChunkEvent', (_message.Message,), {
  'DESCRIPTOR' : _REPLAYCHUNKEVENT,
  '__module__' : 'replays_pb2'
  # @@protoc_insertion_point(class_scope:v1.ReplayChunkEvent)
  })
_sym_db.RegisterMessage(ReplayChunkEvent)

_REPLAYS = DESCRIPTOR.services_by_name['Replays']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\017ReplaysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _REPLAYLISTREQUEST.fields_by_name['filter']._options = None
  _REPLAYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYLISTREQUEST._options = None
  _REPLAYLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYLISTRESPONSE.fields_by_name['chunks']._options = None
  _REPLAYLISTRESPONSE.fields_by_name['chunks']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _REPLAYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _REPLAYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _REPLAYLISTRESPONSE._options = None
  _REPLAYLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYCHUNK.fields_by_name['data']._options = None
  _REPLAYCHUNK.fields_by_name['data']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNK.fields_by_name['events']._options = None
  _REPLAYCHUNK.fields_by_name['events']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNK.fields_by_name['symmetric_key']._options = None
  _REPLAYCHUNK.fields_by_name['symmetric_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNK._options = None
  _REPLAYCHUNK._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYCHUNKEVENT.fields_by_name['data']._options = None
  _REPLAYCHUNKEVENT.fields_by_name['data']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNKEVENT.fields_by_name['duration']._options = None
  _REPLAYCHUNKEVENT.fields_by_name['duration']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _REPLAYCHUNKEVENT._options = None
  _REPLAYCHUNKEVENT._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _REPLAYS._options = None
  _REPLAYS._serialized_options = b'\312\371\263\007\020\302\371\263\007\013ReplayChunk\312\371\263\007\005\330\371\263\007\001\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _REPLAYS.methods_by_name['List']._options = None
  _REPLAYS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\020\252\363\263\007\013/v1/replays'
  _REPLAYLISTREQUEST._serialized_start=81
  _REPLAYLISTREQUEST._serialized_end=209
  _REPLAYLISTRESPONSE._serialized_start=212
  _REPLAYLISTRESPONSE._serialized_end=448
  _REPLAYCHUNK._serialized_start=451
  _REPLAYCHUNK._serialized_end=627
  _REPLAYCHUNKEVENT._serialized_start=630
  _REPLAYCHUNKEVENT._serialized_end=783
  _REPLAYS._serialized_start=786
  _REPLAYS._serialized_end=959
# @@protoc_insertion_point(module_scope)
