# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import accounts_pb2 as accounts__pb2
from . import approval_workflows_pb2 as approval__workflows__pb2
from . import options_pb2 as options__pb2
from . import roles_pb2 as roles__pb2
from . import spec_pb2 as spec__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cgroups.proto\x12\x02v1\x1a\x0e\x61\x63\x63ounts.proto\x1a\x18\x61pproval_workflows.proto\x1a\roptions.proto\x1a\x0broles.proto\x1a\nspec.proto\x1a\ntags.proto\"}\n\x12GroupCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xb6\x01\n\x13GroupCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x9a\x01\n\x1bGroupCreateFromRolesRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x1c\n\x08role_ids\x18\x02 \x03(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06\x63ommit\x18\x03 \x01(\x08\x42\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xd1\x01\n\x1cGroupCreateFromRolesResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x36\n\x0fgroup_from_role\x18\x03 \x03(\x0b\x32\x11.v1.GroupFromRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x8c\x02\n\rGroupFromRole\x12\x35\n\nrate_limit\x18\x01 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\"\n\x04role\x18\x02 \x01(\x0b\x32\x08.v1.RoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x05group\x18\x03 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x08\x61\x63\x63ounts\x18\x04 \x03(\x0b\x32\x08.v1.UserB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x38\n\x0e\x61pproval_flows\x18\x05 \x03(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"i\n\x0fGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xbc\x01\n\x10GroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x89\x01\n\x12GroupUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12$\n\x05group\x18\x03 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xb6\x01\n\x13GroupUpdateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12$\n\x05group\x18\x02 \x01(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"o\n\x12GroupDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x9c\x01\n\x13GroupDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"o\n\x10GroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xb3\x01\n\x11GroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12%\n\x06groups\x18\x02 \x03(\x0b\x32\t.v1.GroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\x8c\x02\n\x05Group\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x06source\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\x12\"\n\x04tags\x18\x05 \x01(\x0b\x32\x08.v1.TagsB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:f\xfa\xf8\xb3\x07\x61\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07I\xa2\xf3\xb3\x07\x1etf_examples/group_resource.txt\xaa\xf3\xb3\x07!tf_examples/group_data_source.txt\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\x9c\x05\n\x06Groups\x12]\n\x06\x43reate\x12\x16.v1.GroupCreateRequest\x1a\x17.v1.GroupCreateResponse\"\"\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x0f\xaa\xf3\xb3\x07\n/v1/groups\x12\x83\x01\n\x0f\x43reateFromRoles\x12\x1f.v1.GroupCreateFromRolesRequest\x1a .v1.GroupCreateFromRolesResponse\"-\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1a\xaa\xf3\xb3\x07\x15/v1/groups/from-roles\x12X\n\x03Get\x12\x13.v1.GroupGetRequest\x1a\x14.v1.GroupGetResponse\"&\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groups/{id}\x12\x61\n\x06Update\x12\x16.v1.GroupUpdateRequest\x1a\x17.v1.GroupUpdateResponse\"&\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groups/{id}\x12\x64\n\x06\x44\x65lete\x12\x16.v1.GroupDeleteRequest\x1a\x17.v1.GroupDeleteResponse\")\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x14\xaa\xf3\xb3\x07\x0f/v1/groups/{id}\x12V\n\x04List\x12\x14.v1.GroupListRequest\x1a\x15.v1.GroupListResponse\"!\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x0f\xaa\xf3\xb3\x07\n/v1/groups\x1a\x32\xca\xf9\xb3\x07#\xc2\xf9\xb3\x07\x05Group\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\x06group-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42z\n\x19\x63om.strongdm.api.plumbingB\x0eGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_GROUPCREATEREQUEST = DESCRIPTOR.message_types_by_name['GroupCreateRequest']
_GROUPCREATERESPONSE = DESCRIPTOR.message_types_by_name['GroupCreateResponse']
_GROUPCREATEFROMROLESREQUEST = DESCRIPTOR.message_types_by_name['GroupCreateFromRolesRequest']
_GROUPCREATEFROMROLESRESPONSE = DESCRIPTOR.message_types_by_name['GroupCreateFromRolesResponse']
_GROUPFROMROLE = DESCRIPTOR.message_types_by_name['GroupFromRole']
_GROUPGETREQUEST = DESCRIPTOR.message_types_by_name['GroupGetRequest']
_GROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['GroupGetResponse']
_GROUPUPDATEREQUEST = DESCRIPTOR.message_types_by_name['GroupUpdateRequest']
_GROUPUPDATERESPONSE = DESCRIPTOR.message_types_by_name['GroupUpdateResponse']
_GROUPDELETEREQUEST = DESCRIPTOR.message_types_by_name['GroupDeleteRequest']
_GROUPDELETERESPONSE = DESCRIPTOR.message_types_by_name['GroupDeleteResponse']
_GROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['GroupListRequest']
_GROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['GroupListResponse']
_GROUP = DESCRIPTOR.message_types_by_name['Group']
GroupCreateRequest = _reflection.GeneratedProtocolMessageType('GroupCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATEREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateRequest)
  })
_sym_db.RegisterMessage(GroupCreateRequest)

GroupCreateResponse = _reflection.GeneratedProtocolMessageType('GroupCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATERESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateResponse)
  })
_sym_db.RegisterMessage(GroupCreateResponse)

GroupCreateFromRolesRequest = _reflection.GeneratedProtocolMessageType('GroupCreateFromRolesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATEFROMROLESREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateFromRolesRequest)
  })
_sym_db.RegisterMessage(GroupCreateFromRolesRequest)

GroupCreateFromRolesResponse = _reflection.GeneratedProtocolMessageType('GroupCreateFromRolesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPCREATEFROMROLESRESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupCreateFromRolesResponse)
  })
_sym_db.RegisterMessage(GroupCreateFromRolesResponse)

GroupFromRole = _reflection.GeneratedProtocolMessageType('GroupFromRole', (_message.Message,), {
  'DESCRIPTOR' : _GROUPFROMROLE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupFromRole)
  })
_sym_db.RegisterMessage(GroupFromRole)

GroupGetRequest = _reflection.GeneratedProtocolMessageType('GroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPGETREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupGetRequest)
  })
_sym_db.RegisterMessage(GroupGetRequest)

GroupGetResponse = _reflection.GeneratedProtocolMessageType('GroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPGETRESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupGetResponse)
  })
_sym_db.RegisterMessage(GroupGetResponse)

GroupUpdateRequest = _reflection.GeneratedProtocolMessageType('GroupUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPUPDATEREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupUpdateRequest)
  })
_sym_db.RegisterMessage(GroupUpdateRequest)

GroupUpdateResponse = _reflection.GeneratedProtocolMessageType('GroupUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPUPDATERESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupUpdateResponse)
  })
_sym_db.RegisterMessage(GroupUpdateResponse)

GroupDeleteRequest = _reflection.GeneratedProtocolMessageType('GroupDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPDELETEREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupDeleteRequest)
  })
_sym_db.RegisterMessage(GroupDeleteRequest)

GroupDeleteResponse = _reflection.GeneratedProtocolMessageType('GroupDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPDELETERESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupDeleteResponse)
  })
_sym_db.RegisterMessage(GroupDeleteResponse)

GroupListRequest = _reflection.GeneratedProtocolMessageType('GroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GROUPLISTREQUEST,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupListRequest)
  })
_sym_db.RegisterMessage(GroupListRequest)

GroupListResponse = _reflection.GeneratedProtocolMessageType('GroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GROUPLISTRESPONSE,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.GroupListResponse)
  })
_sym_db.RegisterMessage(GroupListResponse)

Group = _reflection.GeneratedProtocolMessageType('Group', (_message.Message,), {
  'DESCRIPTOR' : _GROUP,
  '__module__' : 'groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.Group)
  })
_sym_db.RegisterMessage(Group)

_GROUPS = DESCRIPTOR.services_by_name['Groups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\016GroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _GROUPCREATEREQUEST.fields_by_name['group']._options = None
  _GROUPCREATEREQUEST.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEREQUEST._options = None
  _GROUPCREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPCREATERESPONSE.fields_by_name['group']._options = None
  _GROUPCREATERESPONSE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATERESPONSE._options = None
  _GROUPCREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['role_ids']._options = None
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['role_ids']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['commit']._options = None
  _GROUPCREATEFROMROLESREQUEST.fields_by_name['commit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESREQUEST._options = None
  _GROUPCREATEFROMROLESREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['group_from_role']._options = None
  _GROUPCREATEFROMROLESRESPONSE.fields_by_name['group_from_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPCREATEFROMROLESRESPONSE._options = None
  _GROUPCREATEFROMROLESRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPFROMROLE.fields_by_name['rate_limit']._options = None
  _GROUPFROMROLE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['role']._options = None
  _GROUPFROMROLE.fields_by_name['role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['group']._options = None
  _GROUPFROMROLE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['accounts']._options = None
  _GROUPFROMROLE.fields_by_name['accounts']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE.fields_by_name['approval_flows']._options = None
  _GROUPFROMROLE.fields_by_name['approval_flows']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPFROMROLE._options = None
  _GROUPFROMROLE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPGETREQUEST.fields_by_name['id']._options = None
  _GROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETREQUEST._options = None
  _GROUPGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPGETRESPONSE.fields_by_name['meta']._options = None
  _GROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETRESPONSE.fields_by_name['group']._options = None
  _GROUPGETRESPONSE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPGETRESPONSE._options = None
  _GROUPGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPUPDATEREQUEST.fields_by_name['group']._options = None
  _GROUPUPDATEREQUEST.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPUPDATEREQUEST._options = None
  _GROUPUPDATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPUPDATERESPONSE.fields_by_name['group']._options = None
  _GROUPUPDATERESPONSE.fields_by_name['group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPUPDATERESPONSE._options = None
  _GROUPUPDATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPDELETEREQUEST.fields_by_name['id']._options = None
  _GROUPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPDELETEREQUEST._options = None
  _GROUPDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPDELETERESPONSE.fields_by_name['meta']._options = None
  _GROUPDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPDELETERESPONSE._options = None
  _GROUPDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPLISTREQUEST.fields_by_name['filter']._options = None
  _GROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPLISTREQUEST._options = None
  _GROUPLISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPLISTRESPONSE.fields_by_name['groups']._options = None
  _GROUPLISTRESPONSE.fields_by_name['groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _GROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _GROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUPLISTRESPONSE._options = None
  _GROUPLISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUP.fields_by_name['id']._options = None
  _GROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUP.fields_by_name['name']._options = None
  _GROUP.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _GROUP.fields_by_name['description']._options = None
  _GROUP.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUP.fields_by_name['source']._options = None
  _GROUP.fields_by_name['source']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\230\364\263\007\001'
  _GROUP.fields_by_name['tags']._options = None
  _GROUP.fields_by_name['tags']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _GROUP._options = None
  _GROUP._serialized_options = b'\372\370\263\007a\250\363\263\007\001\302\363\263\007I\242\363\263\007\036tf_examples/group_resource.txt\252\363\263\007!tf_examples/group_data_source.txt\322\363\263\007\001*\322\363\263\007\003cli'
  _GROUPS._options = None
  _GROUPS._serialized_options = b'\312\371\263\007#\302\371\263\007\005Group\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\006group-\312\371\263\007\005\350\371\263\007\001'
  _GROUPS.methods_by_name['Create']._options = None
  _GROUPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\017\252\363\263\007\n/v1/groups'
  _GROUPS.methods_by_name['CreateFromRoles']._options = None
  _GROUPS.methods_by_name['CreateFromRoles']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\032\252\363\263\007\025/v1/groups/from-roles'
  _GROUPS.methods_by_name['Get']._options = None
  _GROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\024\252\363\263\007\017/v1/groups/{id}'
  _GROUPS.methods_by_name['Update']._options = None
  _GROUPS.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\024\252\363\263\007\017/v1/groups/{id}'
  _GROUPS.methods_by_name['Delete']._options = None
  _GROUPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\024\252\363\263\007\017/v1/groups/{id}'
  _GROUPS.methods_by_name['List']._options = None
  _GROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\017\252\363\263\007\n/v1/groups'
  _GROUPCREATEREQUEST._serialized_start=114
  _GROUPCREATEREQUEST._serialized_end=239
  _GROUPCREATERESPONSE._serialized_start=242
  _GROUPCREATERESPONSE._serialized_end=424
  _GROUPCREATEFROMROLESREQUEST._serialized_start=427
  _GROUPCREATEFROMROLESREQUEST._serialized_end=581
  _GROUPCREATEFROMROLESRESPONSE._serialized_start=584
  _GROUPCREATEFROMROLESRESPONSE._serialized_end=793
  _GROUPFROMROLE._serialized_start=796
  _GROUPFROMROLE._serialized_end=1064
  _GROUPGETREQUEST._serialized_start=1066
  _GROUPGETREQUEST._serialized_end=1171
  _GROUPGETRESPONSE._serialized_start=1174
  _GROUPGETRESPONSE._serialized_end=1362
  _GROUPUPDATEREQUEST._serialized_start=1365
  _GROUPUPDATEREQUEST._serialized_end=1502
  _GROUPUPDATERESPONSE._serialized_start=1505
  _GROUPUPDATERESPONSE._serialized_end=1687
  _GROUPDELETEREQUEST._serialized_start=1689
  _GROUPDELETEREQUEST._serialized_end=1800
  _GROUPDELETERESPONSE._serialized_start=1803
  _GROUPDELETERESPONSE._serialized_end=1959
  _GROUPLISTREQUEST._serialized_start=1961
  _GROUPLISTREQUEST._serialized_end=2072
  _GROUPLISTRESPONSE._serialized_start=2075
  _GROUPLISTRESPONSE._serialized_end=2254
  _GROUP._serialized_start=2257
  _GROUP._serialized_end=2525
  _GROUPS._serialized_start=2528
  _GROUPS._serialized_end=3196
# @@protoc_insertion_point(module_scope)
