# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peering_group_resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dpeering_group_resources.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x92\x01\n!PeeringGroupResourceCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x44\n\x16peering_group_resource\x18\x02 \x01(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x85\x02\n\"PeeringGroupResourceCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x16peering_group_resource\x18\x02 \x01(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x1ePeeringGroupResourceGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xff\x01\n\x1fPeeringGroupResourceGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x16peering_group_resource\x18\x02 \x01(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n!PeeringGroupResourceDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xbf\x01\n\"PeeringGroupResourceDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n\x1fPeeringGroupResourceListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xea\x01\n PeeringGroupResourceListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x45\n\x17peering_group_resources\x18\x02 \x03(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x83\x01\n\x14PeeringGroupResource\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12!\n\x08group_id\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\x96\x05\n\x15PeeringGroupResources\x12\x8a\x01\n\x06\x43reate\x12%.v1.PeeringGroupResourceCreateRequest\x1a&.v1.PeeringGroupResourceCreateResponse\"1\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/peeringGroupResources\x12\x91\x01\n\x06\x44\x65lete\x12%.v1.PeeringGroupResourceDeleteRequest\x1a&.v1.PeeringGroupResourceDeleteResponse\"8\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/peeringGroupResources/{id}\x12\x85\x01\n\x03Get\x12\".v1.PeeringGroupResourceGetRequest\x1a#.v1.PeeringGroupResourceGetResponse\"5\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/peeringGroupResources/{id}\x12\x83\x01\n\x04List\x12#.v1.PeeringGroupResourceListRequest\x1a$.v1.PeeringGroupResourceListResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/peeringGroupResources\x1aN\xca\xf9\xb3\x07\x19\xc2\xf9\xb3\x07\x14PeeringGroupResource\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03gr-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cli\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\x42q\n\x19\x63om.strongdm.api.plumbingB\x1dPeeringGroupResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_PEERINGGROUPRESOURCECREATEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceCreateRequest']
_PEERINGGROUPRESOURCECREATERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceCreateResponse']
_PEERINGGROUPRESOURCEGETREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceGetRequest']
_PEERINGGROUPRESOURCEGETRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceGetResponse']
_PEERINGGROUPRESOURCEDELETEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceDeleteRequest']
_PEERINGGROUPRESOURCEDELETERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceDeleteResponse']
_PEERINGGROUPRESOURCELISTREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceListRequest']
_PEERINGGROUPRESOURCELISTRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceListResponse']
_PEERINGGROUPRESOURCE = DESCRIPTOR.message_types_by_name['PeeringGroupResource']
PeeringGroupResourceCreateRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCECREATEREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceCreateRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceCreateRequest)

PeeringGroupResourceCreateResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCECREATERESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceCreateResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceCreateResponse)

PeeringGroupResourceGetRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEGETREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceGetRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceGetRequest)

PeeringGroupResourceGetResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEGETRESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceGetResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceGetResponse)

PeeringGroupResourceDeleteRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEDELETEREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceDeleteRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceDeleteRequest)

PeeringGroupResourceDeleteResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEDELETERESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceDeleteResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceDeleteResponse)

PeeringGroupResourceListRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCELISTREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceListRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceListRequest)

PeeringGroupResourceListResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCELISTRESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceListResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceListResponse)

PeeringGroupResource = _reflection.GeneratedProtocolMessageType('PeeringGroupResource', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResource)
  })
_sym_db.RegisterMessage(PeeringGroupResource)

_PEERINGGROUPRESOURCES = DESCRIPTOR.services_by_name['PeeringGroupResources']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\035PeeringGroupResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _PEERINGGROUPRESOURCECREATEREQUEST.fields_by_name['peering_group_resource']._options = None
  _PEERINGGROUPRESOURCECREATEREQUEST.fields_by_name['peering_group_resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['peering_group_resource']._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['peering_group_resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCECREATERESPONSE._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCEGETREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPRESOURCEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['peering_group_resource']._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['peering_group_resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCEGETRESPONSE._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCEDELETEREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPRESOURCEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCEDELETERESPONSE._options = None
  _PEERINGGROUPRESOURCEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCELISTREQUEST.fields_by_name['filter']._options = None
  _PEERINGGROUPRESOURCELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['peering_group_resources']._options = None
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['peering_group_resources']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCE.fields_by_name['id']._options = None
  _PEERINGGROUPRESOURCE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCE.fields_by_name['resource_id']._options = None
  _PEERINGGROUPRESOURCE.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PEERINGGROUPRESOURCE.fields_by_name['group_id']._options = None
  _PEERINGGROUPRESOURCE.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PEERINGGROUPRESOURCE._options = None
  _PEERINGGROUPRESOURCE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCES._options = None
  _PEERINGGROUPRESOURCES._serialized_options = b'\312\371\263\007\031\302\371\263\007\024PeeringGroupResource\312\371\263\007\010\322\371\263\007\003gr-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli\312\371\263\007\005\330\371\263\007\001'
  _PEERINGGROUPRESOURCES.methods_by_name['Create']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\036\252\363\263\007\031/v1/peeringGroupResources'
  _PEERINGGROUPRESOURCES.methods_by_name['Delete']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007#\252\363\263\007\036/v1/peeringGroupResources/{id}'
  _PEERINGGROUPRESOURCES.methods_by_name['Get']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007#\252\363\263\007\036/v1/peeringGroupResources/{id}'
  _PEERINGGROUPRESOURCES.methods_by_name['List']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\036\252\363\263\007\031/v1/peeringGroupResources'
  _PEERINGGROUPRESOURCECREATEREQUEST._serialized_start=65
  _PEERINGGROUPRESOURCECREATEREQUEST._serialized_end=211
  _PEERINGGROUPRESOURCECREATERESPONSE._serialized_start=214
  _PEERINGGROUPRESOURCECREATERESPONSE._serialized_end=475
  _PEERINGGROUPRESOURCEGETREQUEST._serialized_start=477
  _PEERINGGROUPRESOURCEGETREQUEST._serialized_end=571
  _PEERINGGROUPRESOURCEGETRESPONSE._serialized_start=574
  _PEERINGGROUPRESOURCEGETRESPONSE._serialized_end=829
  _PEERINGGROUPRESOURCEDELETEREQUEST._serialized_start=831
  _PEERINGGROUPRESOURCEDELETEREQUEST._serialized_end=931
  _PEERINGGROUPRESOURCEDELETERESPONSE._serialized_start=934
  _PEERINGGROUPRESOURCEDELETERESPONSE._serialized_end=1125
  _PEERINGGROUPRESOURCELISTREQUEST._serialized_start=1127
  _PEERINGGROUPRESOURCELISTREQUEST._serialized_end=1227
  _PEERINGGROUPRESOURCELISTRESPONSE._serialized_start=1230
  _PEERINGGROUPRESOURCELISTRESPONSE._serialized_end=1464
  _PEERINGGROUPRESOURCE._serialized_start=1467
  _PEERINGGROUPRESOURCE._serialized_end=1598
  _PEERINGGROUPRESOURCES._serialized_start=1601
  _PEERINGGROUPRESOURCES._serialized_end=2263
# @@protoc_insertion_point(module_scope)
