# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workflow_roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14workflow_roles.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x86\x01\n\x1aWorkflowRolesCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\rworkflow_role\x18\x02 \x01(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe1\x01\n\x1bWorkflowRolesCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x33\n\rworkflow_role\x18\x02 \x01(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x16WorkflowRoleGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe6\x01\n\x17WorkflowRoleGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rworkflow_role\x18\x02 \x01(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"i\n\x1aWorkflowRolesDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xac\x01\n\x1bWorkflowRolesDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"i\n\x18WorkflowRolesListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xdd\x01\n\x19WorkflowRolesListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x33\n\rworkflow_role\x18\x02 \x03(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xde\x01\n\x0cWorkflowRole\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bworkflow_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07role_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:n\xfa\xf8\xb3\x07i\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07Y\xa2\xf3\xb3\x07&tf_examples/workflow_role_resource.txt\xaa\xf3\xb3\x07)tf_examples/workflow_role_data_source.txt\xd2\xf3\xb3\x07\x01*2\x8d\x04\n\rWorkflowRoles\x12u\n\x06\x43reate\x12\x1e.v1.WorkflowRolesCreateRequest\x1a\x1f.v1.WorkflowRolesCreateResponse\"*\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/workflow-roles\x12m\n\x03Get\x12\x1a.v1.WorkflowRoleGetRequest\x1a\x1b.v1.WorkflowRoleGetResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/workflow-role/{id}\x12w\n\x06\x44\x65lete\x12\x1e.v1.WorkflowRolesDeleteRequest\x1a\x1f.v1.WorkflowRolesDeleteResponse\",\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/workflow-roles\x12n\n\x04List\x12\x1c.v1.WorkflowRolesListRequest\x1a\x1d.v1.WorkflowRolesListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/workflow-roles\x1a-\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0cWorkflowRole\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03wr-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15WorkflowRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_WORKFLOWROLESCREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRolesCreateRequest']
_WORKFLOWROLESCREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRolesCreateResponse']
_WORKFLOWROLEGETREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRoleGetRequest']
_WORKFLOWROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRoleGetResponse']
_WORKFLOWROLESDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRolesDeleteRequest']
_WORKFLOWROLESDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRolesDeleteResponse']
_WORKFLOWROLESLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRolesListRequest']
_WORKFLOWROLESLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRolesListResponse']
_WORKFLOWROLE = DESCRIPTOR.message_types_by_name['WorkflowRole']
WorkflowRolesCreateRequest = _reflection.GeneratedProtocolMessageType('WorkflowRolesCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESCREATEREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesCreateRequest)
  })
_sym_db.RegisterMessage(WorkflowRolesCreateRequest)

WorkflowRolesCreateResponse = _reflection.GeneratedProtocolMessageType('WorkflowRolesCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESCREATERESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesCreateResponse)
  })
_sym_db.RegisterMessage(WorkflowRolesCreateResponse)

WorkflowRoleGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowRoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLEGETREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRoleGetRequest)
  })
_sym_db.RegisterMessage(WorkflowRoleGetRequest)

WorkflowRoleGetResponse = _reflection.GeneratedProtocolMessageType('WorkflowRoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLEGETRESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRoleGetResponse)
  })
_sym_db.RegisterMessage(WorkflowRoleGetResponse)

WorkflowRolesDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkflowRolesDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESDELETEREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesDeleteRequest)
  })
_sym_db.RegisterMessage(WorkflowRolesDeleteRequest)

WorkflowRolesDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkflowRolesDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESDELETERESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesDeleteResponse)
  })
_sym_db.RegisterMessage(WorkflowRolesDeleteResponse)

WorkflowRolesListRequest = _reflection.GeneratedProtocolMessageType('WorkflowRolesListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESLISTREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesListRequest)
  })
_sym_db.RegisterMessage(WorkflowRolesListRequest)

WorkflowRolesListResponse = _reflection.GeneratedProtocolMessageType('WorkflowRolesListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESLISTRESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesListResponse)
  })
_sym_db.RegisterMessage(WorkflowRolesListResponse)

WorkflowRole = _reflection.GeneratedProtocolMessageType('WorkflowRole', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRole)
  })
_sym_db.RegisterMessage(WorkflowRole)

_WORKFLOWROLES = DESCRIPTOR.services_by_name['WorkflowRoles']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025WorkflowRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _WORKFLOWROLESCREATEREQUEST.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLESCREATEREQUEST.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESCREATEREQUEST._options = None
  _WORKFLOWROLESCREATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLESCREATERESPONSE._options = None
  _WORKFLOWROLESCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLEGETREQUEST.fields_by_name['id']._options = None
  _WORKFLOWROLEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLEGETRESPONSE.fields_by_name['meta']._options = None
  _WORKFLOWROLEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLEGETRESPONSE.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLEGETRESPONSE.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLEGETRESPONSE._options = None
  _WORKFLOWROLEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESDELETEREQUEST.fields_by_name['id']._options = None
  _WORKFLOWROLESDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESDELETEREQUEST._options = None
  _WORKFLOWROLESDELETEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLESDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLESDELETERESPONSE._options = None
  _WORKFLOWROLESDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESLISTREQUEST.fields_by_name['filter']._options = None
  _WORKFLOWROLESLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESLISTREQUEST._options = None
  _WORKFLOWROLESLISTREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLESLISTRESPONSE._options = None
  _WORKFLOWROLESLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLE.fields_by_name['id']._options = None
  _WORKFLOWROLE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLE.fields_by_name['workflow_id']._options = None
  _WORKFLOWROLE.fields_by_name['workflow_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _WORKFLOWROLE.fields_by_name['role_id']._options = None
  _WORKFLOWROLE.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _WORKFLOWROLE._options = None
  _WORKFLOWROLE._serialized_options = b'\372\370\263\007i\250\363\263\007\001\302\363\263\007Y\242\363\263\007&tf_examples/workflow_role_resource.txt\252\363\263\007)tf_examples/workflow_role_data_source.txt\322\363\263\007\001*'
  _WORKFLOWROLES._options = None
  _WORKFLOWROLES._serialized_options = b'\312\371\263\007\021\302\371\263\007\014WorkflowRole\312\371\263\007\010\322\371\263\007\003wr-\312\371\263\007\005\350\371\263\007\001'
  _WORKFLOWROLES.methods_by_name['Create']._options = None
  _WORKFLOWROLES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\027\252\363\263\007\022/v1/workflow-roles'
  _WORKFLOWROLES.methods_by_name['Get']._options = None
  _WORKFLOWROLES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/workflow-role/{id}'
  _WORKFLOWROLES.methods_by_name['Delete']._options = None
  _WORKFLOWROLES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\027\252\363\263\007\022/v1/workflow-roles'
  _WORKFLOWROLES.methods_by_name['List']._options = None
  _WORKFLOWROLES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/workflow-roles'
  _WORKFLOWROLESCREATEREQUEST._serialized_start=56
  _WORKFLOWROLESCREATEREQUEST._serialized_end=190
  _WORKFLOWROLESCREATERESPONSE._serialized_start=193
  _WORKFLOWROLESCREATERESPONSE._serialized_end=418
  _WORKFLOWROLEGETREQUEST._serialized_start=420
  _WORKFLOWROLEGETREQUEST._serialized_end=506
  _WORKFLOWROLEGETRESPONSE._serialized_start=509
  _WORKFLOWROLEGETRESPONSE._serialized_end=739
  _WORKFLOWROLESDELETEREQUEST._serialized_start=741
  _WORKFLOWROLESDELETEREQUEST._serialized_end=846
  _WORKFLOWROLESDELETERESPONSE._serialized_start=849
  _WORKFLOWROLESDELETERESPONSE._serialized_end=1021
  _WORKFLOWROLESLISTREQUEST._serialized_start=1023
  _WORKFLOWROLESLISTREQUEST._serialized_end=1128
  _WORKFLOWROLESLISTRESPONSE._serialized_start=1131
  _WORKFLOWROLESLISTRESPONSE._serialized_end=1352
  _WORKFLOWROLE._serialized_start=1355
  _WORKFLOWROLE._serialized_end=1577
  _WORKFLOWROLES._serialized_start=1580
  _WORKFLOWROLES._serialized_end=2105
# @@protoc_insertion_point(module_scope)
