# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from . import drivers_pb2 as drivers__pb2
from . import tags_pb2 as tags__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fresources.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\rdrivers.proto\x1a\ntags.proto\"l\n\x15ResourceCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xdf\x01\n\x16ResourceCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"R\n\x12ResourceGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd9\x01\n\x13ResourceGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"x\n\x15ResourceUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12*\n\x08resource\x18\x03 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xdf\x01\n\x16ResourceUpdateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12*\n\x08resource\x18\x02 \x01(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x15ResourceDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xb3\x01\n\x16ResourceDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"X\n\x13ResourceListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xc4\x01\n\x14ResourceListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12+\n\tresources\x18\x02 \x03(\x0b\x32\x0c.v1.ResourceB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"Y\n\x14\x45numerateTagsRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xbe\x01\n\x15\x45numerateTagsResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12$\n\x07matches\x18\x02 \x03(\x0b\x32\x07.v1.TagB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"i\n\x1aResourceHealthcheckRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xb8\x01\n\x1bResourceHealthcheckResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xad\x06\n\tResources\x12p\n\rEnumerateTags\x12\x18.v1.EnumerateTagsRequest\x1a\x19.v1.EnumerateTagsResponse\"*\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x18\xaa\xf3\xb3\x07\x13/v1/resources/tags/\x12\x66\n\x06\x43reate\x12\x19.v1.ResourceCreateRequest\x1a\x1a.v1.ResourceCreateResponse\"%\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/resources\x12\x61\n\x03Get\x12\x16.v1.ResourceGetRequest\x1a\x17.v1.ResourceGetResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/resources/{id}\x12j\n\x06Update\x12\x19.v1.ResourceUpdateRequest\x1a\x1a.v1.ResourceUpdateResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/resources/{id}\x12m\n\x06\x44\x65lete\x12\x19.v1.ResourceDeleteRequest\x1a\x1a.v1.ResourceDeleteResponse\",\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/resources/{id}\x12_\n\x04List\x12\x17.v1.ResourceListRequest\x1a\x18.v1.ResourceListResponse\"$\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x12\xaa\xf3\xb3\x07\r/v1/resources\x12\x85\x01\n\x0bHealthcheck\x12\x1e.v1.ResourceHealthcheckRequest\x1a\x1f.v1.ResourceHealthcheckResponse\"5\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/resources/{id}/healthcheck\x1a\x1f\xca\xf9\xb3\x07\r\xc2\xf9\xb3\x07\x08Resource\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03rs-Be\n\x19\x63om.strongdm.api.plumbingB\x11ResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_RESOURCECREATEREQUEST = DESCRIPTOR.message_types_by_name['ResourceCreateRequest']
_RESOURCECREATERESPONSE = DESCRIPTOR.message_types_by_name['ResourceCreateResponse']
_RESOURCEGETREQUEST = DESCRIPTOR.message_types_by_name['ResourceGetRequest']
_RESOURCEGETRESPONSE = DESCRIPTOR.message_types_by_name['ResourceGetResponse']
_RESOURCEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['ResourceUpdateRequest']
_RESOURCEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['ResourceUpdateResponse']
_RESOURCEDELETEREQUEST = DESCRIPTOR.message_types_by_name['ResourceDeleteRequest']
_RESOURCEDELETERESPONSE = DESCRIPTOR.message_types_by_name['ResourceDeleteResponse']
_RESOURCELISTREQUEST = DESCRIPTOR.message_types_by_name['ResourceListRequest']
_RESOURCELISTRESPONSE = DESCRIPTOR.message_types_by_name['ResourceListResponse']
_ENUMERATETAGSREQUEST = DESCRIPTOR.message_types_by_name['EnumerateTagsRequest']
_ENUMERATETAGSRESPONSE = DESCRIPTOR.message_types_by_name['EnumerateTagsResponse']
_RESOURCEHEALTHCHECKREQUEST = DESCRIPTOR.message_types_by_name['ResourceHealthcheckRequest']
_RESOURCEHEALTHCHECKRESPONSE = DESCRIPTOR.message_types_by_name['ResourceHealthcheckResponse']
ResourceCreateRequest = _reflection.GeneratedProtocolMessageType('ResourceCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECREATEREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceCreateRequest)
  })
_sym_db.RegisterMessage(ResourceCreateRequest)

ResourceCreateResponse = _reflection.GeneratedProtocolMessageType('ResourceCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCECREATERESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceCreateResponse)
  })
_sym_db.RegisterMessage(ResourceCreateResponse)

ResourceGetRequest = _reflection.GeneratedProtocolMessageType('ResourceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGETREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceGetRequest)
  })
_sym_db.RegisterMessage(ResourceGetRequest)

ResourceGetResponse = _reflection.GeneratedProtocolMessageType('ResourceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEGETRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceGetResponse)
  })
_sym_db.RegisterMessage(ResourceGetResponse)

ResourceUpdateRequest = _reflection.GeneratedProtocolMessageType('ResourceUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUPDATEREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceUpdateRequest)
  })
_sym_db.RegisterMessage(ResourceUpdateRequest)

ResourceUpdateResponse = _reflection.GeneratedProtocolMessageType('ResourceUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEUPDATERESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceUpdateResponse)
  })
_sym_db.RegisterMessage(ResourceUpdateResponse)

ResourceDeleteRequest = _reflection.GeneratedProtocolMessageType('ResourceDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEDELETEREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceDeleteRequest)
  })
_sym_db.RegisterMessage(ResourceDeleteRequest)

ResourceDeleteResponse = _reflection.GeneratedProtocolMessageType('ResourceDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEDELETERESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceDeleteResponse)
  })
_sym_db.RegisterMessage(ResourceDeleteResponse)

ResourceListRequest = _reflection.GeneratedProtocolMessageType('ResourceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELISTREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceListRequest)
  })
_sym_db.RegisterMessage(ResourceListRequest)

ResourceListResponse = _reflection.GeneratedProtocolMessageType('ResourceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCELISTRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceListResponse)
  })
_sym_db.RegisterMessage(ResourceListResponse)

EnumerateTagsRequest = _reflection.GeneratedProtocolMessageType('EnumerateTagsRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENUMERATETAGSREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.EnumerateTagsRequest)
  })
_sym_db.RegisterMessage(EnumerateTagsRequest)

EnumerateTagsResponse = _reflection.GeneratedProtocolMessageType('EnumerateTagsResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENUMERATETAGSRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.EnumerateTagsResponse)
  })
_sym_db.RegisterMessage(EnumerateTagsResponse)

ResourceHealthcheckRequest = _reflection.GeneratedProtocolMessageType('ResourceHealthcheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHEALTHCHECKREQUEST,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHealthcheckRequest)
  })
_sym_db.RegisterMessage(ResourceHealthcheckRequest)

ResourceHealthcheckResponse = _reflection.GeneratedProtocolMessageType('ResourceHealthcheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHEALTHCHECKRESPONSE,
  '__module__' : 'resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.ResourceHealthcheckResponse)
  })
_sym_db.RegisterMessage(ResourceHealthcheckResponse)

_RESOURCES = DESCRIPTOR.services_by_name['Resources']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\021ResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _RESOURCECREATEREQUEST.fields_by_name['resource']._options = None
  _RESOURCECREATEREQUEST.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCECREATERESPONSE.fields_by_name['meta']._options = None
  _RESOURCECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCECREATERESPONSE.fields_by_name['resource']._options = None
  _RESOURCECREATERESPONSE.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCECREATERESPONSE._options = None
  _RESOURCECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEGETREQUEST.fields_by_name['id']._options = None
  _RESOURCEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEGETRESPONSE.fields_by_name['meta']._options = None
  _RESOURCEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEGETRESPONSE.fields_by_name['resource']._options = None
  _RESOURCEGETRESPONSE.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEGETRESPONSE._options = None
  _RESOURCEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEUPDATEREQUEST.fields_by_name['resource']._options = None
  _RESOURCEUPDATEREQUEST.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEUPDATERESPONSE.fields_by_name['meta']._options = None
  _RESOURCEUPDATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEUPDATERESPONSE.fields_by_name['resource']._options = None
  _RESOURCEUPDATERESPONSE.fields_by_name['resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEUPDATERESPONSE._options = None
  _RESOURCEUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEDELETEREQUEST.fields_by_name['id']._options = None
  _RESOURCEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEDELETERESPONSE.fields_by_name['meta']._options = None
  _RESOURCEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEDELETERESPONSE._options = None
  _RESOURCEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCELISTREQUEST.fields_by_name['filter']._options = None
  _RESOURCELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCELISTRESPONSE.fields_by_name['resources']._options = None
  _RESOURCELISTRESPONSE.fields_by_name['resources']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _RESOURCELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ENUMERATETAGSREQUEST.fields_by_name['filter']._options = None
  _ENUMERATETAGSREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ENUMERATETAGSRESPONSE.fields_by_name['matches']._options = None
  _ENUMERATETAGSRESPONSE.fields_by_name['matches']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ENUMERATETAGSRESPONSE.fields_by_name['rate_limit']._options = None
  _ENUMERATETAGSRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEHEALTHCHECKREQUEST.fields_by_name['id']._options = None
  _RESOURCEHEALTHCHECKREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHEALTHCHECKREQUEST._options = None
  _RESOURCEHEALTHCHECKREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['meta']._options = None
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._options = None
  _RESOURCEHEALTHCHECKRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _RESOURCEHEALTHCHECKRESPONSE._options = None
  _RESOURCEHEALTHCHECKRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _RESOURCES._options = None
  _RESOURCES._serialized_options = b'\312\371\263\007\r\302\371\263\007\010Resource\312\371\263\007\010\322\371\263\007\003rs-'
  _RESOURCES.methods_by_name['EnumerateTags']._options = None
  _RESOURCES.methods_by_name['EnumerateTags']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\030\252\363\263\007\023/v1/resources/tags/'
  _RESOURCES.methods_by_name['Create']._options = None
  _RESOURCES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\022\252\363\263\007\r/v1/resources'
  _RESOURCES.methods_by_name['Get']._options = None
  _RESOURCES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/resources/{id}'
  _RESOURCES.methods_by_name['Update']._options = None
  _RESOURCES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\027\252\363\263\007\022/v1/resources/{id}'
  _RESOURCES.methods_by_name['Delete']._options = None
  _RESOURCES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\027\252\363\263\007\022/v1/resources/{id}'
  _RESOURCES.methods_by_name['List']._options = None
  _RESOURCES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\022\252\363\263\007\r/v1/resources'
  _RESOURCES.methods_by_name['Healthcheck']._options = None
  _RESOURCES.methods_by_name['Healthcheck']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007#\252\363\263\007\036/v1/resources/{id}/healthcheck'
  _RESOURCECREATEREQUEST._serialized_start=77
  _RESOURCECREATEREQUEST._serialized_end=185
  _RESOURCECREATERESPONSE._serialized_start=188
  _RESOURCECREATERESPONSE._serialized_end=411
  _RESOURCEGETREQUEST._serialized_start=413
  _RESOURCEGETREQUEST._serialized_end=495
  _RESOURCEGETRESPONSE._serialized_start=498
  _RESOURCEGETRESPONSE._serialized_end=715
  _RESOURCEUPDATEREQUEST._serialized_start=717
  _RESOURCEUPDATEREQUEST._serialized_end=837
  _RESOURCEUPDATERESPONSE._serialized_start=840
  _RESOURCEUPDATERESPONSE._serialized_end=1063
  _RESOURCEDELETEREQUEST._serialized_start=1065
  _RESOURCEDELETEREQUEST._serialized_end=1153
  _RESOURCEDELETERESPONSE._serialized_start=1156
  _RESOURCEDELETERESPONSE._serialized_end=1335
  _RESOURCELISTREQUEST._serialized_start=1337
  _RESOURCELISTREQUEST._serialized_end=1425
  _RESOURCELISTRESPONSE._serialized_start=1428
  _RESOURCELISTRESPONSE._serialized_end=1624
  _ENUMERATETAGSREQUEST._serialized_start=1626
  _ENUMERATETAGSREQUEST._serialized_end=1715
  _ENUMERATETAGSRESPONSE._serialized_start=1718
  _ENUMERATETAGSRESPONSE._serialized_end=1908
  _RESOURCEHEALTHCHECKREQUEST._serialized_start=1910
  _RESOURCEHEALTHCHECKREQUEST._serialized_end=2015
  _RESOURCEHEALTHCHECKRESPONSE._serialized_start=2018
  _RESOURCEHEALTHCHECKRESPONSE._serialized_end=2202
  _RESOURCES._serialized_start=2205
  _RESOURCES._serialized_end=3018
# @@protoc_insertion_point(module_scope)
