# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: accounts_groups.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61\x63\x63ounts_groups.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x93\x01\n\x19\x41\x63\x63ountGroupCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\raccount_group\x18\x02 \x01(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xcc\x01\n\x1a\x41\x63\x63ountGroupCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x33\n\raccount_group\x18\x02 \x01(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"p\n\x16\x41\x63\x63ountGroupGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xd2\x01\n\x17\x41\x63\x63ountGroupGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\raccount_group\x18\x02 \x01(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"v\n\x19\x41\x63\x63ountGroupDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xa3\x01\n\x1a\x41\x63\x63ountGroupDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"v\n\x17\x41\x63\x63ountGroupListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xc9\x01\n\x18\x41\x63\x63ountGroupListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0e\x61\x63\x63ount_groups\x18\x02 \x03(\x0b\x32\x10.v1.AccountGroupB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12\x35\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\x18\xfa\xf8\xb3\x07\x13\xa8\xf3\xb3\x07\x01\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li\"\xe6\x01\n\x0c\x41\x63\x63ountGroup\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\naccount_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12!\n\x08group_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:v\xfa\xf8\xb3\x07q\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07Y\xa2\xf3\xb3\x07&tf_examples/account_group_resource.txt\xaa\xf3\xb3\x07)tf_examples/account_group_data_source.txt\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x03\x63li2\xa1\x04\n\x0e\x41\x63\x63ountsGroups\x12s\n\x06\x43reate\x12\x1d.v1.AccountGroupCreateRequest\x1a\x1e.v1.AccountGroupCreateResponse\"*\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/accountsgroups\x12n\n\x03Get\x12\x1a.v1.AccountGroupGetRequest\x1a\x1b.v1.AccountGroupGetResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/accountsgroups/{id}\x12z\n\x06\x44\x65lete\x12\x1d.v1.AccountGroupDeleteRequest\x1a\x1e.v1.AccountGroupDeleteResponse\"1\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/accountsgroups/{id}\x12l\n\x04List\x12\x1b.v1.AccountGroupListRequest\x1a\x1c.v1.AccountGroupListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/accountsgroups\x1a@\xca\xf9\xb3\x07\x31\xc2\xf9\xb3\x07\x0c\x41\x63\x63ountGroup\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x03\x63li\xd2\xf9\xb3\x07\raccountgroup-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x82\x01\n\x19\x63om.strongdm.api.plumbingB\x16\x41\x63\x63ountsGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x08\xa2\x8c\xb4\x07\x03\x63lib\x06proto3')



_ACCOUNTGROUPCREATEREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupCreateRequest']
_ACCOUNTGROUPCREATERESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupCreateResponse']
_ACCOUNTGROUPGETREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupGetRequest']
_ACCOUNTGROUPGETRESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupGetResponse']
_ACCOUNTGROUPDELETEREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupDeleteRequest']
_ACCOUNTGROUPDELETERESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupDeleteResponse']
_ACCOUNTGROUPLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountGroupListRequest']
_ACCOUNTGROUPLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountGroupListResponse']
_ACCOUNTGROUP = DESCRIPTOR.message_types_by_name['AccountGroup']
AccountGroupCreateRequest = _reflection.GeneratedProtocolMessageType('AccountGroupCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPCREATEREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupCreateRequest)
  })
_sym_db.RegisterMessage(AccountGroupCreateRequest)

AccountGroupCreateResponse = _reflection.GeneratedProtocolMessageType('AccountGroupCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPCREATERESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupCreateResponse)
  })
_sym_db.RegisterMessage(AccountGroupCreateResponse)

AccountGroupGetRequest = _reflection.GeneratedProtocolMessageType('AccountGroupGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPGETREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupGetRequest)
  })
_sym_db.RegisterMessage(AccountGroupGetRequest)

AccountGroupGetResponse = _reflection.GeneratedProtocolMessageType('AccountGroupGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPGETRESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupGetResponse)
  })
_sym_db.RegisterMessage(AccountGroupGetResponse)

AccountGroupDeleteRequest = _reflection.GeneratedProtocolMessageType('AccountGroupDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPDELETEREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupDeleteRequest)
  })
_sym_db.RegisterMessage(AccountGroupDeleteRequest)

AccountGroupDeleteResponse = _reflection.GeneratedProtocolMessageType('AccountGroupDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPDELETERESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupDeleteResponse)
  })
_sym_db.RegisterMessage(AccountGroupDeleteResponse)

AccountGroupListRequest = _reflection.GeneratedProtocolMessageType('AccountGroupListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPLISTREQUEST,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupListRequest)
  })
_sym_db.RegisterMessage(AccountGroupListRequest)

AccountGroupListResponse = _reflection.GeneratedProtocolMessageType('AccountGroupListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPLISTRESPONSE,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroupListResponse)
  })
_sym_db.RegisterMessage(AccountGroupListResponse)

AccountGroup = _reflection.GeneratedProtocolMessageType('AccountGroup', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUP,
  '__module__' : 'accounts_groups_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountGroup)
  })
_sym_db.RegisterMessage(AccountGroup)

_ACCOUNTSGROUPS = DESCRIPTOR.services_by_name['AccountsGroups']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\026AccountsGroupsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\010\242\214\264\007\003cli'
  _ACCOUNTGROUPCREATEREQUEST.fields_by_name['account_group']._options = None
  _ACCOUNTGROUPCREATEREQUEST.fields_by_name['account_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPCREATEREQUEST._options = None
  _ACCOUNTGROUPCREATEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['account_group']._options = None
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['account_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPCREATERESPONSE._options = None
  _ACCOUNTGROUPCREATERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPGETREQUEST.fields_by_name['id']._options = None
  _ACCOUNTGROUPGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETREQUEST._options = None
  _ACCOUNTGROUPGETREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['account_group']._options = None
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['account_group']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPGETRESPONSE._options = None
  _ACCOUNTGROUPGETRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPDELETEREQUEST.fields_by_name['id']._options = None
  _ACCOUNTGROUPDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPDELETEREQUEST._options = None
  _ACCOUNTGROUPDELETEREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['meta']._options = None
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPDELETERESPONSE._options = None
  _ACCOUNTGROUPDELETERESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPLISTREQUEST.fields_by_name['filter']._options = None
  _ACCOUNTGROUPLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPLISTREQUEST._options = None
  _ACCOUNTGROUPLISTREQUEST._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['account_groups']._options = None
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['account_groups']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTGROUPLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUPLISTRESPONSE._options = None
  _ACCOUNTGROUPLISTRESPONSE._serialized_options = b'\372\370\263\007\023\250\363\263\007\001\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTGROUP.fields_by_name['id']._options = None
  _ACCOUNTGROUP.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTGROUP.fields_by_name['account_id']._options = None
  _ACCOUNTGROUP.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTGROUP.fields_by_name['group_id']._options = None
  _ACCOUNTGROUP.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _ACCOUNTGROUP._options = None
  _ACCOUNTGROUP._serialized_options = b'\372\370\263\007q\250\363\263\007\001\302\363\263\007Y\242\363\263\007&tf_examples/account_group_resource.txt\252\363\263\007)tf_examples/account_group_data_source.txt\322\363\263\007\001*\322\363\263\007\003cli'
  _ACCOUNTSGROUPS._options = None
  _ACCOUNTSGROUPS._serialized_options = b'\312\371\263\0071\302\371\263\007\014AccountGroup\312\371\263\007\001*\312\371\263\007\003cli\322\371\263\007\raccountgroup-\312\371\263\007\005\350\371\263\007\001'
  _ACCOUNTSGROUPS.methods_by_name['Create']._options = None
  _ACCOUNTSGROUPS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\027\252\363\263\007\022/v1/accountsgroups'
  _ACCOUNTSGROUPS.methods_by_name['Get']._options = None
  _ACCOUNTSGROUPS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\034\252\363\263\007\027/v1/accountsgroups/{id}'
  _ACCOUNTSGROUPS.methods_by_name['Delete']._options = None
  _ACCOUNTSGROUPS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\034\252\363\263\007\027/v1/accountsgroups/{id}'
  _ACCOUNTSGROUPS.methods_by_name['List']._options = None
  _ACCOUNTSGROUPS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/accountsgroups'
  _ACCOUNTGROUPCREATEREQUEST._serialized_start=57
  _ACCOUNTGROUPCREATEREQUEST._serialized_end=204
  _ACCOUNTGROUPCREATERESPONSE._serialized_start=207
  _ACCOUNTGROUPCREATERESPONSE._serialized_end=411
  _ACCOUNTGROUPGETREQUEST._serialized_start=413
  _ACCOUNTGROUPGETREQUEST._serialized_end=525
  _ACCOUNTGROUPGETRESPONSE._serialized_start=528
  _ACCOUNTGROUPGETRESPONSE._serialized_end=738
  _ACCOUNTGROUPDELETEREQUEST._serialized_start=740
  _ACCOUNTGROUPDELETEREQUEST._serialized_end=858
  _ACCOUNTGROUPDELETERESPONSE._serialized_start=861
  _ACCOUNTGROUPDELETERESPONSE._serialized_end=1024
  _ACCOUNTGROUPLISTREQUEST._serialized_start=1026
  _ACCOUNTGROUPLISTREQUEST._serialized_end=1144
  _ACCOUNTGROUPLISTRESPONSE._serialized_start=1147
  _ACCOUNTGROUPLISTRESPONSE._serialized_end=1348
  _ACCOUNTGROUP._serialized_start=1351
  _ACCOUNTGROUP._serialized_end=1581
  _ACCOUNTSGROUPS._serialized_start=1584
  _ACCOUNTSGROUPS._serialized_end=2129
# @@protoc_insertion_point(module_scope)
