# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proxy_cluster_keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18proxy_cluster_keys.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"\x83\x01\n\x1cProxyClusterKeyCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12:\n\x11proxy_cluster_key\x18\x02 \x01(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x9b\x02\n\x1dProxyClusterKeyCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\x11proxy_cluster_key\x18\x02 \x01(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12#\n\nsecret_key\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xf0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x04 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"Y\n\x19ProxyClusterKeyGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf0\x01\n\x1aProxyClusterKeyGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\x11proxy_cluster_key\x18\x02 \x01(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"_\n\x1cProxyClusterKeyDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xba\x01\n\x1dProxyClusterKeyDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"_\n\x1aProxyClusterKeyListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xdb\x01\n\x1bProxyClusterKeyListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12;\n\x12proxy_cluster_keys\x18\x02 \x03(\x0b\x32\x13.v1.ProxyClusterKeyB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x90\x03\n\x0fProxyClusterKey\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12.\n\x10proxy_cluster_id\x18\x02 \x01(\tB\x14\xf2\xf8\xb3\x07\x0f\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xe0\xf3\xb3\x07\x01\x12]\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider\x12_\n\x0clast_used_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB-\xf2\xf8\xb3\x07(\xb0\xf3\xb3\x07\x01\x98\xf4\xb3\x07\x01\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x13!terraform-provider:u\xfa\xf8\xb3\x07\x66\xc2\xf3\xb3\x07\x61\xa2\xf3\xb3\x07*tf_examples/proxy_cluster_key_resource.txt\xaa\xf3\xb3\x07-tf_examples/proxy_cluster_key_data_source.txt\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\xbc\x04\n\x10ProxyClusterKeys\x12}\n\x06\x43reate\x12 .v1.ProxyClusterKeyCreateRequest\x1a!.v1.ProxyClusterKeyCreateResponse\".\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/proxy-cluster-keys\x12x\n\x03Get\x12\x1d.v1.ProxyClusterKeyGetRequest\x1a\x1e.v1.ProxyClusterKeyGetResponse\"2\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/proxy-cluster-keys/{id}\x12\x84\x01\n\x06\x44\x65lete\x12 .v1.ProxyClusterKeyDeleteRequest\x1a!.v1.ProxyClusterKeyDeleteResponse\"5\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07 \xaa\xf3\xb3\x07\x1b/v1/proxy-cluster-keys/{id}\x12v\n\x04List\x12\x1e.v1.ProxyClusterKeyListRequest\x1a\x1f.v1.ProxyClusterKeyListResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/proxy-cluster-keys\x1a\x30\xca\xf9\xb3\x07\x14\xc2\xf9\xb3\x07\x0fProxyClusterKey\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03gk-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42l\n\x19\x63om.strongdm.api.plumbingB\x18ProxyClusterKeysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_PROXYCLUSTERKEYCREATEREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyCreateRequest']
_PROXYCLUSTERKEYCREATERESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyCreateResponse']
_PROXYCLUSTERKEYGETREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyGetRequest']
_PROXYCLUSTERKEYGETRESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyGetResponse']
_PROXYCLUSTERKEYDELETEREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyDeleteRequest']
_PROXYCLUSTERKEYDELETERESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyDeleteResponse']
_PROXYCLUSTERKEYLISTREQUEST = DESCRIPTOR.message_types_by_name['ProxyClusterKeyListRequest']
_PROXYCLUSTERKEYLISTRESPONSE = DESCRIPTOR.message_types_by_name['ProxyClusterKeyListResponse']
_PROXYCLUSTERKEY = DESCRIPTOR.message_types_by_name['ProxyClusterKey']
ProxyClusterKeyCreateRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYCREATEREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyCreateRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyCreateRequest)

ProxyClusterKeyCreateResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYCREATERESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyCreateResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyCreateResponse)

ProxyClusterKeyGetRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYGETREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyGetRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyGetRequest)

ProxyClusterKeyGetResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYGETRESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyGetResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyGetResponse)

ProxyClusterKeyDeleteRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYDELETEREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyDeleteRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyDeleteRequest)

ProxyClusterKeyDeleteResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYDELETERESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyDeleteResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyDeleteResponse)

ProxyClusterKeyListRequest = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyListRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYLISTREQUEST,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyListRequest)
  })
_sym_db.RegisterMessage(ProxyClusterKeyListRequest)

ProxyClusterKeyListResponse = _reflection.GeneratedProtocolMessageType('ProxyClusterKeyListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEYLISTRESPONSE,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKeyListResponse)
  })
_sym_db.RegisterMessage(ProxyClusterKeyListResponse)

ProxyClusterKey = _reflection.GeneratedProtocolMessageType('ProxyClusterKey', (_message.Message,), {
  'DESCRIPTOR' : _PROXYCLUSTERKEY,
  '__module__' : 'proxy_cluster_keys_pb2'
  # @@protoc_insertion_point(class_scope:v1.ProxyClusterKey)
  })
_sym_db.RegisterMessage(ProxyClusterKey)

_PROXYCLUSTERKEYS = DESCRIPTOR.services_by_name['ProxyClusterKeys']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\030ProxyClusterKeysPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _PROXYCLUSTERKEYCREATEREQUEST.fields_by_name['proxy_cluster_key']._options = None
  _PROXYCLUSTERKEYCREATEREQUEST.fields_by_name['proxy_cluster_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['meta']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['proxy_cluster_key']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['proxy_cluster_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['secret_key']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['secret_key']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\360\363\263\007\001'
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEYCREATERESPONSE._options = None
  _PROXYCLUSTERKEYCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYGETREQUEST.fields_by_name['id']._options = None
  _PROXYCLUSTERKEYGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['meta']._options = None
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['proxy_cluster_key']._options = None
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['proxy_cluster_key']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEYGETRESPONSE._options = None
  _PROXYCLUSTERKEYGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYDELETEREQUEST.fields_by_name['id']._options = None
  _PROXYCLUSTERKEYDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['meta']._options = None
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEYDELETERESPONSE._options = None
  _PROXYCLUSTERKEYDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYLISTREQUEST.fields_by_name['filter']._options = None
  _PROXYCLUSTERKEYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['proxy_cluster_keys']._options = None
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['proxy_cluster_keys']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _PROXYCLUSTERKEYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PROXYCLUSTERKEY.fields_by_name['id']._options = None
  _PROXYCLUSTERKEY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PROXYCLUSTERKEY.fields_by_name['proxy_cluster_id']._options = None
  _PROXYCLUSTERKEY.fields_by_name['proxy_cluster_id']._serialized_options = b'\362\370\263\007\017\260\363\263\007\001\300\363\263\007\001\340\363\263\007\001'
  _PROXYCLUSTERKEY.fields_by_name['created_at']._options = None
  _PROXYCLUSTERKEY.fields_by_name['created_at']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _PROXYCLUSTERKEY.fields_by_name['last_used_at']._options = None
  _PROXYCLUSTERKEY.fields_by_name['last_used_at']._serialized_options = b'\362\370\263\007(\260\363\263\007\001\230\364\263\007\001\262\364\263\007\001*\262\364\263\007\023!terraform-provider'
  _PROXYCLUSTERKEY._options = None
  _PROXYCLUSTERKEY._serialized_options = b'\372\370\263\007f\302\363\263\007a\242\363\263\007*tf_examples/proxy_cluster_key_resource.txt\252\363\263\007-tf_examples/proxy_cluster_key_data_source.txt\372\370\263\007\005\250\363\263\007\001'
  _PROXYCLUSTERKEYS._options = None
  _PROXYCLUSTERKEYS._serialized_options = b'\312\371\263\007\024\302\371\263\007\017ProxyClusterKey\312\371\263\007\010\322\371\263\007\003gk-\312\371\263\007\005\350\371\263\007\001'
  _PROXYCLUSTERKEYS.methods_by_name['Create']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\033\252\363\263\007\026/v1/proxy-cluster-keys'
  _PROXYCLUSTERKEYS.methods_by_name['Get']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007 \252\363\263\007\033/v1/proxy-cluster-keys/{id}'
  _PROXYCLUSTERKEYS.methods_by_name['Delete']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007 \252\363\263\007\033/v1/proxy-cluster-keys/{id}'
  _PROXYCLUSTERKEYS.methods_by_name['List']._options = None
  _PROXYCLUSTERKEYS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/proxy-cluster-keys'
  _PROXYCLUSTERKEYCREATEREQUEST._serialized_start=93
  _PROXYCLUSTERKEYCREATEREQUEST._serialized_end=224
  _PROXYCLUSTERKEYCREATERESPONSE._serialized_start=227
  _PROXYCLUSTERKEYCREATERESPONSE._serialized_end=510
  _PROXYCLUSTERKEYGETREQUEST._serialized_start=512
  _PROXYCLUSTERKEYGETREQUEST._serialized_end=601
  _PROXYCLUSTERKEYGETRESPONSE._serialized_start=604
  _PROXYCLUSTERKEYGETRESPONSE._serialized_end=844
  _PROXYCLUSTERKEYDELETEREQUEST._serialized_start=846
  _PROXYCLUSTERKEYDELETEREQUEST._serialized_end=941
  _PROXYCLUSTERKEYDELETERESPONSE._serialized_start=944
  _PROXYCLUSTERKEYDELETERESPONSE._serialized_end=1130
  _PROXYCLUSTERKEYLISTREQUEST._serialized_start=1132
  _PROXYCLUSTERKEYLISTREQUEST._serialized_end=1227
  _PROXYCLUSTERKEYLISTRESPONSE._serialized_start=1230
  _PROXYCLUSTERKEYLISTRESPONSE._serialized_end=1449
  _PROXYCLUSTERKEY._serialized_start=1452
  _PROXYCLUSTERKEY._serialized_end=1852
  _PROXYCLUSTERKEYS._serialized_start=1855
  _PROXYCLUSTERKEYS._serialized_end=2427
# @@protoc_insertion_point(module_scope)
